@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,11 +36,11 @@ class CfnSkill(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         authentication_configuration: typing.Union["AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
         skill_package: typing.Union["SkillPackageProperty", _IResolvable_9ceae33e],
-        vendor_id: str,
+        vendor_id: builtins.str,
     ) -> None:
         """Create a new ``Alexa::ASK::Skill``.
 
@@ -71,25 +71,26 @@ class CfnSkill(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="authenticationConfiguration")
     def authentication_configuration(
         self,
@@ -101,14 +102,14 @@ class CfnSkill(
         """
         return jsii.get(self, "authenticationConfiguration")
 
-    @authentication_configuration.setter
+    @authentication_configuration.setter # type: ignore
     def authentication_configuration(
         self,
         value: typing.Union["AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "authenticationConfiguration", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="skillPackage")
     def skill_package(
         self,
@@ -120,15 +121,16 @@ class CfnSkill(
         """
         return jsii.get(self, "skillPackage")
 
-    @skill_package.setter
+    @skill_package.setter # type: ignore
     def skill_package(
-        self, value: typing.Union["SkillPackageProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["SkillPackageProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "skillPackage", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="vendorId")
-    def vendor_id(self) -> str:
+    def vendor_id(self) -> builtins.str:
         """``Alexa::ASK::Skill.VendorId``.
 
         see
@@ -136,8 +138,8 @@ class CfnSkill(
         """
         return jsii.get(self, "vendorId")
 
-    @vendor_id.setter
-    def vendor_id(self, value: str) -> None:
+    @vendor_id.setter # type: ignore
+    def vendor_id(self, value: builtins.str) -> None:
         jsii.set(self, "vendorId", value)
 
     @jsii.data_type(
@@ -151,7 +153,11 @@ class CfnSkill(
     )
     class AuthenticationConfigurationProperty:
         def __init__(
-            self, *, client_id: str, client_secret: str, refresh_token: str
+            self,
+            *,
+            client_id: builtins.str,
+            client_secret: builtins.str,
+            refresh_token: builtins.str,
         ) -> None:
             """
             :param client_id: ``CfnSkill.AuthenticationConfigurationProperty.ClientId``.
@@ -161,43 +167,49 @@ class CfnSkill(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "client_id": client_id,
                 "client_secret": client_secret,
                 "refresh_token": refresh_token,
             }
 
         @builtins.property
-        def client_id(self) -> str:
+        def client_id(self) -> builtins.str:
             """``CfnSkill.AuthenticationConfigurationProperty.ClientId``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html#cfn-ask-skill-authenticationconfiguration-clientid
             """
-            return self._values.get("client_id")
+            result = self._values.get("client_id")
+            assert result is not None, "Required property 'client_id' is missing"
+            return result
 
         @builtins.property
-        def client_secret(self) -> str:
+        def client_secret(self) -> builtins.str:
             """``CfnSkill.AuthenticationConfigurationProperty.ClientSecret``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html#cfn-ask-skill-authenticationconfiguration-clientsecret
             """
-            return self._values.get("client_secret")
+            result = self._values.get("client_secret")
+            assert result is not None, "Required property 'client_secret' is missing"
+            return result
 
         @builtins.property
-        def refresh_token(self) -> str:
+        def refresh_token(self) -> builtins.str:
             """``CfnSkill.AuthenticationConfigurationProperty.RefreshToken``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html#cfn-ask-skill-authenticationconfiguration-refreshtoken
             """
-            return self._values.get("refresh_token")
+            result = self._values.get("refresh_token")
+            assert result is not None, "Required property 'refresh_token' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -218,7 +230,7 @@ class CfnSkill(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-overrides.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if manifest is not None:
                 self._values["manifest"] = manifest
 
@@ -229,12 +241,13 @@ class CfnSkill(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-overrides.html#cfn-ask-skill-overrides-manifest
             """
-            return self._values.get("manifest")
+            result = self._values.get("manifest")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -257,11 +270,11 @@ class CfnSkill(
         def __init__(
             self,
             *,
-            s3_bucket: str,
-            s3_key: str,
+            s3_bucket: builtins.str,
+            s3_key: builtins.str,
             overrides: typing.Optional[typing.Union["CfnSkill.OverridesProperty", _IResolvable_9ceae33e]] = None,
-            s3_bucket_role: typing.Optional[str] = None,
-            s3_object_version: typing.Optional[str] = None,
+            s3_bucket_role: typing.Optional[builtins.str] = None,
+            s3_object_version: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param s3_bucket: ``CfnSkill.SkillPackageProperty.S3Bucket``.
@@ -273,7 +286,7 @@ class CfnSkill(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "s3_bucket": s3_bucket,
                 "s3_key": s3_key,
             }
@@ -285,22 +298,26 @@ class CfnSkill(
                 self._values["s3_object_version"] = s3_object_version
 
         @builtins.property
-        def s3_bucket(self) -> str:
+        def s3_bucket(self) -> builtins.str:
             """``CfnSkill.SkillPackageProperty.S3Bucket``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3bucket
             """
-            return self._values.get("s3_bucket")
+            result = self._values.get("s3_bucket")
+            assert result is not None, "Required property 's3_bucket' is missing"
+            return result
 
         @builtins.property
-        def s3_key(self) -> str:
+        def s3_key(self) -> builtins.str:
             """``CfnSkill.SkillPackageProperty.S3Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3key
             """
-            return self._values.get("s3_key")
+            result = self._values.get("s3_key")
+            assert result is not None, "Required property 's3_key' is missing"
+            return result
 
         @builtins.property
         def overrides(
@@ -311,30 +328,33 @@ class CfnSkill(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-overrides
             """
-            return self._values.get("overrides")
+            result = self._values.get("overrides")
+            return result
 
         @builtins.property
-        def s3_bucket_role(self) -> typing.Optional[str]:
+        def s3_bucket_role(self) -> typing.Optional[builtins.str]:
             """``CfnSkill.SkillPackageProperty.S3BucketRole``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3bucketrole
             """
-            return self._values.get("s3_bucket_role")
+            result = self._values.get("s3_bucket_role")
+            return result
 
         @builtins.property
-        def s3_object_version(self) -> typing.Optional[str]:
+        def s3_object_version(self) -> typing.Optional[builtins.str]:
             """``CfnSkill.SkillPackageProperty.S3ObjectVersion``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3objectversion
             """
-            return self._values.get("s3_object_version")
+            result = self._values.get("s3_object_version")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -358,7 +378,7 @@ class CfnSkillProps:
         *,
         authentication_configuration: typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
         skill_package: typing.Union["CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e],
-        vendor_id: str,
+        vendor_id: builtins.str,
     ) -> None:
         """Properties for defining a ``Alexa::ASK::Skill``.
 
@@ -369,7 +389,7 @@ class CfnSkillProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "authentication_configuration": authentication_configuration,
             "skill_package": skill_package,
             "vendor_id": vendor_id,
@@ -384,7 +404,9 @@ class CfnSkillProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-authenticationconfiguration
         """
-        return self._values.get("authentication_configuration")
+        result = self._values.get("authentication_configuration")
+        assert result is not None, "Required property 'authentication_configuration' is missing"
+        return result
 
     @builtins.property
     def skill_package(
@@ -395,21 +417,25 @@ class CfnSkillProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-skillpackage
         """
-        return self._values.get("skill_package")
+        result = self._values.get("skill_package")
+        assert result is not None, "Required property 'skill_package' is missing"
+        return result
 
     @builtins.property
-    def vendor_id(self) -> str:
+    def vendor_id(self) -> builtins.str:
         """``Alexa::ASK::Skill.VendorId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-vendorid
         """
-        return self._values.get("vendor_id")
+        result = self._values.get("vendor_id")
+        assert result is not None, "Required property 'vendor_id' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
