@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -56,14 +56,14 @@ class PipelineDeployStackAction(
     def __init__(
         self,
         *,
-        admin_permissions: bool,
+        admin_permissions: builtins.bool,
         input: _Artifact_af6d98e9,
         stack: _Stack_05f4505a,
         capabilities: typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]] = None,
-        change_set_name: typing.Optional[str] = None,
-        create_change_set_action_name: typing.Optional[str] = None,
+        change_set_name: typing.Optional[builtins.str] = None,
+        create_change_set_action_name: typing.Optional[builtins.str] = None,
         create_change_set_run_order: typing.Optional[jsii.Number] = None,
-        execute_change_set_action_name: typing.Optional[str] = None,
+        execute_change_set_action_name: typing.Optional[builtins.str] = None,
         execute_change_set_run_order: typing.Optional[jsii.Number] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
     ) -> None:
@@ -99,7 +99,8 @@ class PipelineDeployStackAction(
 
     @jsii.member(jsii_name="addToDeploymentRolePolicy")
     def add_to_deployment_role_policy(
-        self, statement: _PolicyStatement_f75dc775
+        self,
+        statement: _PolicyStatement_f75dc775,
     ) -> None:
         """Add policy statements to the role deploying the stack.
 
@@ -141,14 +142,14 @@ class PipelineDeployStackAction(
     @jsii.member(jsii_name="onStateChange")
     def on_state_change(
         self,
-        name: str,
+        name: builtins.str,
         target: typing.Optional[_IRuleTarget_41800a77] = None,
         *,
-        description: typing.Optional[str] = None,
-        enabled: typing.Optional[bool] = None,
+        description: typing.Optional[builtins.str] = None,
+        enabled: typing.Optional[builtins.bool] = None,
         event_bus: typing.Optional[_IEventBus_ed4f1700] = None,
         event_pattern: typing.Optional[_EventPattern_8aa7b781] = None,
-        rule_name: typing.Optional[str] = None,
+        rule_name: typing.Optional[builtins.str] = None,
         schedule: typing.Optional[_Schedule_11a70620] = None,
         targets: typing.Optional[typing.List[_IRuleTarget_41800a77]] = None,
     ) -> _Rule_c38e0b39:
@@ -178,7 +179,7 @@ class PipelineDeployStackAction(
 
         return jsii.invoke(self, "onStateChange", [name, target, options])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="actionProperties")
     def action_properties(self) -> _ActionProperties_8f5d7a9d:
         """
@@ -187,7 +188,7 @@ class PipelineDeployStackAction(
         """
         return jsii.get(self, "actionProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deploymentRole")
     def deployment_role(self) -> _IRole_e69bbae4:
         """
@@ -217,14 +218,14 @@ class PipelineDeployStackActionProps:
     def __init__(
         self,
         *,
-        admin_permissions: bool,
+        admin_permissions: builtins.bool,
         input: _Artifact_af6d98e9,
         stack: _Stack_05f4505a,
         capabilities: typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]] = None,
-        change_set_name: typing.Optional[str] = None,
-        create_change_set_action_name: typing.Optional[str] = None,
+        change_set_name: typing.Optional[builtins.str] = None,
+        create_change_set_action_name: typing.Optional[builtins.str] = None,
         create_change_set_run_order: typing.Optional[jsii.Number] = None,
-        execute_change_set_action_name: typing.Optional[str] = None,
+        execute_change_set_action_name: typing.Optional[builtins.str] = None,
         execute_change_set_run_order: typing.Optional[jsii.Number] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
     ) -> None:
@@ -243,7 +244,7 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "admin_permissions": admin_permissions,
             "input": input,
             "stack": stack,
@@ -264,7 +265,7 @@ class PipelineDeployStackActionProps:
             self._values["role"] = role
 
     @builtins.property
-    def admin_permissions(self) -> bool:
+    def admin_permissions(self) -> builtins.bool:
         """Whether to grant admin permissions to CloudFormation while deploying this template.
 
         Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you
@@ -282,7 +283,9 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("admin_permissions")
+        result = self._values.get("admin_permissions")
+        assert result is not None, "Required property 'admin_permissions' is missing"
+        return result
 
     @builtins.property
     def input(self) -> _Artifact_af6d98e9:
@@ -291,7 +294,9 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("input")
+        result = self._values.get("input")
+        assert result is not None, "Required property 'input' is missing"
+        return result
 
     @builtins.property
     def stack(self) -> _Stack_05f4505a:
@@ -300,7 +305,9 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("stack")
+        result = self._values.get("stack")
+        assert result is not None, "Required property 'stack' is missing"
+        return result
 
     @builtins.property
     def capabilities(
@@ -321,10 +328,11 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("capabilities")
+        result = self._values.get("capabilities")
+        return result
 
     @builtins.property
-    def change_set_name(self) -> typing.Optional[str]:
+    def change_set_name(self) -> typing.Optional[builtins.str]:
         """The name to use when creating a ChangeSet for the stack.
 
         default
@@ -333,10 +341,11 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("change_set_name")
+        result = self._values.get("change_set_name")
+        return result
 
     @builtins.property
-    def create_change_set_action_name(self) -> typing.Optional[str]:
+    def create_change_set_action_name(self) -> typing.Optional[builtins.str]:
         """The name of the CodePipeline action creating the ChangeSet.
 
         default
@@ -345,7 +354,8 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("create_change_set_action_name")
+        result = self._values.get("create_change_set_action_name")
+        return result
 
     @builtins.property
     def create_change_set_run_order(self) -> typing.Optional[jsii.Number]:
@@ -357,10 +367,11 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("create_change_set_run_order")
+        result = self._values.get("create_change_set_run_order")
+        return result
 
     @builtins.property
-    def execute_change_set_action_name(self) -> typing.Optional[str]:
+    def execute_change_set_action_name(self) -> typing.Optional[builtins.str]:
         """The name of the CodePipeline action creating the ChangeSet.
 
         default
@@ -369,7 +380,8 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("execute_change_set_action_name")
+        result = self._values.get("execute_change_set_action_name")
+        return result
 
     @builtins.property
     def execute_change_set_run_order(self) -> typing.Optional[jsii.Number]:
@@ -381,7 +393,8 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("execute_change_set_run_order")
+        result = self._values.get("execute_change_set_run_order")
+        return result
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -397,12 +410,13 @@ class PipelineDeployStackActionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("role")
+        result = self._values.get("role")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
