@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -38,10 +38,10 @@ class CfnAnalyzer(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        type: str,
-        analyzer_name: typing.Optional[str] = None,
+        type: builtins.str,
+        analyzer_name: typing.Optional[builtins.str] = None,
         archive_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -76,34 +76,35 @@ class CfnAnalyzer(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::AccessAnalyzer::Analyzer.Tags``.
@@ -113,9 +114,9 @@ class CfnAnalyzer(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="type")
-    def type(self) -> str:
+    def type(self) -> builtins.str:
         """``AWS::AccessAnalyzer::Analyzer.Type``.
 
         see
@@ -123,13 +124,13 @@ class CfnAnalyzer(
         """
         return jsii.get(self, "type")
 
-    @type.setter
-    def type(self, value: str) -> None:
+    @type.setter # type: ignore
+    def type(self, value: builtins.str) -> None:
         jsii.set(self, "type", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="analyzerName")
-    def analyzer_name(self) -> typing.Optional[str]:
+    def analyzer_name(self) -> typing.Optional[builtins.str]:
         """``AWS::AccessAnalyzer::Analyzer.AnalyzerName``.
 
         see
@@ -137,11 +138,11 @@ class CfnAnalyzer(
         """
         return jsii.get(self, "analyzerName")
 
-    @analyzer_name.setter
-    def analyzer_name(self, value: typing.Optional[str]) -> None:
+    @analyzer_name.setter # type: ignore
+    def analyzer_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "analyzerName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="archiveRules")
     def archive_rules(
         self,
@@ -153,7 +154,7 @@ class CfnAnalyzer(
         """
         return jsii.get(self, "archiveRules")
 
-    @archive_rules.setter
+    @archive_rules.setter # type: ignore
     def archive_rules(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]]]],
@@ -170,7 +171,7 @@ class CfnAnalyzer(
             self,
             *,
             filter: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAnalyzer.FilterProperty", _IResolvable_9ceae33e]]],
-            rule_name: str,
+            rule_name: builtins.str,
         ) -> None:
             """
             :param filter: ``CfnAnalyzer.ArchiveRuleProperty.Filter``.
@@ -179,7 +180,7 @@ class CfnAnalyzer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-archiverule.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "filter": filter,
                 "rule_name": rule_name,
             }
@@ -193,21 +194,25 @@ class CfnAnalyzer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-archiverule.html#cfn-accessanalyzer-analyzer-archiverule-filter
             """
-            return self._values.get("filter")
+            result = self._values.get("filter")
+            assert result is not None, "Required property 'filter' is missing"
+            return result
 
         @builtins.property
-        def rule_name(self) -> str:
+        def rule_name(self) -> builtins.str:
             """``CfnAnalyzer.ArchiveRuleProperty.RuleName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-archiverule.html#cfn-accessanalyzer-analyzer-archiverule-rulename
             """
-            return self._values.get("rule_name")
+            result = self._values.get("rule_name")
+            assert result is not None, "Required property 'rule_name' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -230,11 +235,11 @@ class CfnAnalyzer(
         def __init__(
             self,
             *,
-            property: str,
-            contains: typing.Optional[typing.List[str]] = None,
-            eq: typing.Optional[typing.List[str]] = None,
-            exists: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            neq: typing.Optional[typing.List[str]] = None,
+            property: builtins.str,
+            contains: typing.Optional[typing.List[builtins.str]] = None,
+            eq: typing.Optional[typing.List[builtins.str]] = None,
+            exists: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            neq: typing.Optional[typing.List[builtins.str]] = None,
         ) -> None:
             """
             :param property: ``CfnAnalyzer.FilterProperty.Property``.
@@ -246,7 +251,7 @@ class CfnAnalyzer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-filter.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "property": property,
             }
             if contains is not None:
@@ -259,54 +264,62 @@ class CfnAnalyzer(
                 self._values["neq"] = neq
 
         @builtins.property
-        def property(self) -> str:
+        def property(self) -> builtins.str:
             """``CfnAnalyzer.FilterProperty.Property``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-filter.html#cfn-accessanalyzer-analyzer-filter-property
             """
-            return self._values.get("property")
+            result = self._values.get("property")
+            assert result is not None, "Required property 'property' is missing"
+            return result
 
         @builtins.property
-        def contains(self) -> typing.Optional[typing.List[str]]:
+        def contains(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnAnalyzer.FilterProperty.Contains``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-filter.html#cfn-accessanalyzer-analyzer-filter-contains
             """
-            return self._values.get("contains")
+            result = self._values.get("contains")
+            return result
 
         @builtins.property
-        def eq(self) -> typing.Optional[typing.List[str]]:
+        def eq(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnAnalyzer.FilterProperty.Eq``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-filter.html#cfn-accessanalyzer-analyzer-filter-eq
             """
-            return self._values.get("eq")
+            result = self._values.get("eq")
+            return result
 
         @builtins.property
-        def exists(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        def exists(
+            self,
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnAnalyzer.FilterProperty.Exists``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-filter.html#cfn-accessanalyzer-analyzer-filter-exists
             """
-            return self._values.get("exists")
+            result = self._values.get("exists")
+            return result
 
         @builtins.property
-        def neq(self) -> typing.Optional[typing.List[str]]:
+        def neq(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnAnalyzer.FilterProperty.Neq``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-accessanalyzer-analyzer-filter.html#cfn-accessanalyzer-analyzer-filter-neq
             """
-            return self._values.get("neq")
+            result = self._values.get("neq")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -329,8 +342,8 @@ class CfnAnalyzerProps:
     def __init__(
         self,
         *,
-        type: str,
-        analyzer_name: typing.Optional[str] = None,
+        type: builtins.str,
+        analyzer_name: typing.Optional[builtins.str] = None,
         archive_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAnalyzer.ArchiveRuleProperty", _IResolvable_9ceae33e]]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -344,7 +357,7 @@ class CfnAnalyzerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-accessanalyzer-analyzer.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "type": type,
         }
         if analyzer_name is not None:
@@ -355,22 +368,25 @@ class CfnAnalyzerProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def type(self) -> str:
+    def type(self) -> builtins.str:
         """``AWS::AccessAnalyzer::Analyzer.Type``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-accessanalyzer-analyzer.html#cfn-accessanalyzer-analyzer-type
         """
-        return self._values.get("type")
+        result = self._values.get("type")
+        assert result is not None, "Required property 'type' is missing"
+        return result
 
     @builtins.property
-    def analyzer_name(self) -> typing.Optional[str]:
+    def analyzer_name(self) -> typing.Optional[builtins.str]:
         """``AWS::AccessAnalyzer::Analyzer.AnalyzerName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-accessanalyzer-analyzer.html#cfn-accessanalyzer-analyzer-analyzername
         """
-        return self._values.get("analyzer_name")
+        result = self._values.get("analyzer_name")
+        return result
 
     @builtins.property
     def archive_rules(
@@ -381,7 +397,8 @@ class CfnAnalyzerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-accessanalyzer-analyzer.html#cfn-accessanalyzer-analyzer-archiverules
         """
-        return self._values.get("archive_rules")
+        result = self._values.get("archive_rules")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -390,12 +407,13 @@ class CfnAnalyzerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-accessanalyzer-analyzer.html#cfn-accessanalyzer-analyzer-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
