@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -33,7 +33,7 @@ class Alarms:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
             self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
         if upper_alarm_interval_index is not None:
@@ -45,7 +45,8 @@ class Alarms:
         stability
         :stability: experimental
         """
-        return self._values.get("lower_alarm_interval_index")
+        result = self._values.get("lower_alarm_interval_index")
+        return result
 
     @builtins.property
     def upper_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
@@ -53,12 +54,13 @@ class Alarms:
         stability
         :stability: experimental
         """
-        return self._values.get("upper_alarm_interval_index")
+        result = self._values.get("upper_alarm_interval_index")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -74,7 +76,10 @@ class Alarms:
 )
 class ArbitraryIntervals:
     def __init__(
-        self, *, absolute: bool, intervals: typing.List["ScalingInterval"]
+        self,
+        *,
+        absolute: builtins.bool,
+        intervals: typing.List["ScalingInterval"],
     ) -> None:
         """
         :param absolute: 
@@ -83,18 +88,20 @@ class ArbitraryIntervals:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "absolute": absolute,
             "intervals": intervals,
         }
 
     @builtins.property
-    def absolute(self) -> bool:
+    def absolute(self) -> builtins.bool:
         """
         stability
         :stability: experimental
         """
-        return self._values.get("absolute")
+        result = self._values.get("absolute")
+        assert result is not None, "Required property 'absolute' is missing"
+        return result
 
     @builtins.property
     def intervals(self) -> typing.List["ScalingInterval"]:
@@ -102,12 +109,14 @@ class ArbitraryIntervals:
         stability
         :stability: experimental
         """
-        return self._values.get("intervals")
+        result = self._values.get("intervals")
+        assert result is not None, "Required property 'intervals' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -137,7 +146,7 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "lower": lower,
             "upper": upper,
         }
@@ -150,7 +159,9 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("lower")
+        result = self._values.get("lower")
+        assert result is not None, "Required property 'lower' is missing"
+        return result
 
     @builtins.property
     def upper(self) -> jsii.Number:
@@ -158,7 +169,9 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("upper")
+        result = self._values.get("upper")
+        assert result is not None, "Required property 'upper' is missing"
+        return result
 
     @builtins.property
     def change(self) -> typing.Optional[jsii.Number]:
@@ -166,12 +179,13 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("change")
+        result = self._values.get("change")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -181,7 +195,7 @@ class CompleteScalingInterval:
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_autoscaling_common.IRandomGenerator")
-class IRandomGenerator(jsii.compat.Protocol):
+class IRandomGenerator(typing_extensions.Protocol):
     """
     stability
     :stability: experimental
@@ -192,7 +206,7 @@ class IRandomGenerator(jsii.compat.Protocol):
         return _IRandomGeneratorProxy
 
     @jsii.member(jsii_name="nextBoolean")
-    def next_boolean(self) -> bool:
+    def next_boolean(self) -> builtins.bool:
         """
         stability
         :stability: experimental
@@ -217,10 +231,10 @@ class _IRandomGeneratorProxy:
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_autoscaling_common.IRandomGenerator"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_autoscaling_common.IRandomGenerator"
 
     @jsii.member(jsii_name="nextBoolean")
-    def next_boolean(self) -> bool:
+    def next_boolean(self) -> builtins.bool:
         """
         stability
         :stability: experimental
@@ -261,7 +275,7 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "change": change,
         }
         if lower is not None:
@@ -285,7 +299,9 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("change")
+        result = self._values.get("change")
+        assert result is not None, "Required property 'change' is missing"
+        return result
 
     @builtins.property
     def lower(self) -> typing.Optional[jsii.Number]:
@@ -299,7 +315,8 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("lower")
+        result = self._values.get("lower")
+        return result
 
     @builtins.property
     def upper(self) -> typing.Optional[jsii.Number]:
@@ -313,12 +330,13 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("upper")
+        result = self._values.get("upper")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
