@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,9 +36,9 @@ class CfnKeyspace(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        keyspace_name: typing.Optional[str] = None,
+        keyspace_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::Cassandra::Keyspace``.
 
@@ -63,27 +63,28 @@ class CfnKeyspace(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="keyspaceName")
-    def keyspace_name(self) -> typing.Optional[str]:
+    def keyspace_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Keyspace.KeyspaceName``.
 
         see
@@ -91,8 +92,8 @@ class CfnKeyspace(
         """
         return jsii.get(self, "keyspaceName")
 
-    @keyspace_name.setter
-    def keyspace_name(self, value: typing.Optional[str]) -> None:
+    @keyspace_name.setter # type: ignore
+    def keyspace_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "keyspaceName", value)
 
 
@@ -102,7 +103,7 @@ class CfnKeyspace(
     name_mapping={"keyspace_name": "keyspaceName"},
 )
 class CfnKeyspaceProps:
-    def __init__(self, *, keyspace_name: typing.Optional[str] = None) -> None:
+    def __init__(self, *, keyspace_name: typing.Optional[builtins.str] = None) -> None:
         """Properties for defining a ``AWS::Cassandra::Keyspace``.
 
         :param keyspace_name: ``AWS::Cassandra::Keyspace.KeyspaceName``.
@@ -110,23 +111,24 @@ class CfnKeyspaceProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if keyspace_name is not None:
             self._values["keyspace_name"] = keyspace_name
 
     @builtins.property
-    def keyspace_name(self) -> typing.Optional[str]:
+    def keyspace_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Keyspace.KeyspaceName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html#cfn-cassandra-keyspace-keyspacename
         """
-        return self._values.get("keyspace_name")
+        result = self._values.get("keyspace_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -152,14 +154,14 @@ class CfnTable(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        keyspace_name: str,
+        keyspace_name: builtins.str,
         partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]],
         billing_mode: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]] = None,
         clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]] = None,
         regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]] = None,
-        table_name: typing.Optional[str] = None,
+        table_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::Cassandra::Table``.
 
@@ -196,27 +198,28 @@ class CfnTable(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="keyspaceName")
-    def keyspace_name(self) -> str:
+    def keyspace_name(self) -> builtins.str:
         """``AWS::Cassandra::Table.KeyspaceName``.
 
         see
@@ -224,11 +227,11 @@ class CfnTable(
         """
         return jsii.get(self, "keyspaceName")
 
-    @keyspace_name.setter
-    def keyspace_name(self, value: str) -> None:
+    @keyspace_name.setter # type: ignore
+    def keyspace_name(self, value: builtins.str) -> None:
         jsii.set(self, "keyspaceName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="partitionKeyColumns")
     def partition_key_columns(
         self,
@@ -240,14 +243,14 @@ class CfnTable(
         """
         return jsii.get(self, "partitionKeyColumns")
 
-    @partition_key_columns.setter
+    @partition_key_columns.setter # type: ignore
     def partition_key_columns(
         self,
         value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "partitionKeyColumns", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="billingMode")
     def billing_mode(
         self,
@@ -259,14 +262,14 @@ class CfnTable(
         """
         return jsii.get(self, "billingMode")
 
-    @billing_mode.setter
+    @billing_mode.setter # type: ignore
     def billing_mode(
         self,
         value: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "billingMode", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="clusteringKeyColumns")
     def clustering_key_columns(
         self,
@@ -278,14 +281,14 @@ class CfnTable(
         """
         return jsii.get(self, "clusteringKeyColumns")
 
-    @clustering_key_columns.setter
+    @clustering_key_columns.setter # type: ignore
     def clustering_key_columns(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "clusteringKeyColumns", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="regularColumns")
     def regular_columns(
         self,
@@ -297,16 +300,16 @@ class CfnTable(
         """
         return jsii.get(self, "regularColumns")
 
-    @regular_columns.setter
+    @regular_columns.setter # type: ignore
     def regular_columns(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "regularColumns", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tableName")
-    def table_name(self) -> typing.Optional[str]:
+    def table_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Table.TableName``.
 
         see
@@ -314,8 +317,8 @@ class CfnTable(
         """
         return jsii.get(self, "tableName")
 
-    @table_name.setter
-    def table_name(self, value: typing.Optional[str]) -> None:
+    @table_name.setter # type: ignore
+    def table_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "tableName", value)
 
     @jsii.data_type(
@@ -330,7 +333,7 @@ class CfnTable(
         def __init__(
             self,
             *,
-            mode: str,
+            mode: builtins.str,
             provisioned_throughput: typing.Optional[typing.Union["CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
@@ -340,20 +343,22 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "mode": mode,
             }
             if provisioned_throughput is not None:
                 self._values["provisioned_throughput"] = provisioned_throughput
 
         @builtins.property
-        def mode(self) -> str:
+        def mode(self) -> builtins.str:
             """``CfnTable.BillingModeProperty.Mode``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html#cfn-cassandra-table-billingmode-mode
             """
-            return self._values.get("mode")
+            result = self._values.get("mode")
+            assert result is not None, "Required property 'mode' is missing"
+            return result
 
         @builtins.property
         def provisioned_throughput(
@@ -364,12 +369,13 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html#cfn-cassandra-table-billingmode-provisionedthroughput
             """
-            return self._values.get("provisioned_throughput")
+            result = self._values.get("provisioned_throughput")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -387,7 +393,7 @@ class CfnTable(
             self,
             *,
             column: typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e],
-            order_by: typing.Optional[str] = None,
+            order_by: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param column: ``CfnTable.ClusteringKeyColumnProperty.Column``.
@@ -396,7 +402,7 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "column": column,
             }
             if order_by is not None:
@@ -411,21 +417,24 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html#cfn-cassandra-table-clusteringkeycolumn-column
             """
-            return self._values.get("column")
+            result = self._values.get("column")
+            assert result is not None, "Required property 'column' is missing"
+            return result
 
         @builtins.property
-        def order_by(self) -> typing.Optional[str]:
+        def order_by(self) -> typing.Optional[builtins.str]:
             """``CfnTable.ClusteringKeyColumnProperty.OrderBy``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html#cfn-cassandra-table-clusteringkeycolumn-orderby
             """
-            return self._values.get("order_by")
+            result = self._values.get("order_by")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -439,7 +448,12 @@ class CfnTable(
         name_mapping={"column_name": "columnName", "column_type": "columnType"},
     )
     class ColumnProperty:
-        def __init__(self, *, column_name: str, column_type: str) -> None:
+        def __init__(
+            self,
+            *,
+            column_name: builtins.str,
+            column_type: builtins.str,
+        ) -> None:
             """
             :param column_name: ``CfnTable.ColumnProperty.ColumnName``.
             :param column_type: ``CfnTable.ColumnProperty.ColumnType``.
@@ -447,33 +461,37 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "column_name": column_name,
                 "column_type": column_type,
             }
 
         @builtins.property
-        def column_name(self) -> str:
+        def column_name(self) -> builtins.str:
             """``CfnTable.ColumnProperty.ColumnName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html#cfn-cassandra-table-column-columnname
             """
-            return self._values.get("column_name")
+            result = self._values.get("column_name")
+            assert result is not None, "Required property 'column_name' is missing"
+            return result
 
         @builtins.property
-        def column_type(self) -> str:
+        def column_type(self) -> builtins.str:
             """``CfnTable.ColumnProperty.ColumnType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html#cfn-cassandra-table-column-columntype
             """
-            return self._values.get("column_type")
+            result = self._values.get("column_type")
+            assert result is not None, "Required property 'column_type' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -503,7 +521,7 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "read_capacity_units": read_capacity_units,
                 "write_capacity_units": write_capacity_units,
             }
@@ -515,7 +533,9 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html#cfn-cassandra-table-provisionedthroughput-readcapacityunits
             """
-            return self._values.get("read_capacity_units")
+            result = self._values.get("read_capacity_units")
+            assert result is not None, "Required property 'read_capacity_units' is missing"
+            return result
 
         @builtins.property
         def write_capacity_units(self) -> jsii.Number:
@@ -524,12 +544,14 @@ class CfnTable(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html#cfn-cassandra-table-provisionedthroughput-writecapacityunits
             """
-            return self._values.get("write_capacity_units")
+            result = self._values.get("write_capacity_units")
+            assert result is not None, "Required property 'write_capacity_units' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -554,12 +576,12 @@ class CfnTableProps:
     def __init__(
         self,
         *,
-        keyspace_name: str,
+        keyspace_name: builtins.str,
         partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]],
         billing_mode: typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]] = None,
         clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]] = None,
         regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]] = None,
-        table_name: typing.Optional[str] = None,
+        table_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::Cassandra::Table``.
 
@@ -573,7 +595,7 @@ class CfnTableProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "keyspace_name": keyspace_name,
             "partition_key_columns": partition_key_columns,
         }
@@ -587,13 +609,15 @@ class CfnTableProps:
             self._values["table_name"] = table_name
 
     @builtins.property
-    def keyspace_name(self) -> str:
+    def keyspace_name(self) -> builtins.str:
         """``AWS::Cassandra::Table.KeyspaceName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-keyspacename
         """
-        return self._values.get("keyspace_name")
+        result = self._values.get("keyspace_name")
+        assert result is not None, "Required property 'keyspace_name' is missing"
+        return result
 
     @builtins.property
     def partition_key_columns(
@@ -604,7 +628,9 @@ class CfnTableProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-partitionkeycolumns
         """
-        return self._values.get("partition_key_columns")
+        result = self._values.get("partition_key_columns")
+        assert result is not None, "Required property 'partition_key_columns' is missing"
+        return result
 
     @builtins.property
     def billing_mode(
@@ -615,7 +641,8 @@ class CfnTableProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-billingmode
         """
-        return self._values.get("billing_mode")
+        result = self._values.get("billing_mode")
+        return result
 
     @builtins.property
     def clustering_key_columns(
@@ -626,7 +653,8 @@ class CfnTableProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-clusteringkeycolumns
         """
-        return self._values.get("clustering_key_columns")
+        result = self._values.get("clustering_key_columns")
+        return result
 
     @builtins.property
     def regular_columns(
@@ -637,21 +665,23 @@ class CfnTableProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-regularcolumns
         """
-        return self._values.get("regular_columns")
+        result = self._values.get("regular_columns")
+        return result
 
     @builtins.property
-    def table_name(self) -> typing.Optional[str]:
+    def table_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Table.TableName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-tablename
         """
-        return self._values.get("table_name")
+        result = self._values.get("table_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
