@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -35,11 +35,11 @@ class CfnCostCategory(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
-        rules: str,
-        rule_version: str,
+        name: builtins.str,
+        rules: builtins.str,
+        rule_version: builtins.str,
     ) -> None:
         """Create a new ``AWS::CE::CostCategory``.
 
@@ -66,45 +66,46 @@ class CfnCostCategory(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrEffectiveStart")
-    def attr_effective_start(self) -> str:
+    def attr_effective_start(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: EffectiveStart
         """
         return jsii.get(self, "attrEffectiveStart")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::CE::CostCategory.Name``.
 
         see
@@ -112,13 +113,13 @@ class CfnCostCategory(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="rules")
-    def rules(self) -> str:
+    def rules(self) -> builtins.str:
         """``AWS::CE::CostCategory.Rules``.
 
         see
@@ -126,13 +127,13 @@ class CfnCostCategory(
         """
         return jsii.get(self, "rules")
 
-    @rules.setter
-    def rules(self, value: str) -> None:
+    @rules.setter # type: ignore
+    def rules(self, value: builtins.str) -> None:
         jsii.set(self, "rules", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ruleVersion")
-    def rule_version(self) -> str:
+    def rule_version(self) -> builtins.str:
         """``AWS::CE::CostCategory.RuleVersion``.
 
         see
@@ -140,8 +141,8 @@ class CfnCostCategory(
         """
         return jsii.get(self, "ruleVersion")
 
-    @rule_version.setter
-    def rule_version(self, value: str) -> None:
+    @rule_version.setter # type: ignore
+    def rule_version(self, value: builtins.str) -> None:
         jsii.set(self, "ruleVersion", value)
 
 
@@ -151,7 +152,13 @@ class CfnCostCategory(
     name_mapping={"name": "name", "rules": "rules", "rule_version": "ruleVersion"},
 )
 class CfnCostCategoryProps:
-    def __init__(self, *, name: str, rules: str, rule_version: str) -> None:
+    def __init__(
+        self,
+        *,
+        name: builtins.str,
+        rules: builtins.str,
+        rule_version: builtins.str,
+    ) -> None:
         """Properties for defining a ``AWS::CE::CostCategory``.
 
         :param name: ``AWS::CE::CostCategory.Name``.
@@ -161,43 +168,49 @@ class CfnCostCategoryProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ce-costcategory.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "rules": rules,
             "rule_version": rule_version,
         }
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::CE::CostCategory.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ce-costcategory.html#cfn-ce-costcategory-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def rules(self) -> str:
+    def rules(self) -> builtins.str:
         """``AWS::CE::CostCategory.Rules``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ce-costcategory.html#cfn-ce-costcategory-rules
         """
-        return self._values.get("rules")
+        result = self._values.get("rules")
+        assert result is not None, "Required property 'rules' is missing"
+        return result
 
     @builtins.property
-    def rule_version(self) -> str:
+    def rule_version(self) -> builtins.str:
         """``AWS::CE::CostCategory.RuleVersion``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ce-costcategory.html#cfn-ce-costcategory-ruleversion
         """
-        return self._values.get("rule_version")
+        result = self._values.get("rule_version")
+        assert result is not None, "Required property 'rule_version' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
