@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -1068,7 +1069,7 @@ class Certificate(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         domain_name: builtins.str,
@@ -1103,7 +1104,7 @@ class Certificate(
     @builtins.classmethod
     def from_certificate_arn(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         certificate_arn: builtins.str,
     ) -> "ICertificate":
@@ -1148,7 +1149,7 @@ class DnsValidatedCertificate(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         hosted_zone: _IHostedZone_59ffab76,
