@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
@@ -578,7 +579,7 @@ class SlackChannelConfiguration(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         slack_channel_configuration_name: builtins.str,
@@ -625,7 +626,7 @@ class SlackChannelConfiguration(
     @builtins.classmethod
     def from_slack_channel_configuration_arn(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         slack_channel_configuration_arn: builtins.str,
     ) -> "ISlackChannelConfiguration":
