@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -767,7 +768,7 @@ class Ec2Environment(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         vpc: _IVpc_3795853f,
@@ -805,7 +806,7 @@ class Ec2Environment(
     @builtins.classmethod
     def from_ec2_environment_name(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         ec2_environment_name: builtins.str,
     ) -> "IEc2Environment":
