@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -941,7 +942,7 @@ class Trail(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         bucket: typing.Optional[_IBucket_25bad983] = None,
@@ -1000,7 +1001,7 @@ class Trail(
     @builtins.classmethod
     def on_event(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         description: typing.Optional[builtins.str] = None,
