@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -1505,7 +1506,7 @@ class Repository(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         repository_name: builtins.str,
@@ -1530,7 +1531,7 @@ class Repository(
     @builtins.classmethod
     def from_repository_arn(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         repository_arn: builtins.str,
     ) -> "IRepository":
@@ -1549,7 +1550,7 @@ class Repository(
     @builtins.classmethod
     def from_repository_name(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         repository_name: builtins.str,
     ) -> "IRepository":
