@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -497,7 +498,7 @@ class ProfilingGroup(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         compute_platform: typing.Optional["ComputePlatform"] = None,
@@ -523,7 +524,7 @@ class ProfilingGroup(
     @builtins.classmethod
     def from_profiling_group_arn(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         profiling_group_arn: builtins.str,
     ) -> "IProfilingGroup":
@@ -542,7 +543,7 @@ class ProfilingGroup(
     @builtins.classmethod
     def from_profiling_group_name(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         profiling_group_name: builtins.str,
     ) -> "IProfilingGroup":
