@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,11 +37,11 @@ class CfnConnection(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        connection_name: str,
-        host_arn: typing.Optional[str] = None,
-        provider_type: typing.Optional[str] = None,
+        connection_name: builtins.str,
+        host_arn: typing.Optional[builtins.str] = None,
+        provider_type: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::CodeStarConnections::Connection``.
@@ -75,52 +75,53 @@ class CfnConnection(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrConnectionArn")
-    def attr_connection_arn(self) -> str:
+    def attr_connection_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ConnectionArn
         """
         return jsii.get(self, "attrConnectionArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrConnectionStatus")
-    def attr_connection_status(self) -> str:
+    def attr_connection_status(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ConnectionStatus
         """
         return jsii.get(self, "attrConnectionStatus")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrOwnerAccountId")
-    def attr_owner_account_id(self) -> str:
+    def attr_owner_account_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: OwnerAccountId
         """
         return jsii.get(self, "attrOwnerAccountId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::CodeStarConnections::Connection.Tags``.
@@ -130,9 +131,9 @@ class CfnConnection(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="connectionName")
-    def connection_name(self) -> str:
+    def connection_name(self) -> builtins.str:
         """``AWS::CodeStarConnections::Connection.ConnectionName``.
 
         see
@@ -140,13 +141,13 @@ class CfnConnection(
         """
         return jsii.get(self, "connectionName")
 
-    @connection_name.setter
-    def connection_name(self, value: str) -> None:
+    @connection_name.setter # type: ignore
+    def connection_name(self, value: builtins.str) -> None:
         jsii.set(self, "connectionName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="hostArn")
-    def host_arn(self) -> typing.Optional[str]:
+    def host_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStarConnections::Connection.HostArn``.
 
         see
@@ -154,13 +155,13 @@ class CfnConnection(
         """
         return jsii.get(self, "hostArn")
 
-    @host_arn.setter
-    def host_arn(self, value: typing.Optional[str]) -> None:
+    @host_arn.setter # type: ignore
+    def host_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "hostArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="providerType")
-    def provider_type(self) -> typing.Optional[str]:
+    def provider_type(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStarConnections::Connection.ProviderType``.
 
         see
@@ -168,8 +169,8 @@ class CfnConnection(
         """
         return jsii.get(self, "providerType")
 
-    @provider_type.setter
-    def provider_type(self, value: typing.Optional[str]) -> None:
+    @provider_type.setter # type: ignore
+    def provider_type(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "providerType", value)
 
 
@@ -187,9 +188,9 @@ class CfnConnectionProps:
     def __init__(
         self,
         *,
-        connection_name: str,
-        host_arn: typing.Optional[str] = None,
-        provider_type: typing.Optional[str] = None,
+        connection_name: builtins.str,
+        host_arn: typing.Optional[builtins.str] = None,
+        provider_type: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::CodeStarConnections::Connection``.
@@ -202,7 +203,7 @@ class CfnConnectionProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "connection_name": connection_name,
         }
         if host_arn is not None:
@@ -213,31 +214,35 @@ class CfnConnectionProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def connection_name(self) -> str:
+    def connection_name(self) -> builtins.str:
         """``AWS::CodeStarConnections::Connection.ConnectionName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html#cfn-codestarconnections-connection-connectionname
         """
-        return self._values.get("connection_name")
+        result = self._values.get("connection_name")
+        assert result is not None, "Required property 'connection_name' is missing"
+        return result
 
     @builtins.property
-    def host_arn(self) -> typing.Optional[str]:
+    def host_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStarConnections::Connection.HostArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html#cfn-codestarconnections-connection-hostarn
         """
-        return self._values.get("host_arn")
+        result = self._values.get("host_arn")
+        return result
 
     @builtins.property
-    def provider_type(self) -> typing.Optional[str]:
+    def provider_type(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStarConnections::Connection.ProviderType``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html#cfn-codestarconnections-connection-providertype
         """
-        return self._values.get("provider_type")
+        result = self._values.get("provider_type")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -246,12 +251,13 @@ class CfnConnectionProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html#cfn-codestarconnections-connection-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
