@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,14 +37,14 @@ class CfnNotificationRule(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        detail_type: str,
-        event_type_ids: typing.List[str],
-        name: str,
-        resource: str,
+        detail_type: builtins.str,
+        event_type_ids: typing.List[builtins.str],
+        name: builtins.str,
+        resource: builtins.str,
         targets: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]]],
-        status: typing.Optional[str] = None,
+        status: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Create a new ``AWS::CodeStarNotifications::NotificationRule``.
@@ -84,25 +84,26 @@ class CfnNotificationRule(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::CodeStarNotifications::NotificationRule.Tags``.
@@ -112,9 +113,9 @@ class CfnNotificationRule(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="detailType")
-    def detail_type(self) -> str:
+    def detail_type(self) -> builtins.str:
         """``AWS::CodeStarNotifications::NotificationRule.DetailType``.
 
         see
@@ -122,13 +123,13 @@ class CfnNotificationRule(
         """
         return jsii.get(self, "detailType")
 
-    @detail_type.setter
-    def detail_type(self, value: str) -> None:
+    @detail_type.setter # type: ignore
+    def detail_type(self, value: builtins.str) -> None:
         jsii.set(self, "detailType", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="eventTypeIds")
-    def event_type_ids(self) -> typing.List[str]:
+    def event_type_ids(self) -> typing.List[builtins.str]:
         """``AWS::CodeStarNotifications::NotificationRule.EventTypeIds``.
 
         see
@@ -136,13 +137,13 @@ class CfnNotificationRule(
         """
         return jsii.get(self, "eventTypeIds")
 
-    @event_type_ids.setter
-    def event_type_ids(self, value: typing.List[str]) -> None:
+    @event_type_ids.setter # type: ignore
+    def event_type_ids(self, value: typing.List[builtins.str]) -> None:
         jsii.set(self, "eventTypeIds", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::CodeStarNotifications::NotificationRule.Name``.
 
         see
@@ -150,13 +151,13 @@ class CfnNotificationRule(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resource")
-    def resource(self) -> str:
+    def resource(self) -> builtins.str:
         """``AWS::CodeStarNotifications::NotificationRule.Resource``.
 
         see
@@ -164,11 +165,11 @@ class CfnNotificationRule(
         """
         return jsii.get(self, "resource")
 
-    @resource.setter
-    def resource(self, value: str) -> None:
+    @resource.setter # type: ignore
+    def resource(self, value: builtins.str) -> None:
         jsii.set(self, "resource", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="targets")
     def targets(
         self,
@@ -180,16 +181,16 @@ class CfnNotificationRule(
         """
         return jsii.get(self, "targets")
 
-    @targets.setter
+    @targets.setter # type: ignore
     def targets(
         self,
         value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "targets", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="status")
-    def status(self) -> typing.Optional[str]:
+    def status(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStarNotifications::NotificationRule.Status``.
 
         see
@@ -197,8 +198,8 @@ class CfnNotificationRule(
         """
         return jsii.get(self, "status")
 
-    @status.setter
-    def status(self, value: typing.Optional[str]) -> None:
+    @status.setter # type: ignore
+    def status(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "status", value)
 
     @jsii.data_type(
@@ -210,8 +211,8 @@ class CfnNotificationRule(
         def __init__(
             self,
             *,
-            target_address: typing.Optional[str] = None,
-            target_type: typing.Optional[str] = None,
+            target_address: typing.Optional[builtins.str] = None,
+            target_type: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param target_address: ``CfnNotificationRule.TargetProperty.TargetAddress``.
@@ -220,34 +221,36 @@ class CfnNotificationRule(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestarnotifications-notificationrule-target.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if target_address is not None:
                 self._values["target_address"] = target_address
             if target_type is not None:
                 self._values["target_type"] = target_type
 
         @builtins.property
-        def target_address(self) -> typing.Optional[str]:
+        def target_address(self) -> typing.Optional[builtins.str]:
             """``CfnNotificationRule.TargetProperty.TargetAddress``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestarnotifications-notificationrule-target.html#cfn-codestarnotifications-notificationrule-target-targetaddress
             """
-            return self._values.get("target_address")
+            result = self._values.get("target_address")
+            return result
 
         @builtins.property
-        def target_type(self) -> typing.Optional[str]:
+        def target_type(self) -> typing.Optional[builtins.str]:
             """``CfnNotificationRule.TargetProperty.TargetType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestarnotifications-notificationrule-target.html#cfn-codestarnotifications-notificationrule-target-targettype
             """
-            return self._values.get("target_type")
+            result = self._values.get("target_type")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -273,12 +276,12 @@ class CfnNotificationRuleProps:
     def __init__(
         self,
         *,
-        detail_type: str,
-        event_type_ids: typing.List[str],
-        name: str,
-        resource: str,
+        detail_type: builtins.str,
+        event_type_ids: typing.List[builtins.str],
+        name: builtins.str,
+        resource: builtins.str,
         targets: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_9ceae33e]]],
-        status: typing.Optional[str] = None,
+        status: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Properties for defining a ``AWS::CodeStarNotifications::NotificationRule``.
@@ -294,7 +297,7 @@ class CfnNotificationRuleProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "detail_type": detail_type,
             "event_type_ids": event_type_ids,
             "name": name,
@@ -307,40 +310,48 @@ class CfnNotificationRuleProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def detail_type(self) -> str:
+    def detail_type(self) -> builtins.str:
         """``AWS::CodeStarNotifications::NotificationRule.DetailType``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-detailtype
         """
-        return self._values.get("detail_type")
+        result = self._values.get("detail_type")
+        assert result is not None, "Required property 'detail_type' is missing"
+        return result
 
     @builtins.property
-    def event_type_ids(self) -> typing.List[str]:
+    def event_type_ids(self) -> typing.List[builtins.str]:
         """``AWS::CodeStarNotifications::NotificationRule.EventTypeIds``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         """
-        return self._values.get("event_type_ids")
+        result = self._values.get("event_type_ids")
+        assert result is not None, "Required property 'event_type_ids' is missing"
+        return result
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::CodeStarNotifications::NotificationRule.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def resource(self) -> str:
+    def resource(self) -> builtins.str:
         """``AWS::CodeStarNotifications::NotificationRule.Resource``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-resource
         """
-        return self._values.get("resource")
+        result = self._values.get("resource")
+        assert result is not None, "Required property 'resource' is missing"
+        return result
 
     @builtins.property
     def targets(
@@ -351,16 +362,19 @@ class CfnNotificationRuleProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         """
-        return self._values.get("targets")
+        result = self._values.get("targets")
+        assert result is not None, "Required property 'targets' is missing"
+        return result
 
     @builtins.property
-    def status(self) -> typing.Optional[str]:
+    def status(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStarNotifications::NotificationRule.Status``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-status
         """
-        return self._values.get("status")
+        result = self._values.get("status")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -369,12 +383,13 @@ class CfnNotificationRuleProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
