@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,12 +36,12 @@ class CfnPipeline(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
+        name: builtins.str,
         parameter_objects: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterObjectProperty", _IResolvable_9ceae33e]]],
-        activate: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        description: typing.Optional[str] = None,
+        activate: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        description: typing.Optional[builtins.str] = None,
         parameter_values: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterValueProperty", _IResolvable_9ceae33e]]]] = None,
         pipeline_objects: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineObjectProperty", _IResolvable_9ceae33e]]]] = None,
         pipeline_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineTagProperty", _IResolvable_9ceae33e]]]] = None,
@@ -83,27 +83,28 @@ class CfnPipeline(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
         see
@@ -111,11 +112,11 @@ class CfnPipeline(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameterObjects")
     def parameter_objects(
         self,
@@ -127,16 +128,18 @@ class CfnPipeline(
         """
         return jsii.get(self, "parameterObjects")
 
-    @parameter_objects.setter
+    @parameter_objects.setter # type: ignore
     def parameter_objects(
         self,
         value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterObjectProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "parameterObjects", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="activate")
-    def activate(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def activate(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
         see
@@ -144,15 +147,16 @@ class CfnPipeline(
         """
         return jsii.get(self, "activate")
 
-    @activate.setter
+    @activate.setter # type: ignore
     def activate(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "activate", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
         see
@@ -160,11 +164,11 @@ class CfnPipeline(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameterValues")
     def parameter_values(
         self,
@@ -176,14 +180,14 @@ class CfnPipeline(
         """
         return jsii.get(self, "parameterValues")
 
-    @parameter_values.setter
+    @parameter_values.setter # type: ignore
     def parameter_values(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterValueProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "parameterValues", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="pipelineObjects")
     def pipeline_objects(
         self,
@@ -195,14 +199,14 @@ class CfnPipeline(
         """
         return jsii.get(self, "pipelineObjects")
 
-    @pipeline_objects.setter
+    @pipeline_objects.setter # type: ignore
     def pipeline_objects(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineObjectProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "pipelineObjects", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="pipelineTags")
     def pipeline_tags(
         self,
@@ -214,7 +218,7 @@ class CfnPipeline(
         """
         return jsii.get(self, "pipelineTags")
 
-    @pipeline_tags.setter
+    @pipeline_tags.setter # type: ignore
     def pipeline_tags(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineTagProperty", _IResolvable_9ceae33e]]]],
@@ -234,9 +238,9 @@ class CfnPipeline(
         def __init__(
             self,
             *,
-            key: str,
-            ref_value: typing.Optional[str] = None,
-            string_value: typing.Optional[str] = None,
+            key: builtins.str,
+            ref_value: typing.Optional[builtins.str] = None,
+            string_value: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param key: ``CfnPipeline.FieldProperty.Key``.
@@ -246,7 +250,7 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
             }
             if ref_value is not None:
@@ -255,36 +259,40 @@ class CfnPipeline(
                 self._values["string_value"] = string_value
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPipeline.FieldProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def ref_value(self) -> typing.Optional[str]:
+        def ref_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.RefValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-refvalue
             """
-            return self._values.get("ref_value")
+            result = self._values.get("ref_value")
+            return result
 
         @builtins.property
-        def string_value(self) -> typing.Optional[str]:
+        def string_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.StringValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-stringvalue
             """
-            return self._values.get("string_value")
+            result = self._values.get("string_value")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -298,7 +306,7 @@ class CfnPipeline(
         name_mapping={"key": "key", "string_value": "stringValue"},
     )
     class ParameterAttributeProperty:
-        def __init__(self, *, key: str, string_value: str) -> None:
+        def __init__(self, *, key: builtins.str, string_value: builtins.str) -> None:
             """
             :param key: ``CfnPipeline.ParameterAttributeProperty.Key``.
             :param string_value: ``CfnPipeline.ParameterAttributeProperty.StringValue``.
@@ -306,33 +314,37 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "string_value": string_value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def string_value(self) -> str:
+        def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-stringvalue
             """
-            return self._values.get("string_value")
+            result = self._values.get("string_value")
+            assert result is not None, "Required property 'string_value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -350,7 +362,7 @@ class CfnPipeline(
             self,
             *,
             attributes: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterAttributeProperty", _IResolvable_9ceae33e]]],
-            id: str,
+            id: builtins.str,
         ) -> None:
             """
             :param attributes: ``CfnPipeline.ParameterObjectProperty.Attributes``.
@@ -359,7 +371,7 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "attributes": attributes,
                 "id": id,
             }
@@ -373,21 +385,25 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-attributes
             """
-            return self._values.get("attributes")
+            result = self._values.get("attributes")
+            assert result is not None, "Required property 'attributes' is missing"
+            return result
 
         @builtins.property
-        def id(self) -> str:
+        def id(self) -> builtins.str:
             """``CfnPipeline.ParameterObjectProperty.Id``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-id
             """
-            return self._values.get("id")
+            result = self._values.get("id")
+            assert result is not None, "Required property 'id' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -401,7 +417,7 @@ class CfnPipeline(
         name_mapping={"id": "id", "string_value": "stringValue"},
     )
     class ParameterValueProperty:
-        def __init__(self, *, id: str, string_value: str) -> None:
+        def __init__(self, *, id: builtins.str, string_value: builtins.str) -> None:
             """
             :param id: ``CfnPipeline.ParameterValueProperty.Id``.
             :param string_value: ``CfnPipeline.ParameterValueProperty.StringValue``.
@@ -409,33 +425,37 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "id": id,
                 "string_value": string_value,
             }
 
         @builtins.property
-        def id(self) -> str:
+        def id(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.Id``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-id
             """
-            return self._values.get("id")
+            result = self._values.get("id")
+            assert result is not None, "Required property 'id' is missing"
+            return result
 
         @builtins.property
-        def string_value(self) -> str:
+        def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.StringValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-stringvalue
             """
-            return self._values.get("string_value")
+            result = self._values.get("string_value")
+            assert result is not None, "Required property 'string_value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -453,8 +473,8 @@ class CfnPipeline(
             self,
             *,
             fields: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.FieldProperty", _IResolvable_9ceae33e]]],
-            id: str,
-            name: str,
+            id: builtins.str,
+            name: builtins.str,
         ) -> None:
             """
             :param fields: ``CfnPipeline.PipelineObjectProperty.Fields``.
@@ -464,7 +484,7 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "fields": fields,
                 "id": id,
                 "name": name,
@@ -479,30 +499,36 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-fields
             """
-            return self._values.get("fields")
+            result = self._values.get("fields")
+            assert result is not None, "Required property 'fields' is missing"
+            return result
 
         @builtins.property
-        def id(self) -> str:
+        def id(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Id``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-id
             """
-            return self._values.get("id")
+            result = self._values.get("id")
+            assert result is not None, "Required property 'id' is missing"
+            return result
 
         @builtins.property
-        def name(self) -> str:
+        def name(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            assert result is not None, "Required property 'name' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -516,7 +542,7 @@ class CfnPipeline(
         name_mapping={"key": "key", "value": "value"},
     )
     class PipelineTagProperty:
-        def __init__(self, *, key: str, value: str) -> None:
+        def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
             """
             :param key: ``CfnPipeline.PipelineTagProperty.Key``.
             :param value: ``CfnPipeline.PipelineTagProperty.Value``.
@@ -524,33 +550,37 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "value": value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def value(self) -> str:
+        def value(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            assert result is not None, "Required property 'value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -576,10 +606,10 @@ class CfnPipelineProps:
     def __init__(
         self,
         *,
-        name: str,
+        name: builtins.str,
         parameter_objects: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", _IResolvable_9ceae33e]]],
-        activate: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        description: typing.Optional[str] = None,
+        activate: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        description: typing.Optional[builtins.str] = None,
         parameter_values: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterValueProperty", _IResolvable_9ceae33e]]]] = None,
         pipeline_objects: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineObjectProperty", _IResolvable_9ceae33e]]]] = None,
         pipeline_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineTagProperty", _IResolvable_9ceae33e]]]] = None,
@@ -597,7 +627,7 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "parameter_objects": parameter_objects,
         }
@@ -613,13 +643,15 @@ class CfnPipelineProps:
             self._values["pipeline_tags"] = pipeline_tags
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
     def parameter_objects(
@@ -630,25 +662,31 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
         """
-        return self._values.get("parameter_objects")
+        result = self._values.get("parameter_objects")
+        assert result is not None, "Required property 'parameter_objects' is missing"
+        return result
 
     @builtins.property
-    def activate(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def activate(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
         """
-        return self._values.get("activate")
+        result = self._values.get("activate")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
     def parameter_values(
@@ -659,7 +697,8 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
         """
-        return self._values.get("parameter_values")
+        result = self._values.get("parameter_values")
+        return result
 
     @builtins.property
     def pipeline_objects(
@@ -670,7 +709,8 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
         """
-        return self._values.get("pipeline_objects")
+        result = self._values.get("pipeline_objects")
+        return result
 
     @builtins.property
     def pipeline_tags(
@@ -681,12 +721,13 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
         """
-        return self._values.get("pipeline_tags")
+        result = self._values.get("pipeline_tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
