@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -32,7 +32,7 @@ class CfnGraph(
     :cloudformationResource:: AWS::Detective::Graph
     """
 
-    def __init__(self, scope: _Construct_f50a3f53, id: str) -> None:
+    def __init__(self, scope: _Construct_f50a3f53, id: builtins.str) -> None:
         """Create a new ``AWS::Detective::Graph``.
 
         :param scope: - scope in which this resource is defined.
@@ -51,15 +51,15 @@ class CfnGraph(
         """
         return jsii.invoke(self, "inspect", [inspector])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
@@ -84,12 +84,12 @@ class CfnMemberInvitation(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        graph_arn: str,
-        member_email_address: str,
-        member_id: str,
-        message: typing.Optional[str] = None,
+        graph_arn: builtins.str,
+        member_email_address: builtins.str,
+        member_id: builtins.str,
+        message: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::Detective::MemberInvitation``.
 
@@ -122,27 +122,28 @@ class CfnMemberInvitation(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="graphArn")
-    def graph_arn(self) -> str:
+    def graph_arn(self) -> builtins.str:
         """``AWS::Detective::MemberInvitation.GraphArn``.
 
         see
@@ -150,13 +151,13 @@ class CfnMemberInvitation(
         """
         return jsii.get(self, "graphArn")
 
-    @graph_arn.setter
-    def graph_arn(self, value: str) -> None:
+    @graph_arn.setter # type: ignore
+    def graph_arn(self, value: builtins.str) -> None:
         jsii.set(self, "graphArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="memberEmailAddress")
-    def member_email_address(self) -> str:
+    def member_email_address(self) -> builtins.str:
         """``AWS::Detective::MemberInvitation.MemberEmailAddress``.
 
         see
@@ -164,13 +165,13 @@ class CfnMemberInvitation(
         """
         return jsii.get(self, "memberEmailAddress")
 
-    @member_email_address.setter
-    def member_email_address(self, value: str) -> None:
+    @member_email_address.setter # type: ignore
+    def member_email_address(self, value: builtins.str) -> None:
         jsii.set(self, "memberEmailAddress", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="memberId")
-    def member_id(self) -> str:
+    def member_id(self) -> builtins.str:
         """``AWS::Detective::MemberInvitation.MemberId``.
 
         see
@@ -178,13 +179,13 @@ class CfnMemberInvitation(
         """
         return jsii.get(self, "memberId")
 
-    @member_id.setter
-    def member_id(self, value: str) -> None:
+    @member_id.setter # type: ignore
+    def member_id(self, value: builtins.str) -> None:
         jsii.set(self, "memberId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="message")
-    def message(self) -> typing.Optional[str]:
+    def message(self) -> typing.Optional[builtins.str]:
         """``AWS::Detective::MemberInvitation.Message``.
 
         see
@@ -192,8 +193,8 @@ class CfnMemberInvitation(
         """
         return jsii.get(self, "message")
 
-    @message.setter
-    def message(self, value: typing.Optional[str]) -> None:
+    @message.setter # type: ignore
+    def message(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "message", value)
 
 
@@ -211,10 +212,10 @@ class CfnMemberInvitationProps:
     def __init__(
         self,
         *,
-        graph_arn: str,
-        member_email_address: str,
-        member_id: str,
-        message: typing.Optional[str] = None,
+        graph_arn: builtins.str,
+        member_email_address: builtins.str,
+        member_id: builtins.str,
+        message: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::Detective::MemberInvitation``.
 
@@ -226,7 +227,7 @@ class CfnMemberInvitationProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-detective-memberinvitation.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "graph_arn": graph_arn,
             "member_email_address": member_email_address,
             "member_id": member_id,
@@ -235,45 +236,52 @@ class CfnMemberInvitationProps:
             self._values["message"] = message
 
     @builtins.property
-    def graph_arn(self) -> str:
+    def graph_arn(self) -> builtins.str:
         """``AWS::Detective::MemberInvitation.GraphArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-detective-memberinvitation.html#cfn-detective-memberinvitation-grapharn
         """
-        return self._values.get("graph_arn")
+        result = self._values.get("graph_arn")
+        assert result is not None, "Required property 'graph_arn' is missing"
+        return result
 
     @builtins.property
-    def member_email_address(self) -> str:
+    def member_email_address(self) -> builtins.str:
         """``AWS::Detective::MemberInvitation.MemberEmailAddress``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-detective-memberinvitation.html#cfn-detective-memberinvitation-memberemailaddress
         """
-        return self._values.get("member_email_address")
+        result = self._values.get("member_email_address")
+        assert result is not None, "Required property 'member_email_address' is missing"
+        return result
 
     @builtins.property
-    def member_id(self) -> str:
+    def member_id(self) -> builtins.str:
         """``AWS::Detective::MemberInvitation.MemberId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-detective-memberinvitation.html#cfn-detective-memberinvitation-memberid
         """
-        return self._values.get("member_id")
+        result = self._values.get("member_id")
+        assert result is not None, "Required property 'member_id' is missing"
+        return result
 
     @builtins.property
-    def message(self) -> typing.Optional[str]:
+    def message(self) -> typing.Optional[builtins.str]:
         """``AWS::Detective::MemberInvitation.Message``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-detective-memberinvitation.html#cfn-detective-memberinvitation-message
         """
-        return self._values.get("message")
+        result = self._values.get("message")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
