@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,12 +37,12 @@ class CfnLifecyclePolicy(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        description: typing.Optional[str] = None,
-        execution_role_arn: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        execution_role_arn: typing.Optional[builtins.str] = None,
         policy_details: typing.Optional[typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]] = None,
-        state: typing.Optional[str] = None,
+        state: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::DLM::LifecyclePolicy``.
 
@@ -75,36 +75,37 @@ class CfnLifecyclePolicy(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.Description``.
 
         see
@@ -112,13 +113,13 @@ class CfnLifecyclePolicy(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="executionRoleArn")
-    def execution_role_arn(self) -> typing.Optional[str]:
+    def execution_role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.ExecutionRoleArn``.
 
         see
@@ -126,11 +127,11 @@ class CfnLifecyclePolicy(
         """
         return jsii.get(self, "executionRoleArn")
 
-    @execution_role_arn.setter
-    def execution_role_arn(self, value: typing.Optional[str]) -> None:
+    @execution_role_arn.setter # type: ignore
+    def execution_role_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "executionRoleArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="policyDetails")
     def policy_details(
         self,
@@ -142,16 +143,16 @@ class CfnLifecyclePolicy(
         """
         return jsii.get(self, "policyDetails")
 
-    @policy_details.setter
+    @policy_details.setter # type: ignore
     def policy_details(
         self,
         value: typing.Optional[typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "policyDetails", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="state")
-    def state(self) -> typing.Optional[str]:
+    def state(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.State``.
 
         see
@@ -159,8 +160,8 @@ class CfnLifecyclePolicy(
         """
         return jsii.get(self, "state")
 
-    @state.setter
-    def state(self, value: typing.Optional[str]) -> None:
+    @state.setter # type: ignore
+    def state(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "state", value)
 
     @jsii.data_type(
@@ -177,10 +178,10 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            cron_expression: typing.Optional[str] = None,
+            cron_expression: typing.Optional[builtins.str] = None,
             interval: typing.Optional[jsii.Number] = None,
-            interval_unit: typing.Optional[str] = None,
-            times: typing.Optional[typing.List[str]] = None,
+            interval_unit: typing.Optional[builtins.str] = None,
+            times: typing.Optional[typing.List[builtins.str]] = None,
         ) -> None:
             """
             :param cron_expression: ``CfnLifecyclePolicy.CreateRuleProperty.CronExpression``.
@@ -191,7 +192,7 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if cron_expression is not None:
                 self._values["cron_expression"] = cron_expression
             if interval is not None:
@@ -202,13 +203,14 @@ class CfnLifecyclePolicy(
                 self._values["times"] = times
 
         @builtins.property
-        def cron_expression(self) -> typing.Optional[str]:
+        def cron_expression(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.CreateRuleProperty.CronExpression``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-cronexpression
             """
-            return self._values.get("cron_expression")
+            result = self._values.get("cron_expression")
+            return result
 
         @builtins.property
         def interval(self) -> typing.Optional[jsii.Number]:
@@ -217,30 +219,33 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-interval
             """
-            return self._values.get("interval")
+            result = self._values.get("interval")
+            return result
 
         @builtins.property
-        def interval_unit(self) -> typing.Optional[str]:
+        def interval_unit(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.CreateRuleProperty.IntervalUnit``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-intervalunit
             """
-            return self._values.get("interval_unit")
+            result = self._values.get("interval_unit")
+            return result
 
         @builtins.property
-        def times(self) -> typing.Optional[typing.List[str]]:
+        def times(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnLifecyclePolicy.CreateRuleProperty.Times``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-times
             """
-            return self._values.get("times")
+            result = self._values.get("times")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -254,7 +259,12 @@ class CfnLifecyclePolicy(
         name_mapping={"interval": "interval", "interval_unit": "intervalUnit"},
     )
     class CrossRegionCopyRetainRuleProperty:
-        def __init__(self, *, interval: jsii.Number, interval_unit: str) -> None:
+        def __init__(
+            self,
+            *,
+            interval: jsii.Number,
+            interval_unit: builtins.str,
+        ) -> None:
             """
             :param interval: ``CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty.Interval``.
             :param interval_unit: ``CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty.IntervalUnit``.
@@ -262,7 +272,7 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyretainrule.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "interval": interval,
                 "interval_unit": interval_unit,
             }
@@ -274,21 +284,25 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyretainrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyretainrule-interval
             """
-            return self._values.get("interval")
+            result = self._values.get("interval")
+            assert result is not None, "Required property 'interval' is missing"
+            return result
 
         @builtins.property
-        def interval_unit(self) -> str:
+        def interval_unit(self) -> builtins.str:
             """``CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty.IntervalUnit``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyretainrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyretainrule-intervalunit
             """
-            return self._values.get("interval_unit")
+            result = self._values.get("interval_unit")
+            assert result is not None, "Required property 'interval_unit' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -311,10 +325,10 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            encrypted: typing.Union[bool, _IResolvable_9ceae33e],
-            target_region: str,
-            cmk_arn: typing.Optional[str] = None,
-            copy_tags: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            encrypted: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+            target_region: builtins.str,
+            cmk_arn: typing.Optional[builtins.str] = None,
+            copy_tags: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
             retain_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
@@ -327,7 +341,7 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "encrypted": encrypted,
                 "target_region": target_region,
             }
@@ -339,42 +353,48 @@ class CfnLifecyclePolicy(
                 self._values["retain_rule"] = retain_rule
 
         @builtins.property
-        def encrypted(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+        def encrypted(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.Encrypted``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-encrypted
             """
-            return self._values.get("encrypted")
+            result = self._values.get("encrypted")
+            assert result is not None, "Required property 'encrypted' is missing"
+            return result
 
         @builtins.property
-        def target_region(self) -> str:
+        def target_region(self) -> builtins.str:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.TargetRegion``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-targetregion
             """
-            return self._values.get("target_region")
+            result = self._values.get("target_region")
+            assert result is not None, "Required property 'target_region' is missing"
+            return result
 
         @builtins.property
-        def cmk_arn(self) -> typing.Optional[str]:
+        def cmk_arn(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.CmkArn``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-cmkarn
             """
-            return self._values.get("cmk_arn")
+            result = self._values.get("cmk_arn")
+            return result
 
         @builtins.property
         def copy_tags(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.CopyTags``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-copytags
             """
-            return self._values.get("copy_tags")
+            result = self._values.get("copy_tags")
+            return result
 
         @builtins.property
         def retain_rule(
@@ -385,12 +405,13 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-retainrule
             """
-            return self._values.get("retain_rule")
+            result = self._values.get("retain_rule")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -412,10 +433,10 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            availability_zones: typing.Optional[typing.List[str]] = None,
+            availability_zones: typing.Optional[typing.List[builtins.str]] = None,
             count: typing.Optional[jsii.Number] = None,
             interval: typing.Optional[jsii.Number] = None,
-            interval_unit: typing.Optional[str] = None,
+            interval_unit: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param availability_zones: ``CfnLifecyclePolicy.FastRestoreRuleProperty.AvailabilityZones``.
@@ -426,7 +447,7 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if availability_zones is not None:
                 self._values["availability_zones"] = availability_zones
             if count is not None:
@@ -437,13 +458,14 @@ class CfnLifecyclePolicy(
                 self._values["interval_unit"] = interval_unit
 
         @builtins.property
-        def availability_zones(self) -> typing.Optional[typing.List[str]]:
+        def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnLifecyclePolicy.FastRestoreRuleProperty.AvailabilityZones``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-availabilityzones
             """
-            return self._values.get("availability_zones")
+            result = self._values.get("availability_zones")
+            return result
 
         @builtins.property
         def count(self) -> typing.Optional[jsii.Number]:
@@ -452,7 +474,8 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-count
             """
-            return self._values.get("count")
+            result = self._values.get("count")
+            return result
 
         @builtins.property
         def interval(self) -> typing.Optional[jsii.Number]:
@@ -461,21 +484,23 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-interval
             """
-            return self._values.get("interval")
+            result = self._values.get("interval")
+            return result
 
         @builtins.property
-        def interval_unit(self) -> typing.Optional[str]:
+        def interval_unit(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.FastRestoreRuleProperty.IntervalUnit``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-intervalunit
             """
-            return self._values.get("interval_unit")
+            result = self._values.get("interval_unit")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -492,7 +517,7 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            exclude_boot_volume: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            exclude_boot_volume: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param exclude_boot_volume: ``CfnLifecyclePolicy.ParametersProperty.ExcludeBootVolume``.
@@ -500,25 +525,26 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-parameters.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if exclude_boot_volume is not None:
                 self._values["exclude_boot_volume"] = exclude_boot_volume
 
         @builtins.property
         def exclude_boot_volume(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ParametersProperty.ExcludeBootVolume``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-parameters.html#cfn-dlm-lifecyclepolicy-parameters-excludebootvolume
             """
-            return self._values.get("exclude_boot_volume")
+            result = self._values.get("exclude_boot_volume")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -541,11 +567,11 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            resource_types: typing.List[str],
+            resource_types: typing.List[builtins.str],
             schedules: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.ScheduleProperty", _IResolvable_9ceae33e]]],
             target_tags: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]],
             parameters: typing.Optional[typing.Union["CfnLifecyclePolicy.ParametersProperty", _IResolvable_9ceae33e]] = None,
-            policy_type: typing.Optional[str] = None,
+            policy_type: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param resource_types: ``CfnLifecyclePolicy.PolicyDetailsProperty.ResourceTypes``.
@@ -557,7 +583,7 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "resource_types": resource_types,
                 "schedules": schedules,
                 "target_tags": target_tags,
@@ -568,13 +594,15 @@ class CfnLifecyclePolicy(
                 self._values["policy_type"] = policy_type
 
         @builtins.property
-        def resource_types(self) -> typing.List[str]:
+        def resource_types(self) -> typing.List[builtins.str]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.ResourceTypes``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-resourcetypes
             """
-            return self._values.get("resource_types")
+            result = self._values.get("resource_types")
+            assert result is not None, "Required property 'resource_types' is missing"
+            return result
 
         @builtins.property
         def schedules(
@@ -585,7 +613,9 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-schedules
             """
-            return self._values.get("schedules")
+            result = self._values.get("schedules")
+            assert result is not None, "Required property 'schedules' is missing"
+            return result
 
         @builtins.property
         def target_tags(
@@ -596,7 +626,9 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-targettags
             """
-            return self._values.get("target_tags")
+            result = self._values.get("target_tags")
+            assert result is not None, "Required property 'target_tags' is missing"
+            return result
 
         @builtins.property
         def parameters(
@@ -607,21 +639,23 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-parameters
             """
-            return self._values.get("parameters")
+            result = self._values.get("parameters")
+            return result
 
         @builtins.property
-        def policy_type(self) -> typing.Optional[str]:
+        def policy_type(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.PolicyType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-policytype
             """
-            return self._values.get("policy_type")
+            result = self._values.get("policy_type")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -644,7 +678,7 @@ class CfnLifecyclePolicy(
             *,
             count: typing.Optional[jsii.Number] = None,
             interval: typing.Optional[jsii.Number] = None,
-            interval_unit: typing.Optional[str] = None,
+            interval_unit: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param count: ``CfnLifecyclePolicy.RetainRuleProperty.Count``.
@@ -654,7 +688,7 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if count is not None:
                 self._values["count"] = count
             if interval is not None:
@@ -669,7 +703,8 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html#cfn-dlm-lifecyclepolicy-retainrule-count
             """
-            return self._values.get("count")
+            result = self._values.get("count")
+            return result
 
         @builtins.property
         def interval(self) -> typing.Optional[jsii.Number]:
@@ -678,21 +713,23 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html#cfn-dlm-lifecyclepolicy-retainrule-interval
             """
-            return self._values.get("interval")
+            result = self._values.get("interval")
+            return result
 
         @builtins.property
-        def interval_unit(self) -> typing.Optional[str]:
+        def interval_unit(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.RetainRuleProperty.IntervalUnit``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html#cfn-dlm-lifecyclepolicy-retainrule-intervalunit
             """
-            return self._values.get("interval_unit")
+            result = self._values.get("interval_unit")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -718,11 +755,11 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            copy_tags: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            copy_tags: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
             create_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.CreateRuleProperty", _IResolvable_9ceae33e]] = None,
             cross_region_copy_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRuleProperty", _IResolvable_9ceae33e]]]] = None,
             fast_restore_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.FastRestoreRuleProperty", _IResolvable_9ceae33e]] = None,
-            name: typing.Optional[str] = None,
+            name: typing.Optional[builtins.str] = None,
             retain_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.RetainRuleProperty", _IResolvable_9ceae33e]] = None,
             tags_to_add: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
             variable_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
@@ -740,7 +777,7 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if copy_tags is not None:
                 self._values["copy_tags"] = copy_tags
             if create_rule is not None:
@@ -761,13 +798,14 @@ class CfnLifecyclePolicy(
         @builtins.property
         def copy_tags(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.CopyTags``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-copytags
             """
-            return self._values.get("copy_tags")
+            result = self._values.get("copy_tags")
+            return result
 
         @builtins.property
         def create_rule(
@@ -778,7 +816,8 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-createrule
             """
-            return self._values.get("create_rule")
+            result = self._values.get("create_rule")
+            return result
 
         @builtins.property
         def cross_region_copy_rules(
@@ -789,7 +828,8 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-crossregioncopyrules
             """
-            return self._values.get("cross_region_copy_rules")
+            result = self._values.get("cross_region_copy_rules")
+            return result
 
         @builtins.property
         def fast_restore_rule(
@@ -800,16 +840,18 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-fastrestorerule
             """
-            return self._values.get("fast_restore_rule")
+            result = self._values.get("fast_restore_rule")
+            return result
 
         @builtins.property
-        def name(self) -> typing.Optional[str]:
+        def name(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.ScheduleProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            return result
 
         @builtins.property
         def retain_rule(
@@ -820,7 +862,8 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-retainrule
             """
-            return self._values.get("retain_rule")
+            result = self._values.get("retain_rule")
+            return result
 
         @builtins.property
         def tags_to_add(
@@ -831,7 +874,8 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-tagstoadd
             """
-            return self._values.get("tags_to_add")
+            result = self._values.get("tags_to_add")
+            return result
 
         @builtins.property
         def variable_tags(
@@ -842,12 +886,13 @@ class CfnLifecyclePolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-variabletags
             """
-            return self._values.get("variable_tags")
+            result = self._values.get("variable_tags")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -870,10 +915,10 @@ class CfnLifecyclePolicyProps:
     def __init__(
         self,
         *,
-        description: typing.Optional[str] = None,
-        execution_role_arn: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        execution_role_arn: typing.Optional[builtins.str] = None,
         policy_details: typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]] = None,
-        state: typing.Optional[str] = None,
+        state: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DLM::LifecyclePolicy``.
 
@@ -885,7 +930,7 @@ class CfnLifecyclePolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if description is not None:
             self._values["description"] = description
         if execution_role_arn is not None:
@@ -896,22 +941,24 @@ class CfnLifecyclePolicyProps:
             self._values["state"] = state
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def execution_role_arn(self) -> typing.Optional[str]:
+    def execution_role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.ExecutionRoleArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-executionrolearn
         """
-        return self._values.get("execution_role_arn")
+        result = self._values.get("execution_role_arn")
+        return result
 
     @builtins.property
     def policy_details(
@@ -922,21 +969,23 @@ class CfnLifecyclePolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-policydetails
         """
-        return self._values.get("policy_details")
+        result = self._values.get("policy_details")
+        return result
 
     @builtins.property
-    def state(self) -> typing.Optional[str]:
+    def state(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.State``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-state
         """
-        return self._values.get("state")
+        result = self._values.get("state")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
