@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -1360,7 +1361,7 @@ class RepositoryBase(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         account: typing.Optional[builtins.str] = None,
