@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
@@ -2284,7 +2285,7 @@ class AccessPoint(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         file_system: "IFileSystem",
@@ -2316,7 +2317,7 @@ class AccessPoint(
     @builtins.classmethod
     def from_access_point_id(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         access_point_id: builtins.str,
     ) -> "IAccessPoint":
@@ -2388,7 +2389,7 @@ class FileSystem(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         vpc: _IVpc_3795853f,
@@ -2442,7 +2443,7 @@ class FileSystem(
     @builtins.classmethod
     def from_file_system_attributes(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         file_system_id: builtins.str,
