@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,10 +36,10 @@ class CfnNotificationChannel(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        sns_role_name: str,
-        sns_topic_arn: str,
+        sns_role_name: builtins.str,
+        sns_topic_arn: builtins.str,
     ) -> None:
         """Create a new ``AWS::FMS::NotificationChannel``.
 
@@ -67,27 +67,28 @@ class CfnNotificationChannel(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="snsRoleName")
-    def sns_role_name(self) -> str:
+    def sns_role_name(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsRoleName``.
 
         see
@@ -95,13 +96,13 @@ class CfnNotificationChannel(
         """
         return jsii.get(self, "snsRoleName")
 
-    @sns_role_name.setter
-    def sns_role_name(self, value: str) -> None:
+    @sns_role_name.setter # type: ignore
+    def sns_role_name(self, value: builtins.str) -> None:
         jsii.set(self, "snsRoleName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="snsTopicArn")
-    def sns_topic_arn(self) -> str:
+    def sns_topic_arn(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsTopicArn``.
 
         see
@@ -109,8 +110,8 @@ class CfnNotificationChannel(
         """
         return jsii.get(self, "snsTopicArn")
 
-    @sns_topic_arn.setter
-    def sns_topic_arn(self, value: str) -> None:
+    @sns_topic_arn.setter # type: ignore
+    def sns_topic_arn(self, value: builtins.str) -> None:
         jsii.set(self, "snsTopicArn", value)
 
 
@@ -120,7 +121,12 @@ class CfnNotificationChannel(
     name_mapping={"sns_role_name": "snsRoleName", "sns_topic_arn": "snsTopicArn"},
 )
 class CfnNotificationChannelProps:
-    def __init__(self, *, sns_role_name: str, sns_topic_arn: str) -> None:
+    def __init__(
+        self,
+        *,
+        sns_role_name: builtins.str,
+        sns_topic_arn: builtins.str,
+    ) -> None:
         """Properties for defining a ``AWS::FMS::NotificationChannel``.
 
         :param sns_role_name: ``AWS::FMS::NotificationChannel.SnsRoleName``.
@@ -129,33 +135,37 @@ class CfnNotificationChannelProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "sns_role_name": sns_role_name,
             "sns_topic_arn": sns_topic_arn,
         }
 
     @builtins.property
-    def sns_role_name(self) -> str:
+    def sns_role_name(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsRoleName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snsrolename
         """
-        return self._values.get("sns_role_name")
+        result = self._values.get("sns_role_name")
+        assert result is not None, "Required property 'sns_role_name' is missing"
+        return result
 
     @builtins.property
-    def sns_topic_arn(self) -> str:
+    def sns_topic_arn(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsTopicArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snstopicarn
         """
-        return self._values.get("sns_topic_arn")
+        result = self._values.get("sns_topic_arn")
+        assert result is not None, "Required property 'sns_topic_arn' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -181,18 +191,18 @@ class CfnPolicy(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        exclude_resource_tags: typing.Union[bool, _IResolvable_9ceae33e],
-        policy_name: str,
-        remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e],
-        resource_type: str,
+        exclude_resource_tags: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+        policy_name: builtins.str,
+        remediation_enabled: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+        resource_type: builtins.str,
         security_service_policy_data: typing.Any,
-        delete_all_policy_resources: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        delete_all_policy_resources: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         exclude_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]] = None,
         include_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]] = None,
         resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]] = None,
-        resource_type_list: typing.Optional[typing.List[str]] = None,
+        resource_type_list: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List["PolicyTagProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::FMS::Policy``.
@@ -240,45 +250,48 @@ class CfnPolicy(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrId")
-    def attr_id(self) -> str:
+    def attr_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Id
         """
         return jsii.get(self, "attrId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="excludeResourceTags")
-    def exclude_resource_tags(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def exclude_resource_tags(
+        self,
+    ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.ExcludeResourceTags``.
 
         see
@@ -286,15 +299,16 @@ class CfnPolicy(
         """
         return jsii.get(self, "excludeResourceTags")
 
-    @exclude_resource_tags.setter
+    @exclude_resource_tags.setter # type: ignore
     def exclude_resource_tags(
-        self, value: typing.Union[bool, _IResolvable_9ceae33e]
+        self,
+        value: typing.Union[builtins.bool, _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "excludeResourceTags", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="policyName")
-    def policy_name(self) -> str:
+    def policy_name(self) -> builtins.str:
         """``AWS::FMS::Policy.PolicyName``.
 
         see
@@ -302,13 +316,13 @@ class CfnPolicy(
         """
         return jsii.get(self, "policyName")
 
-    @policy_name.setter
-    def policy_name(self, value: str) -> None:
+    @policy_name.setter # type: ignore
+    def policy_name(self, value: builtins.str) -> None:
         jsii.set(self, "policyName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="remediationEnabled")
-    def remediation_enabled(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def remediation_enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.RemediationEnabled``.
 
         see
@@ -316,15 +330,16 @@ class CfnPolicy(
         """
         return jsii.get(self, "remediationEnabled")
 
-    @remediation_enabled.setter
+    @remediation_enabled.setter # type: ignore
     def remediation_enabled(
-        self, value: typing.Union[bool, _IResolvable_9ceae33e]
+        self,
+        value: typing.Union[builtins.bool, _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "remediationEnabled", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceType")
-    def resource_type(self) -> str:
+    def resource_type(self) -> builtins.str:
         """``AWS::FMS::Policy.ResourceType``.
 
         see
@@ -332,11 +347,11 @@ class CfnPolicy(
         """
         return jsii.get(self, "resourceType")
 
-    @resource_type.setter
-    def resource_type(self, value: str) -> None:
+    @resource_type.setter # type: ignore
+    def resource_type(self, value: builtins.str) -> None:
         jsii.set(self, "resourceType", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="securityServicePolicyData")
     def security_service_policy_data(self) -> typing.Any:
         """``AWS::FMS::Policy.SecurityServicePolicyData``.
@@ -346,15 +361,15 @@ class CfnPolicy(
         """
         return jsii.get(self, "securityServicePolicyData")
 
-    @security_service_policy_data.setter
+    @security_service_policy_data.setter # type: ignore
     def security_service_policy_data(self, value: typing.Any) -> None:
         jsii.set(self, "securityServicePolicyData", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deleteAllPolicyResources")
     def delete_all_policy_resources(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.DeleteAllPolicyResources``.
 
         see
@@ -362,13 +377,14 @@ class CfnPolicy(
         """
         return jsii.get(self, "deleteAllPolicyResources")
 
-    @delete_all_policy_resources.setter
+    @delete_all_policy_resources.setter # type: ignore
     def delete_all_policy_resources(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "deleteAllPolicyResources", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="excludeMap")
     def exclude_map(
         self,
@@ -380,14 +396,14 @@ class CfnPolicy(
         """
         return jsii.get(self, "excludeMap")
 
-    @exclude_map.setter
+    @exclude_map.setter # type: ignore
     def exclude_map(
         self,
         value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "excludeMap", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="includeMap")
     def include_map(
         self,
@@ -399,14 +415,14 @@ class CfnPolicy(
         """
         return jsii.get(self, "includeMap")
 
-    @include_map.setter
+    @include_map.setter # type: ignore
     def include_map(
         self,
         value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "includeMap", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceTags")
     def resource_tags(
         self,
@@ -418,16 +434,16 @@ class CfnPolicy(
         """
         return jsii.get(self, "resourceTags")
 
-    @resource_tags.setter
+    @resource_tags.setter # type: ignore
     def resource_tags(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "resourceTags", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceTypeList")
-    def resource_type_list(self) -> typing.Optional[typing.List[str]]:
+    def resource_type_list(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::FMS::Policy.ResourceTypeList``.
 
         see
@@ -435,11 +451,14 @@ class CfnPolicy(
         """
         return jsii.get(self, "resourceTypeList")
 
-    @resource_type_list.setter
-    def resource_type_list(self, value: typing.Optional[typing.List[str]]) -> None:
+    @resource_type_list.setter # type: ignore
+    def resource_type_list(
+        self,
+        value: typing.Optional[typing.List[builtins.str]],
+    ) -> None:
         jsii.set(self, "resourceTypeList", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Optional[typing.List["PolicyTagProperty"]]:
         """``AWS::FMS::Policy.Tags``.
@@ -449,12 +468,12 @@ class CfnPolicy(
         """
         return jsii.get(self, "tags")
 
-    @tags.setter
+    @tags.setter # type: ignore
     def tags(self, value: typing.Optional[typing.List["PolicyTagProperty"]]) -> None:
         jsii.set(self, "tags", value)
 
     @jsii.interface(jsii_type="monocdk-experiment.aws_fms.CfnPolicy.IEMapProperty")
-    class IEMapProperty(jsii.compat.Protocol):
+    class IEMapProperty(typing_extensions.Protocol):
         """
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html
@@ -464,9 +483,9 @@ class CfnPolicy(
         def __jsii_proxy_class__():
             return _IEMapPropertyProxy
 
-        @builtins.property
+        @builtins.property # type: ignore
         @jsii.member(jsii_name="account")
-        def account(self) -> typing.Optional[typing.List[str]]:
+        def account(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ACCOUNT``.
 
             see
@@ -474,9 +493,9 @@ class CfnPolicy(
             """
             ...
 
-        @builtins.property
+        @builtins.property # type: ignore
         @jsii.member(jsii_name="orgunit")
-        def orgunit(self) -> typing.Optional[typing.List[str]]:
+        def orgunit(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ORGUNIT``.
 
             see
@@ -491,11 +510,11 @@ class CfnPolicy(
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html
         """
 
-        __jsii_type__ = "monocdk-experiment.aws_fms.CfnPolicy.IEMapProperty"
+        __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_fms.CfnPolicy.IEMapProperty"
 
-        @builtins.property
+        @builtins.property # type: ignore
         @jsii.member(jsii_name="account")
-        def account(self) -> typing.Optional[typing.List[str]]:
+        def account(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ACCOUNT``.
 
             see
@@ -503,9 +522,9 @@ class CfnPolicy(
             """
             return jsii.get(self, "account")
 
-        @builtins.property
+        @builtins.property # type: ignore
         @jsii.member(jsii_name="orgunit")
-        def orgunit(self) -> typing.Optional[typing.List[str]]:
+        def orgunit(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ORGUNIT``.
 
             see
@@ -519,7 +538,7 @@ class CfnPolicy(
         name_mapping={"key": "key", "value": "value"},
     )
     class PolicyTagProperty:
-        def __init__(self, *, key: str, value: str) -> None:
+        def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
             """
             :param key: ``CfnPolicy.PolicyTagProperty.Key``.
             :param value: ``CfnPolicy.PolicyTagProperty.Value``.
@@ -527,33 +546,37 @@ class CfnPolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "value": value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPolicy.PolicyTagProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html#cfn-fms-policy-policytag-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def value(self) -> str:
+        def value(self) -> builtins.str:
             """``CfnPolicy.PolicyTagProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html#cfn-fms-policy-policytag-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            assert result is not None, "Required property 'value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -567,7 +590,12 @@ class CfnPolicy(
         name_mapping={"key": "key", "value": "value"},
     )
     class ResourceTagProperty:
-        def __init__(self, *, key: str, value: typing.Optional[str] = None) -> None:
+        def __init__(
+            self,
+            *,
+            key: builtins.str,
+            value: typing.Optional[builtins.str] = None,
+        ) -> None:
             """
             :param key: ``CfnPolicy.ResourceTagProperty.Key``.
             :param value: ``CfnPolicy.ResourceTagProperty.Value``.
@@ -575,34 +603,37 @@ class CfnPolicy(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
             }
             if value is not None:
                 self._values["value"] = value
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPolicy.ResourceTagProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html#cfn-fms-policy-resourcetag-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def value(self) -> typing.Optional[str]:
+        def value(self) -> typing.Optional[builtins.str]:
             """``CfnPolicy.ResourceTagProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html#cfn-fms-policy-resourcetag-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -632,16 +663,16 @@ class CfnPolicyProps:
     def __init__(
         self,
         *,
-        exclude_resource_tags: typing.Union[bool, _IResolvable_9ceae33e],
-        policy_name: str,
-        remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e],
-        resource_type: str,
+        exclude_resource_tags: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+        policy_name: builtins.str,
+        remediation_enabled: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+        resource_type: builtins.str,
         security_service_policy_data: typing.Any,
-        delete_all_policy_resources: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        delete_all_policy_resources: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         exclude_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
         include_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
         resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]] = None,
-        resource_type_list: typing.Optional[typing.List[str]] = None,
+        resource_type_list: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::FMS::Policy``.
@@ -661,7 +692,7 @@ class CfnPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "exclude_resource_tags": exclude_resource_tags,
             "policy_name": policy_name,
             "remediation_enabled": remediation_enabled,
@@ -682,40 +713,50 @@ class CfnPolicyProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def exclude_resource_tags(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def exclude_resource_tags(
+        self,
+    ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.ExcludeResourceTags``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excluderesourcetags
         """
-        return self._values.get("exclude_resource_tags")
+        result = self._values.get("exclude_resource_tags")
+        assert result is not None, "Required property 'exclude_resource_tags' is missing"
+        return result
 
     @builtins.property
-    def policy_name(self) -> str:
+    def policy_name(self) -> builtins.str:
         """``AWS::FMS::Policy.PolicyName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-policyname
         """
-        return self._values.get("policy_name")
+        result = self._values.get("policy_name")
+        assert result is not None, "Required property 'policy_name' is missing"
+        return result
 
     @builtins.property
-    def remediation_enabled(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def remediation_enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.RemediationEnabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-remediationenabled
         """
-        return self._values.get("remediation_enabled")
+        result = self._values.get("remediation_enabled")
+        assert result is not None, "Required property 'remediation_enabled' is missing"
+        return result
 
     @builtins.property
-    def resource_type(self) -> str:
+    def resource_type(self) -> builtins.str:
         """``AWS::FMS::Policy.ResourceType``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetype
         """
-        return self._values.get("resource_type")
+        result = self._values.get("resource_type")
+        assert result is not None, "Required property 'resource_type' is missing"
+        return result
 
     @builtins.property
     def security_service_policy_data(self) -> typing.Any:
@@ -724,18 +765,21 @@ class CfnPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-securityservicepolicydata
         """
-        return self._values.get("security_service_policy_data")
+        result = self._values.get("security_service_policy_data")
+        assert result is not None, "Required property 'security_service_policy_data' is missing"
+        return result
 
     @builtins.property
     def delete_all_policy_resources(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.DeleteAllPolicyResources``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-deleteallpolicyresources
         """
-        return self._values.get("delete_all_policy_resources")
+        result = self._values.get("delete_all_policy_resources")
+        return result
 
     @builtins.property
     def exclude_map(
@@ -746,7 +790,8 @@ class CfnPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excludemap
         """
-        return self._values.get("exclude_map")
+        result = self._values.get("exclude_map")
+        return result
 
     @builtins.property
     def include_map(
@@ -757,7 +802,8 @@ class CfnPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-includemap
         """
-        return self._values.get("include_map")
+        result = self._values.get("include_map")
+        return result
 
     @builtins.property
     def resource_tags(
@@ -768,16 +814,18 @@ class CfnPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetags
         """
-        return self._values.get("resource_tags")
+        result = self._values.get("resource_tags")
+        return result
 
     @builtins.property
-    def resource_type_list(self) -> typing.Optional[typing.List[str]]:
+    def resource_type_list(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::FMS::Policy.ResourceTypeList``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetypelist
         """
-        return self._values.get("resource_type_list")
+        result = self._values.get("resource_type_list")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]]:
@@ -786,12 +834,13 @@ class CfnPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
