@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -1731,7 +1732,7 @@ class FileSystemBase(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         account: typing.Optional[builtins.str] = None,
@@ -1851,7 +1852,7 @@ class LustreFileSystem(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         lustre_configuration: "LustreConfiguration",
@@ -1892,7 +1893,7 @@ class LustreFileSystem(
     @builtins.classmethod
     def from_lustre_file_system_attributes(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         dns_name: builtins.str,
