@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,10 +37,10 @@ class CfnAssessmentTarget(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        assessment_target_name: typing.Optional[str] = None,
-        resource_group_arn: typing.Optional[str] = None,
+        assessment_target_name: typing.Optional[builtins.str] = None,
+        resource_group_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTarget``.
 
@@ -69,36 +69,37 @@ class CfnAssessmentTarget(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="assessmentTargetName")
-    def assessment_target_name(self) -> typing.Optional[str]:
+    def assessment_target_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
         see
@@ -106,13 +107,13 @@ class CfnAssessmentTarget(
         """
         return jsii.get(self, "assessmentTargetName")
 
-    @assessment_target_name.setter
-    def assessment_target_name(self, value: typing.Optional[str]) -> None:
+    @assessment_target_name.setter # type: ignore
+    def assessment_target_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "assessmentTargetName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceGroupArn")
-    def resource_group_arn(self) -> typing.Optional[str]:
+    def resource_group_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
         see
@@ -120,8 +121,8 @@ class CfnAssessmentTarget(
         """
         return jsii.get(self, "resourceGroupArn")
 
-    @resource_group_arn.setter
-    def resource_group_arn(self, value: typing.Optional[str]) -> None:
+    @resource_group_arn.setter # type: ignore
+    def resource_group_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "resourceGroupArn", value)
 
 
@@ -137,8 +138,8 @@ class CfnAssessmentTargetProps:
     def __init__(
         self,
         *,
-        assessment_target_name: typing.Optional[str] = None,
-        resource_group_arn: typing.Optional[str] = None,
+        assessment_target_name: typing.Optional[builtins.str] = None,
+        resource_group_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTarget``.
 
@@ -148,34 +149,36 @@ class CfnAssessmentTargetProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if assessment_target_name is not None:
             self._values["assessment_target_name"] = assessment_target_name
         if resource_group_arn is not None:
             self._values["resource_group_arn"] = resource_group_arn
 
     @builtins.property
-    def assessment_target_name(self) -> typing.Optional[str]:
+    def assessment_target_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
         """
-        return self._values.get("assessment_target_name")
+        result = self._values.get("assessment_target_name")
+        return result
 
     @builtins.property
-    def resource_group_arn(self) -> typing.Optional[str]:
+    def resource_group_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
         """
-        return self._values.get("resource_group_arn")
+        result = self._values.get("resource_group_arn")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -201,12 +204,12 @@ class CfnAssessmentTemplate(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        assessment_target_arn: str,
+        assessment_target_arn: builtins.str,
         duration_in_seconds: jsii.Number,
-        rules_package_arns: typing.List[str],
-        assessment_template_name: typing.Optional[str] = None,
+        rules_package_arns: typing.List[builtins.str],
+        assessment_template_name: typing.Optional[builtins.str] = None,
         user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
     ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTemplate``.
@@ -242,36 +245,37 @@ class CfnAssessmentTemplate(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="assessmentTargetArn")
-    def assessment_target_arn(self) -> str:
+    def assessment_target_arn(self) -> builtins.str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
         see
@@ -279,11 +283,11 @@ class CfnAssessmentTemplate(
         """
         return jsii.get(self, "assessmentTargetArn")
 
-    @assessment_target_arn.setter
-    def assessment_target_arn(self, value: str) -> None:
+    @assessment_target_arn.setter # type: ignore
+    def assessment_target_arn(self, value: builtins.str) -> None:
         jsii.set(self, "assessmentTargetArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="durationInSeconds")
     def duration_in_seconds(self) -> jsii.Number:
         """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
@@ -293,13 +297,13 @@ class CfnAssessmentTemplate(
         """
         return jsii.get(self, "durationInSeconds")
 
-    @duration_in_seconds.setter
+    @duration_in_seconds.setter # type: ignore
     def duration_in_seconds(self, value: jsii.Number) -> None:
         jsii.set(self, "durationInSeconds", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="rulesPackageArns")
-    def rules_package_arns(self) -> typing.List[str]:
+    def rules_package_arns(self) -> typing.List[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
         see
@@ -307,13 +311,13 @@ class CfnAssessmentTemplate(
         """
         return jsii.get(self, "rulesPackageArns")
 
-    @rules_package_arns.setter
-    def rules_package_arns(self, value: typing.List[str]) -> None:
+    @rules_package_arns.setter # type: ignore
+    def rules_package_arns(self, value: typing.List[builtins.str]) -> None:
         jsii.set(self, "rulesPackageArns", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="assessmentTemplateName")
-    def assessment_template_name(self) -> typing.Optional[str]:
+    def assessment_template_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
         see
@@ -321,11 +325,11 @@ class CfnAssessmentTemplate(
         """
         return jsii.get(self, "assessmentTemplateName")
 
-    @assessment_template_name.setter
-    def assessment_template_name(self, value: typing.Optional[str]) -> None:
+    @assessment_template_name.setter # type: ignore
+    def assessment_template_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "assessmentTemplateName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="userAttributesForFindings")
     def user_attributes_for_findings(
         self,
@@ -337,7 +341,7 @@ class CfnAssessmentTemplate(
         """
         return jsii.get(self, "userAttributesForFindings")
 
-    @user_attributes_for_findings.setter
+    @user_attributes_for_findings.setter # type: ignore
     def user_attributes_for_findings(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]],
@@ -360,10 +364,10 @@ class CfnAssessmentTemplateProps:
     def __init__(
         self,
         *,
-        assessment_target_arn: str,
+        assessment_target_arn: builtins.str,
         duration_in_seconds: jsii.Number,
-        rules_package_arns: typing.List[str],
-        assessment_template_name: typing.Optional[str] = None,
+        rules_package_arns: typing.List[builtins.str],
+        assessment_template_name: typing.Optional[builtins.str] = None,
         user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
@@ -377,7 +381,7 @@ class CfnAssessmentTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "assessment_target_arn": assessment_target_arn,
             "duration_in_seconds": duration_in_seconds,
             "rules_package_arns": rules_package_arns,
@@ -388,13 +392,15 @@ class CfnAssessmentTemplateProps:
             self._values["user_attributes_for_findings"] = user_attributes_for_findings
 
     @builtins.property
-    def assessment_target_arn(self) -> str:
+    def assessment_target_arn(self) -> builtins.str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
         """
-        return self._values.get("assessment_target_arn")
+        result = self._values.get("assessment_target_arn")
+        assert result is not None, "Required property 'assessment_target_arn' is missing"
+        return result
 
     @builtins.property
     def duration_in_seconds(self) -> jsii.Number:
@@ -403,25 +409,30 @@ class CfnAssessmentTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
         """
-        return self._values.get("duration_in_seconds")
+        result = self._values.get("duration_in_seconds")
+        assert result is not None, "Required property 'duration_in_seconds' is missing"
+        return result
 
     @builtins.property
-    def rules_package_arns(self) -> typing.List[str]:
+    def rules_package_arns(self) -> typing.List[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
         """
-        return self._values.get("rules_package_arns")
+        result = self._values.get("rules_package_arns")
+        assert result is not None, "Required property 'rules_package_arns' is missing"
+        return result
 
     @builtins.property
-    def assessment_template_name(self) -> typing.Optional[str]:
+    def assessment_template_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
         """
-        return self._values.get("assessment_template_name")
+        result = self._values.get("assessment_template_name")
+        return result
 
     @builtins.property
     def user_attributes_for_findings(
@@ -432,12 +443,13 @@ class CfnAssessmentTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
         """
-        return self._values.get("user_attributes_for_findings")
+        result = self._values.get("user_attributes_for_findings")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -463,7 +475,7 @@ class CfnResourceGroup(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         resource_group_tags: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]],
     ) -> None:
@@ -490,34 +502,35 @@ class CfnResourceGroup(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceGroupTags")
     def resource_group_tags(
         self,
@@ -529,7 +542,7 @@ class CfnResourceGroup(
         """
         return jsii.get(self, "resourceGroupTags")
 
-    @resource_group_tags.setter
+    @resource_group_tags.setter # type: ignore
     def resource_group_tags(
         self,
         value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]],
@@ -555,7 +568,7 @@ class CfnResourceGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "resource_group_tags": resource_group_tags,
         }
 
@@ -568,12 +581,14 @@ class CfnResourceGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
         """
-        return self._values.get("resource_group_tags")
+        result = self._values.get("resource_group_tags")
+        assert result is not None, "Required property 'resource_group_tags' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
