@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,10 +36,10 @@ class CfnDevice(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        device_id: str,
-        enabled: typing.Union[bool, _IResolvable_9ceae33e],
+        device_id: builtins.str,
+        enabled: typing.Union[builtins.bool, _IResolvable_9ceae33e],
     ) -> None:
         """Create a new ``AWS::IoT1Click::Device``.
 
@@ -65,38 +65,39 @@ class CfnDevice(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrDeviceId")
-    def attr_device_id(self) -> str:
+    def attr_device_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: DeviceId
         """
         return jsii.get(self, "attrDeviceId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrEnabled")
     def attr_enabled(self) -> _IResolvable_9ceae33e:
         """
@@ -105,14 +106,14 @@ class CfnDevice(
         """
         return jsii.get(self, "attrEnabled")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deviceId")
-    def device_id(self) -> str:
+    def device_id(self) -> builtins.str:
         """``AWS::IoT1Click::Device.DeviceId``.
 
         see
@@ -120,13 +121,13 @@ class CfnDevice(
         """
         return jsii.get(self, "deviceId")
 
-    @device_id.setter
-    def device_id(self, value: str) -> None:
+    @device_id.setter # type: ignore
+    def device_id(self, value: builtins.str) -> None:
         jsii.set(self, "deviceId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="enabled")
-    def enabled(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Device.Enabled``.
 
         see
@@ -134,8 +135,11 @@ class CfnDevice(
         """
         return jsii.get(self, "enabled")
 
-    @enabled.setter
-    def enabled(self, value: typing.Union[bool, _IResolvable_9ceae33e]) -> None:
+    @enabled.setter # type: ignore
+    def enabled(
+        self,
+        value: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+    ) -> None:
         jsii.set(self, "enabled", value)
 
 
@@ -146,7 +150,10 @@ class CfnDevice(
 )
 class CfnDeviceProps:
     def __init__(
-        self, *, device_id: str, enabled: typing.Union[bool, _IResolvable_9ceae33e]
+        self,
+        *,
+        device_id: builtins.str,
+        enabled: typing.Union[builtins.bool, _IResolvable_9ceae33e],
     ) -> None:
         """Properties for defining a ``AWS::IoT1Click::Device``.
 
@@ -156,33 +163,37 @@ class CfnDeviceProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "device_id": device_id,
             "enabled": enabled,
         }
 
     @builtins.property
-    def device_id(self) -> str:
+    def device_id(self) -> builtins.str:
         """``AWS::IoT1Click::Device.DeviceId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-deviceid
         """
-        return self._values.get("device_id")
+        result = self._values.get("device_id")
+        assert result is not None, "Required property 'device_id' is missing"
+        return result
 
     @builtins.property
-    def enabled(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Device.Enabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-enabled
         """
-        return self._values.get("enabled")
+        result = self._values.get("enabled")
+        assert result is not None, "Required property 'enabled' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -208,12 +219,12 @@ class CfnPlacement(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        project_name: str,
+        project_name: builtins.str,
         associated_devices: typing.Any = None,
         attributes: typing.Any = None,
-        placement_name: typing.Optional[str] = None,
+        placement_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::IoT1Click::Placement``.
 
@@ -246,43 +257,44 @@ class CfnPlacement(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrPlacementName")
-    def attr_placement_name(self) -> str:
+    def attr_placement_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: PlacementName
         """
         return jsii.get(self, "attrPlacementName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrProjectName")
-    def attr_project_name(self) -> str:
+    def attr_project_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ProjectName
         """
         return jsii.get(self, "attrProjectName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="associatedDevices")
     def associated_devices(self) -> typing.Any:
         """``AWS::IoT1Click::Placement.AssociatedDevices``.
@@ -292,11 +304,11 @@ class CfnPlacement(
         """
         return jsii.get(self, "associatedDevices")
 
-    @associated_devices.setter
+    @associated_devices.setter # type: ignore
     def associated_devices(self, value: typing.Any) -> None:
         jsii.set(self, "associatedDevices", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attributes")
     def attributes(self) -> typing.Any:
         """``AWS::IoT1Click::Placement.Attributes``.
@@ -306,13 +318,13 @@ class CfnPlacement(
         """
         return jsii.get(self, "attributes")
 
-    @attributes.setter
+    @attributes.setter # type: ignore
     def attributes(self, value: typing.Any) -> None:
         jsii.set(self, "attributes", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="projectName")
-    def project_name(self) -> str:
+    def project_name(self) -> builtins.str:
         """``AWS::IoT1Click::Placement.ProjectName``.
 
         see
@@ -320,13 +332,13 @@ class CfnPlacement(
         """
         return jsii.get(self, "projectName")
 
-    @project_name.setter
-    def project_name(self, value: str) -> None:
+    @project_name.setter # type: ignore
+    def project_name(self, value: builtins.str) -> None:
         jsii.set(self, "projectName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="placementName")
-    def placement_name(self) -> typing.Optional[str]:
+    def placement_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Placement.PlacementName``.
 
         see
@@ -334,8 +346,8 @@ class CfnPlacement(
         """
         return jsii.get(self, "placementName")
 
-    @placement_name.setter
-    def placement_name(self, value: typing.Optional[str]) -> None:
+    @placement_name.setter # type: ignore
+    def placement_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "placementName", value)
 
 
@@ -353,10 +365,10 @@ class CfnPlacementProps:
     def __init__(
         self,
         *,
-        project_name: str,
+        project_name: builtins.str,
         associated_devices: typing.Any = None,
         attributes: typing.Any = None,
-        placement_name: typing.Optional[str] = None,
+        placement_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::IoT1Click::Placement``.
 
@@ -368,7 +380,7 @@ class CfnPlacementProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "project_name": project_name,
         }
         if associated_devices is not None:
@@ -379,13 +391,15 @@ class CfnPlacementProps:
             self._values["placement_name"] = placement_name
 
     @builtins.property
-    def project_name(self) -> str:
+    def project_name(self) -> builtins.str:
         """``AWS::IoT1Click::Placement.ProjectName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-projectname
         """
-        return self._values.get("project_name")
+        result = self._values.get("project_name")
+        assert result is not None, "Required property 'project_name' is missing"
+        return result
 
     @builtins.property
     def associated_devices(self) -> typing.Any:
@@ -394,7 +408,8 @@ class CfnPlacementProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-associateddevices
         """
-        return self._values.get("associated_devices")
+        result = self._values.get("associated_devices")
+        return result
 
     @builtins.property
     def attributes(self) -> typing.Any:
@@ -403,21 +418,23 @@ class CfnPlacementProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-attributes
         """
-        return self._values.get("attributes")
+        result = self._values.get("attributes")
+        return result
 
     @builtins.property
-    def placement_name(self) -> typing.Optional[str]:
+    def placement_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Placement.PlacementName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-placementname
         """
-        return self._values.get("placement_name")
+        result = self._values.get("placement_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -443,11 +460,11 @@ class CfnProject(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         placement_template: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e],
-        description: typing.Optional[str] = None,
-        project_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        project_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::IoT1Click::Project``.
 
@@ -478,43 +495,44 @@ class CfnProject(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrProjectName")
-    def attr_project_name(self) -> str:
+    def attr_project_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ProjectName
         """
         return jsii.get(self, "attrProjectName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="placementTemplate")
     def placement_template(
         self,
@@ -526,15 +544,16 @@ class CfnProject(
         """
         return jsii.get(self, "placementTemplate")
 
-    @placement_template.setter
+    @placement_template.setter # type: ignore
     def placement_template(
-        self, value: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "placementTemplate", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.Description``.
 
         see
@@ -542,13 +561,13 @@ class CfnProject(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="projectName")
-    def project_name(self) -> typing.Optional[str]:
+    def project_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.ProjectName``.
 
         see
@@ -556,8 +575,8 @@ class CfnProject(
         """
         return jsii.get(self, "projectName")
 
-    @project_name.setter
-    def project_name(self, value: typing.Optional[str]) -> None:
+    @project_name.setter # type: ignore
+    def project_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "projectName", value)
 
     @jsii.data_type(
@@ -573,7 +592,7 @@ class CfnProject(
             self,
             *,
             callback_overrides: typing.Any = None,
-            device_type: typing.Optional[str] = None,
+            device_type: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param callback_overrides: ``CfnProject.DeviceTemplateProperty.CallbackOverrides``.
@@ -582,7 +601,7 @@ class CfnProject(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if callback_overrides is not None:
                 self._values["callback_overrides"] = callback_overrides
             if device_type is not None:
@@ -595,21 +614,23 @@ class CfnProject(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html#cfn-iot1click-project-devicetemplate-callbackoverrides
             """
-            return self._values.get("callback_overrides")
+            result = self._values.get("callback_overrides")
+            return result
 
         @builtins.property
-        def device_type(self) -> typing.Optional[str]:
+        def device_type(self) -> typing.Optional[builtins.str]:
             """``CfnProject.DeviceTemplateProperty.DeviceType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html#cfn-iot1click-project-devicetemplate-devicetype
             """
-            return self._values.get("device_type")
+            result = self._values.get("device_type")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -630,7 +651,7 @@ class CfnProject(
             self,
             *,
             default_attributes: typing.Any = None,
-            device_templates: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]] = None,
+            device_templates: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]] = None,
         ) -> None:
             """
             :param default_attributes: ``CfnProject.PlacementTemplateProperty.DefaultAttributes``.
@@ -639,7 +660,7 @@ class CfnProject(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if default_attributes is not None:
                 self._values["default_attributes"] = default_attributes
             if device_templates is not None:
@@ -652,23 +673,25 @@ class CfnProject(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html#cfn-iot1click-project-placementtemplate-defaultattributes
             """
-            return self._values.get("default_attributes")
+            result = self._values.get("default_attributes")
+            return result
 
         @builtins.property
         def device_templates(
             self,
-        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]]:
             """``CfnProject.PlacementTemplateProperty.DeviceTemplates``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html#cfn-iot1click-project-placementtemplate-devicetemplates
             """
-            return self._values.get("device_templates")
+            result = self._values.get("device_templates")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -691,8 +714,8 @@ class CfnProjectProps:
         self,
         *,
         placement_template: typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e],
-        description: typing.Optional[str] = None,
-        project_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        project_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::IoT1Click::Project``.
 
@@ -703,7 +726,7 @@ class CfnProjectProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "placement_template": placement_template,
         }
         if description is not None:
@@ -720,30 +743,34 @@ class CfnProjectProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-placementtemplate
         """
-        return self._values.get("placement_template")
+        result = self._values.get("placement_template")
+        assert result is not None, "Required property 'placement_template' is missing"
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def project_name(self) -> typing.Optional[str]:
+    def project_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.ProjectName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-projectname
         """
-        return self._values.get("project_name")
+        result = self._values.get("project_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
