@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,7 +36,7 @@ class CfnFlowTemplate(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         definition: typing.Union["DefinitionDocumentProperty", _IResolvable_9ceae33e],
         compatible_namespace_version: typing.Optional[jsii.Number] = None,
@@ -68,25 +68,26 @@ class CfnFlowTemplate(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="definition")
     def definition(
         self,
@@ -98,13 +99,14 @@ class CfnFlowTemplate(
         """
         return jsii.get(self, "definition")
 
-    @definition.setter
+    @definition.setter # type: ignore
     def definition(
-        self, value: typing.Union["DefinitionDocumentProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["DefinitionDocumentProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "definition", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="compatibleNamespaceVersion")
     def compatible_namespace_version(self) -> typing.Optional[jsii.Number]:
         """``AWS::IoTThingsGraph::FlowTemplate.CompatibleNamespaceVersion``.
@@ -114,7 +116,7 @@ class CfnFlowTemplate(
         """
         return jsii.get(self, "compatibleNamespaceVersion")
 
-    @compatible_namespace_version.setter
+    @compatible_namespace_version.setter # type: ignore
     def compatible_namespace_version(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "compatibleNamespaceVersion", value)
 
@@ -124,7 +126,7 @@ class CfnFlowTemplate(
         name_mapping={"language": "language", "text": "text"},
     )
     class DefinitionDocumentProperty:
-        def __init__(self, *, language: str, text: str) -> None:
+        def __init__(self, *, language: builtins.str, text: builtins.str) -> None:
             """
             :param language: ``CfnFlowTemplate.DefinitionDocumentProperty.Language``.
             :param text: ``CfnFlowTemplate.DefinitionDocumentProperty.Text``.
@@ -132,33 +134,37 @@ class CfnFlowTemplate(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotthingsgraph-flowtemplate-definitiondocument.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "language": language,
                 "text": text,
             }
 
         @builtins.property
-        def language(self) -> str:
+        def language(self) -> builtins.str:
             """``CfnFlowTemplate.DefinitionDocumentProperty.Language``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotthingsgraph-flowtemplate-definitiondocument.html#cfn-iotthingsgraph-flowtemplate-definitiondocument-language
             """
-            return self._values.get("language")
+            result = self._values.get("language")
+            assert result is not None, "Required property 'language' is missing"
+            return result
 
         @builtins.property
-        def text(self) -> str:
+        def text(self) -> builtins.str:
             """``CfnFlowTemplate.DefinitionDocumentProperty.Text``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotthingsgraph-flowtemplate-definitiondocument.html#cfn-iotthingsgraph-flowtemplate-definitiondocument-text
             """
-            return self._values.get("text")
+            result = self._values.get("text")
+            assert result is not None, "Required property 'text' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -190,7 +196,7 @@ class CfnFlowTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotthingsgraph-flowtemplate.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "definition": definition,
         }
         if compatible_namespace_version is not None:
@@ -205,7 +211,9 @@ class CfnFlowTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotthingsgraph-flowtemplate.html#cfn-iotthingsgraph-flowtemplate-definition
         """
-        return self._values.get("definition")
+        result = self._values.get("definition")
+        assert result is not None, "Required property 'definition' is missing"
+        return result
 
     @builtins.property
     def compatible_namespace_version(self) -> typing.Optional[jsii.Number]:
@@ -214,12 +222,13 @@ class CfnFlowTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotthingsgraph-flowtemplate.html#cfn-iotthingsgraph-flowtemplate-compatiblenamespaceversion
         """
-        return self._values.get("compatible_namespace_version")
+        result = self._values.get("compatible_namespace_version")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
