@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -775,7 +776,7 @@ class Stream(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         encryption: typing.Optional["StreamEncryption"] = None,
@@ -810,7 +811,7 @@ class Stream(
     @builtins.classmethod
     def from_stream_arn(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         stream_arn: builtins.str,
     ) -> "IStream":
@@ -829,7 +830,7 @@ class Stream(
     @builtins.classmethod
     def from_stream_attributes(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         stream_arn: builtins.str,
