@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     CfnTag as _CfnTag_b4661f1a,
@@ -919,7 +920,7 @@ class Key(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         alias: typing.Optional[builtins.str] = None,
@@ -960,7 +961,7 @@ class Key(
     @builtins.classmethod
     def from_key_arn(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         key_arn: builtins.str,
     ) -> "IKey":
@@ -1424,7 +1425,7 @@ class Alias(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         alias_name: builtins.str,
@@ -1451,7 +1452,7 @@ class Alias(
     @builtins.classmethod
     def from_alias_attributes(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         alias_name: builtins.str,
@@ -1477,7 +1478,7 @@ class Alias(
     @builtins.classmethod
     def from_alias_name(
         cls,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         alias_name: builtins.str,
     ) -> "IAlias":
