@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,7 +36,7 @@ class CfnDataLakeSettings(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         admins: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
@@ -63,25 +63,26 @@ class CfnDataLakeSettings(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="admins")
     def admins(
         self,
@@ -93,7 +94,7 @@ class CfnDataLakeSettings(
         """
         return jsii.get(self, "admins")
 
-    @admins.setter
+    @admins.setter # type: ignore
     def admins(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]],
@@ -107,7 +108,9 @@ class CfnDataLakeSettings(
     )
     class DataLakePrincipalProperty:
         def __init__(
-            self, *, data_lake_principal_identifier: typing.Optional[str] = None
+            self,
+            *,
+            data_lake_principal_identifier: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param data_lake_principal_identifier: ``CfnDataLakeSettings.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
@@ -115,23 +118,24 @@ class CfnDataLakeSettings(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-datalakesettings-datalakeprincipal.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if data_lake_principal_identifier is not None:
                 self._values["data_lake_principal_identifier"] = data_lake_principal_identifier
 
         @builtins.property
-        def data_lake_principal_identifier(self) -> typing.Optional[str]:
+        def data_lake_principal_identifier(self) -> typing.Optional[builtins.str]:
             """``CfnDataLakeSettings.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-datalakesettings-datalakeprincipal.html#cfn-lakeformation-datalakesettings-datalakeprincipal-datalakeprincipalidentifier
             """
-            return self._values.get("data_lake_principal_identifier")
+            result = self._values.get("data_lake_principal_identifier")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -158,7 +162,7 @@ class CfnDataLakeSettingsProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if admins is not None:
             self._values["admins"] = admins
 
@@ -171,12 +175,13 @@ class CfnDataLakeSettingsProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html#cfn-lakeformation-datalakesettings-admins
         """
-        return self._values.get("admins")
+        result = self._values.get("admins")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -202,12 +207,12 @@ class CfnPermissions(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         data_lake_principal: typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e],
         resource: typing.Union["ResourceProperty", _IResolvable_9ceae33e],
-        permissions: typing.Optional[typing.List[str]] = None,
-        permissions_with_grant_option: typing.Optional[typing.List[str]] = None,
+        permissions: typing.Optional[typing.List[builtins.str]] = None,
+        permissions_with_grant_option: typing.Optional[typing.List[builtins.str]] = None,
     ) -> None:
         """Create a new ``AWS::LakeFormation::Permissions``.
 
@@ -240,25 +245,26 @@ class CfnPermissions(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="dataLakePrincipal")
     def data_lake_principal(
         self,
@@ -270,13 +276,14 @@ class CfnPermissions(
         """
         return jsii.get(self, "dataLakePrincipal")
 
-    @data_lake_principal.setter
+    @data_lake_principal.setter # type: ignore
     def data_lake_principal(
-        self, value: typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "dataLakePrincipal", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resource")
     def resource(self) -> typing.Union["ResourceProperty", _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Permissions.Resource``.
@@ -286,15 +293,16 @@ class CfnPermissions(
         """
         return jsii.get(self, "resource")
 
-    @resource.setter
+    @resource.setter # type: ignore
     def resource(
-        self, value: typing.Union["ResourceProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["ResourceProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "resource", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="permissions")
-    def permissions(self) -> typing.Optional[typing.List[str]]:
+    def permissions(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.Permissions``.
 
         see
@@ -302,13 +310,15 @@ class CfnPermissions(
         """
         return jsii.get(self, "permissions")
 
-    @permissions.setter
-    def permissions(self, value: typing.Optional[typing.List[str]]) -> None:
+    @permissions.setter # type: ignore
+    def permissions(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
         jsii.set(self, "permissions", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="permissionsWithGrantOption")
-    def permissions_with_grant_option(self) -> typing.Optional[typing.List[str]]:
+    def permissions_with_grant_option(
+        self,
+    ) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.PermissionsWithGrantOption``.
 
         see
@@ -316,9 +326,10 @@ class CfnPermissions(
         """
         return jsii.get(self, "permissionsWithGrantOption")
 
-    @permissions_with_grant_option.setter
+    @permissions_with_grant_option.setter # type: ignore
     def permissions_with_grant_option(
-        self, value: typing.Optional[typing.List[str]]
+        self,
+        value: typing.Optional[typing.List[builtins.str]],
     ) -> None:
         jsii.set(self, "permissionsWithGrantOption", value)
 
@@ -329,7 +340,9 @@ class CfnPermissions(
     )
     class ColumnWildcardProperty:
         def __init__(
-            self, *, excluded_column_names: typing.Optional[typing.List[str]] = None
+            self,
+            *,
+            excluded_column_names: typing.Optional[typing.List[builtins.str]] = None,
         ) -> None:
             """
             :param excluded_column_names: ``CfnPermissions.ColumnWildcardProperty.ExcludedColumnNames``.
@@ -337,23 +350,24 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-columnwildcard.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if excluded_column_names is not None:
                 self._values["excluded_column_names"] = excluded_column_names
 
         @builtins.property
-        def excluded_column_names(self) -> typing.Optional[typing.List[str]]:
+        def excluded_column_names(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPermissions.ColumnWildcardProperty.ExcludedColumnNames``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-columnwildcard.html#cfn-lakeformation-permissions-columnwildcard-excludedcolumnnames
             """
-            return self._values.get("excluded_column_names")
+            result = self._values.get("excluded_column_names")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -368,7 +382,9 @@ class CfnPermissions(
     )
     class DataLakePrincipalProperty:
         def __init__(
-            self, *, data_lake_principal_identifier: typing.Optional[str] = None
+            self,
+            *,
+            data_lake_principal_identifier: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param data_lake_principal_identifier: ``CfnPermissions.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
@@ -376,23 +392,24 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalakeprincipal.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if data_lake_principal_identifier is not None:
                 self._values["data_lake_principal_identifier"] = data_lake_principal_identifier
 
         @builtins.property
-        def data_lake_principal_identifier(self) -> typing.Optional[str]:
+        def data_lake_principal_identifier(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalakeprincipal.html#cfn-lakeformation-permissions-datalakeprincipal-datalakeprincipalidentifier
             """
-            return self._values.get("data_lake_principal_identifier")
+            result = self._values.get("data_lake_principal_identifier")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -406,30 +423,35 @@ class CfnPermissions(
         name_mapping={"s3_resource": "s3Resource"},
     )
     class DataLocationResourceProperty:
-        def __init__(self, *, s3_resource: typing.Optional[str] = None) -> None:
+        def __init__(
+            self,
+            *,
+            s3_resource: typing.Optional[builtins.str] = None,
+        ) -> None:
             """
             :param s3_resource: ``CfnPermissions.DataLocationResourceProperty.S3Resource``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalocationresource.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if s3_resource is not None:
                 self._values["s3_resource"] = s3_resource
 
         @builtins.property
-        def s3_resource(self) -> typing.Optional[str]:
+        def s3_resource(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.DataLocationResourceProperty.S3Resource``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalocationresource.html#cfn-lakeformation-permissions-datalocationresource-s3resource
             """
-            return self._values.get("s3_resource")
+            result = self._values.get("s3_resource")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -443,30 +465,31 @@ class CfnPermissions(
         name_mapping={"name": "name"},
     )
     class DatabaseResourceProperty:
-        def __init__(self, *, name: typing.Optional[str] = None) -> None:
+        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
             """
             :param name: ``CfnPermissions.DatabaseResourceProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-databaseresource.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if name is not None:
                 self._values["name"] = name
 
         @builtins.property
-        def name(self) -> typing.Optional[str]:
+        def name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.DatabaseResourceProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-databaseresource.html#cfn-lakeformation-permissions-databaseresource-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -502,7 +525,7 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if database_resource is not None:
                 self._values["database_resource"] = database_resource
             if data_location_resource is not None:
@@ -521,7 +544,8 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-databaseresource
             """
-            return self._values.get("database_resource")
+            result = self._values.get("database_resource")
+            return result
 
         @builtins.property
         def data_location_resource(
@@ -532,7 +556,8 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-datalocationresource
             """
-            return self._values.get("data_location_resource")
+            result = self._values.get("data_location_resource")
+            return result
 
         @builtins.property
         def table_resource(
@@ -543,7 +568,8 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-tableresource
             """
-            return self._values.get("table_resource")
+            result = self._values.get("table_resource")
+            return result
 
         @builtins.property
         def table_with_columns_resource(
@@ -554,12 +580,13 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-tablewithcolumnsresource
             """
-            return self._values.get("table_with_columns_resource")
+            result = self._values.get("table_with_columns_resource")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -576,8 +603,8 @@ class CfnPermissions(
         def __init__(
             self,
             *,
-            database_name: typing.Optional[str] = None,
-            name: typing.Optional[str] = None,
+            database_name: typing.Optional[builtins.str] = None,
+            name: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param database_name: ``CfnPermissions.TableResourceProperty.DatabaseName``.
@@ -586,34 +613,36 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if database_name is not None:
                 self._values["database_name"] = database_name
             if name is not None:
                 self._values["name"] = name
 
         @builtins.property
-        def database_name(self) -> typing.Optional[str]:
+        def database_name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableResourceProperty.DatabaseName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html#cfn-lakeformation-permissions-tableresource-databasename
             """
-            return self._values.get("database_name")
+            result = self._values.get("database_name")
+            return result
 
         @builtins.property
-        def name(self) -> typing.Optional[str]:
+        def name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableResourceProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html#cfn-lakeformation-permissions-tableresource-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -635,10 +664,10 @@ class CfnPermissions(
         def __init__(
             self,
             *,
-            column_names: typing.Optional[typing.List[str]] = None,
+            column_names: typing.Optional[typing.List[builtins.str]] = None,
             column_wildcard: typing.Optional[typing.Union["CfnPermissions.ColumnWildcardProperty", _IResolvable_9ceae33e]] = None,
-            database_name: typing.Optional[str] = None,
-            name: typing.Optional[str] = None,
+            database_name: typing.Optional[builtins.str] = None,
+            name: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param column_names: ``CfnPermissions.TableWithColumnsResourceProperty.ColumnNames``.
@@ -649,7 +678,7 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if column_names is not None:
                 self._values["column_names"] = column_names
             if column_wildcard is not None:
@@ -660,13 +689,14 @@ class CfnPermissions(
                 self._values["name"] = name
 
         @builtins.property
-        def column_names(self) -> typing.Optional[typing.List[str]]:
+        def column_names(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPermissions.TableWithColumnsResourceProperty.ColumnNames``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-columnnames
             """
-            return self._values.get("column_names")
+            result = self._values.get("column_names")
+            return result
 
         @builtins.property
         def column_wildcard(
@@ -677,30 +707,33 @@ class CfnPermissions(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-columnwildcard
             """
-            return self._values.get("column_wildcard")
+            result = self._values.get("column_wildcard")
+            return result
 
         @builtins.property
-        def database_name(self) -> typing.Optional[str]:
+        def database_name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableWithColumnsResourceProperty.DatabaseName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-databasename
             """
-            return self._values.get("database_name")
+            result = self._values.get("database_name")
+            return result
 
         @builtins.property
-        def name(self) -> typing.Optional[str]:
+        def name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableWithColumnsResourceProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -725,8 +758,8 @@ class CfnPermissionsProps:
         *,
         data_lake_principal: typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e],
         resource: typing.Union["CfnPermissions.ResourceProperty", _IResolvable_9ceae33e],
-        permissions: typing.Optional[typing.List[str]] = None,
-        permissions_with_grant_option: typing.Optional[typing.List[str]] = None,
+        permissions: typing.Optional[typing.List[builtins.str]] = None,
+        permissions_with_grant_option: typing.Optional[typing.List[builtins.str]] = None,
     ) -> None:
         """Properties for defining a ``AWS::LakeFormation::Permissions``.
 
@@ -738,7 +771,7 @@ class CfnPermissionsProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "data_lake_principal": data_lake_principal,
             "resource": resource,
         }
@@ -756,7 +789,9 @@ class CfnPermissionsProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-datalakeprincipal
         """
-        return self._values.get("data_lake_principal")
+        result = self._values.get("data_lake_principal")
+        assert result is not None, "Required property 'data_lake_principal' is missing"
+        return result
 
     @builtins.property
     def resource(
@@ -767,30 +802,36 @@ class CfnPermissionsProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-resource
         """
-        return self._values.get("resource")
+        result = self._values.get("resource")
+        assert result is not None, "Required property 'resource' is missing"
+        return result
 
     @builtins.property
-    def permissions(self) -> typing.Optional[typing.List[str]]:
+    def permissions(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.Permissions``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-permissions
         """
-        return self._values.get("permissions")
+        result = self._values.get("permissions")
+        return result
 
     @builtins.property
-    def permissions_with_grant_option(self) -> typing.Optional[typing.List[str]]:
+    def permissions_with_grant_option(
+        self,
+    ) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.PermissionsWithGrantOption``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-permissionswithgrantoption
         """
-        return self._values.get("permissions_with_grant_option")
+        result = self._values.get("permissions_with_grant_option")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -816,11 +857,11 @@ class CfnResource(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        resource_arn: str,
-        use_service_linked_role: typing.Union[bool, _IResolvable_9ceae33e],
-        role_arn: typing.Optional[str] = None,
+        resource_arn: builtins.str,
+        use_service_linked_role: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+        role_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::LakeFormation::Resource``.
 
@@ -851,27 +892,28 @@ class CfnResource(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceArn")
-    def resource_arn(self) -> str:
+    def resource_arn(self) -> builtins.str:
         """``AWS::LakeFormation::Resource.ResourceArn``.
 
         see
@@ -879,13 +921,15 @@ class CfnResource(
         """
         return jsii.get(self, "resourceArn")
 
-    @resource_arn.setter
-    def resource_arn(self, value: str) -> None:
+    @resource_arn.setter # type: ignore
+    def resource_arn(self, value: builtins.str) -> None:
         jsii.set(self, "resourceArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="useServiceLinkedRole")
-    def use_service_linked_role(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def use_service_linked_role(
+        self,
+    ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Resource.UseServiceLinkedRole``.
 
         see
@@ -893,15 +937,16 @@ class CfnResource(
         """
         return jsii.get(self, "useServiceLinkedRole")
 
-    @use_service_linked_role.setter
+    @use_service_linked_role.setter # type: ignore
     def use_service_linked_role(
-        self, value: typing.Union[bool, _IResolvable_9ceae33e]
+        self,
+        value: typing.Union[builtins.bool, _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "useServiceLinkedRole", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="roleArn")
-    def role_arn(self) -> typing.Optional[str]:
+    def role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::LakeFormation::Resource.RoleArn``.
 
         see
@@ -909,8 +954,8 @@ class CfnResource(
         """
         return jsii.get(self, "roleArn")
 
-    @role_arn.setter
-    def role_arn(self, value: typing.Optional[str]) -> None:
+    @role_arn.setter # type: ignore
+    def role_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "roleArn", value)
 
 
@@ -927,9 +972,9 @@ class CfnResourceProps:
     def __init__(
         self,
         *,
-        resource_arn: str,
-        use_service_linked_role: typing.Union[bool, _IResolvable_9ceae33e],
-        role_arn: typing.Optional[str] = None,
+        resource_arn: builtins.str,
+        use_service_linked_role: typing.Union[builtins.bool, _IResolvable_9ceae33e],
+        role_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::LakeFormation::Resource``.
 
@@ -940,7 +985,7 @@ class CfnResourceProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "resource_arn": resource_arn,
             "use_service_linked_role": use_service_linked_role,
         }
@@ -948,36 +993,43 @@ class CfnResourceProps:
             self._values["role_arn"] = role_arn
 
     @builtins.property
-    def resource_arn(self) -> str:
+    def resource_arn(self) -> builtins.str:
         """``AWS::LakeFormation::Resource.ResourceArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-resourcearn
         """
-        return self._values.get("resource_arn")
+        result = self._values.get("resource_arn")
+        assert result is not None, "Required property 'resource_arn' is missing"
+        return result
 
     @builtins.property
-    def use_service_linked_role(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
+    def use_service_linked_role(
+        self,
+    ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Resource.UseServiceLinkedRole``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-useservicelinkedrole
         """
-        return self._values.get("use_service_linked_role")
+        result = self._values.get("use_service_linked_role")
+        assert result is not None, "Required property 'use_service_linked_role' is missing"
+        return result
 
     @builtins.property
-    def role_arn(self) -> typing.Optional[str]:
+    def role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::LakeFormation::Resource.RoleArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-rolearn
         """
-        return self._values.get("role_arn")
+        result = self._values.get("role_arn")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
