@@ -36,7 +36,12 @@ from ..aws_s3 import (
     EventType as _EventType_726686dc,
     NotificationKeyFilter as _NotificationKeyFilter_c547ae3c,
 )
-from ..aws_sns import ITopic as _ITopic_ef0ebe0e
+from ..aws_sns import (
+    ITopic as _ITopic_ef0ebe0e, SubscriptionFilter as _SubscriptionFilter_91537200
+)
+from ..aws_sns_subscriptions import (
+    LambdaSubscriptionProps as _LambdaSubscriptionProps_923b2648
+)
 from ..aws_sqs import IQueue as _IQueue_b743f559
 
 
@@ -271,14 +276,26 @@ class SnsEventSource(
     :stability: experimental
     """
 
-    def __init__(self, topic: _ITopic_ef0ebe0e) -> None:
+    def __init__(
+        self,
+        topic: _ITopic_ef0ebe0e,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
+    ) -> None:
         """
         :param topic: -
+        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: The filter policy. Default: - all messages are delivered
 
         stability
         :stability: experimental
         """
-        jsii.create(SnsEventSource, self, [topic])
+        props = SnsEventSourceProps(
+            dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
+        )
+
+        jsii.create(SnsEventSource, self, [topic, props])
 
     @jsii.member(jsii_name="bind")
     def bind(self, target: _IFunction_1c1de0bc) -> None:
@@ -301,6 +318,77 @@ class SnsEventSource(
         return jsii.get(self, "topic")
 
 
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_lambda_event_sources.SnsEventSourceProps",
+    jsii_struct_bases=[_LambdaSubscriptionProps_923b2648],
+    name_mapping={
+        "dead_letter_queue": "deadLetterQueue",
+        "filter_policy": "filterPolicy",
+    },
+)
+class SnsEventSourceProps(_LambdaSubscriptionProps_923b2648):
+    def __init__(
+        self,
+        *,
+        dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
+    ) -> None:
+        """Properties forwarded to the Lambda Subscription.
+
+        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: The filter policy. Default: - all messages are delivered
+
+        stability
+        :stability: experimental
+        """
+        self._values: typing.Dict[str, typing.Any] = {}
+        if dead_letter_queue is not None:
+            self._values["dead_letter_queue"] = dead_letter_queue
+        if filter_policy is not None:
+            self._values["filter_policy"] = filter_policy
+
+    @builtins.property
+    def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
+        """Queue to be used as dead letter queue.
+
+        If not passed no dead letter queue is enabled.
+
+        default
+        :default: - No dead letter queue enabled.
+
+        stability
+        :stability: experimental
+        """
+        result = self._values.get("dead_letter_queue")
+        return result
+
+    @builtins.property
+    def filter_policy(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
+        """The filter policy.
+
+        default
+        :default: - all messages are delivered
+
+        stability
+        :stability: experimental
+        """
+        result = self._values.get("filter_policy")
+        return result
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "SnsEventSourceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(_IEventSourceDlq_64554172)
 class SqsDlq(
     metaclass=jsii.JSIIMeta,
@@ -517,6 +605,7 @@ class StreamEventSource(
         batch_size: typing.Optional[jsii.Number] = None,
         bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         enabled: typing.Optional[builtins.bool] = None,
+        kafka_topic: typing.Optional[builtins.str] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -526,15 +615,16 @@ class StreamEventSource(
     ) -> _EventSourceMappingOptions_2fe36144:
         """
         :param event_source_arn: The Amazon Resource Name (ARN) of the event source. Any record added to this stream can invoke the Lambda function.
-        :param batch_size: The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records. Valid Range: Minimum value of 1. Maximum value of 10000. Default: - Amazon Kinesis and Amazon DynamoDB is 100 records. Both the default and maximum for Amazon SQS are 10 messages.
+        :param batch_size: The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records. Valid Range: Minimum value of 1. Maximum value of 10000. Default: - Amazon Kinesis, Amazon DynamoDB, and Amazon MSK is 100 records. Both the default and maximum for Amazon SQS are 10 messages.
         :param bisect_batch_on_error: If the function returns an error, split the batch in two and retry. Default: false
         :param enabled: Set to false to disable the event source upon creation. Default: true
+        :param kafka_topic: The name of the Kafka topic. Default: - no topic
         :param max_batching_window: The maximum amount of time to gather records before invoking the function. Maximum of Duration.minutes(5) Default: Duration.seconds(0)
         :param max_record_age: The maximum age of a record that Lambda sends to a function for processing. Valid Range: - Minimum value of 60 seconds - Maximum value of 7 days Default: Duration.days(7)
         :param on_failure: An Amazon SQS queue or Amazon SNS topic destination for discarded records. Default: discarded records are ignored
         :param parallelization_factor: The number of batches to process from each shard concurrently. Valid Range: - Minimum value of 1 - Maximum value of 10 Default: 1
-        :param retry_attempts: The maximum number of times to retry when the function returns an error. Valid Range: - Minimum value of 0 - Maximum value of 10000 Default: 10000
-        :param starting_position: The position in the DynamoDB or Kinesis stream where AWS Lambda should start reading. Default: - Required for Amazon Kinesis and Amazon DynamoDB Streams sources.
+        :param retry_attempts: The maximum number of times to retry when the function returns an error. Set to ``undefined`` if you want lambda to keep retrying infinitely or until the record expires. Valid Range: - Minimum value of 0 - Maximum value of 10000 Default: - infinite or until the record expires.
+        :param starting_position: The position in the DynamoDB, Kinesis or MSK stream where AWS Lambda should start reading. Default: - Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
 
         stability
         :stability: experimental
@@ -544,6 +634,7 @@ class StreamEventSource(
             batch_size=batch_size,
             bisect_batch_on_error=bisect_batch_on_error,
             enabled=enabled,
+            kafka_topic=kafka_topic,
             max_batching_window=max_batching_window,
             max_record_age=max_record_age,
             on_failure=on_failure,
@@ -1328,6 +1419,7 @@ __all__ = [
     "S3EventSourceProps",
     "SnsDlq",
     "SnsEventSource",
+    "SnsEventSourceProps",
     "SqsDlq",
     "SqsEventSource",
     "SqsEventSourceProps",
