@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -50,29 +50,29 @@ class PythonFunction(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        entry: str,
-        handler: typing.Optional[str] = None,
-        index: typing.Optional[str] = None,
+        entry: builtins.str,
+        handler: typing.Optional[builtins.str] = None,
+        index: typing.Optional[builtins.str] = None,
         runtime: typing.Optional[_Runtime_8b970b80] = None,
-        allow_all_outbound: typing.Optional[bool] = None,
-        allow_public_subnet: typing.Optional[bool] = None,
+        allow_all_outbound: typing.Optional[builtins.bool] = None,
+        allow_public_subnet: typing.Optional[builtins.bool] = None,
         current_version_options: typing.Optional[_VersionOptions_9a55a63d] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        dead_letter_queue_enabled: typing.Optional[bool] = None,
-        description: typing.Optional[str] = None,
-        environment: typing.Optional[typing.Mapping[str, str]] = None,
+        dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+        description: typing.Optional[builtins.str] = None,
+        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         events: typing.Optional[typing.List[_IEventSource_0e6bcb85]] = None,
         filesystem: typing.Optional[_FileSystem_132c0ce7] = None,
-        function_name: typing.Optional[str] = None,
+        function_name: typing.Optional[builtins.str] = None,
         initial_policy: typing.Optional[typing.List[_PolicyStatement_f75dc775]] = None,
         layers: typing.Optional[typing.List[_ILayerVersion_aa5e0c0c]] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_09658088] = None,
         log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         memory_size: typing.Optional[jsii.Number] = None,
-        profiling: typing.Optional[bool] = None,
+        profiling: typing.Optional[builtins.bool] = None,
         profiling_group: typing.Optional[_IProfilingGroup_ca898ddc] = None,
         reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
@@ -216,23 +216,23 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         on_failure: typing.Optional[_IDestination_7081f282] = None,
         on_success: typing.Optional[_IDestination_7081f282] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
-        allow_all_outbound: typing.Optional[bool] = None,
-        allow_public_subnet: typing.Optional[bool] = None,
+        allow_all_outbound: typing.Optional[builtins.bool] = None,
+        allow_public_subnet: typing.Optional[builtins.bool] = None,
         current_version_options: typing.Optional[_VersionOptions_9a55a63d] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        dead_letter_queue_enabled: typing.Optional[bool] = None,
-        description: typing.Optional[str] = None,
-        environment: typing.Optional[typing.Mapping[str, str]] = None,
+        dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+        description: typing.Optional[builtins.str] = None,
+        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         events: typing.Optional[typing.List[_IEventSource_0e6bcb85]] = None,
         filesystem: typing.Optional[_FileSystem_132c0ce7] = None,
-        function_name: typing.Optional[str] = None,
+        function_name: typing.Optional[builtins.str] = None,
         initial_policy: typing.Optional[typing.List[_PolicyStatement_f75dc775]] = None,
         layers: typing.Optional[typing.List[_ILayerVersion_aa5e0c0c]] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_09658088] = None,
         log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         memory_size: typing.Optional[jsii.Number] = None,
-        profiling: typing.Optional[bool] = None,
+        profiling: typing.Optional[builtins.bool] = None,
         profiling_group: typing.Optional[_IProfilingGroup_ca898ddc] = None,
         reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
@@ -242,9 +242,9 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         tracing: typing.Optional[_Tracing_34f0a955] = None,
         vpc: typing.Optional[_IVpc_3795853f] = None,
         vpc_subnets: typing.Optional[_SubnetSelection_36a13cd6] = None,
-        entry: str,
-        handler: typing.Optional[str] = None,
-        index: typing.Optional[str] = None,
+        entry: builtins.str,
+        handler: typing.Optional[builtins.str] = None,
+        index: typing.Optional[builtins.str] = None,
         runtime: typing.Optional[_Runtime_8b970b80] = None,
     ) -> None:
         """Properties for a PythonFunction.
@@ -293,7 +293,7 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
             log_retention_retry_options = _LogRetentionRetryOptions_09658088(**log_retention_retry_options)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = _SubnetSelection_36a13cd6(**vpc_subnets)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "entry": entry,
         }
         if max_event_age is not None:
@@ -376,7 +376,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("max_event_age")
+        result = self._values.get("max_event_age")
+        return result
 
     @builtins.property
     def on_failure(self) -> typing.Optional[_IDestination_7081f282]:
@@ -388,7 +389,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("on_failure")
+        result = self._values.get("on_failure")
+        return result
 
     @builtins.property
     def on_success(self) -> typing.Optional[_IDestination_7081f282]:
@@ -400,7 +402,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("on_success")
+        result = self._values.get("on_success")
+        return result
 
     @builtins.property
     def retry_attempts(self) -> typing.Optional[jsii.Number]:
@@ -415,10 +418,11 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("retry_attempts")
+        result = self._values.get("retry_attempts")
+        return result
 
     @builtins.property
-    def allow_all_outbound(self) -> typing.Optional[bool]:
+    def allow_all_outbound(self) -> typing.Optional[builtins.bool]:
         """Whether to allow the Lambda to send all network traffic.
 
         If set to false, you must individually add traffic rules to allow the
@@ -430,10 +434,11 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("allow_all_outbound")
+        result = self._values.get("allow_all_outbound")
+        return result
 
     @builtins.property
-    def allow_public_subnet(self) -> typing.Optional[bool]:
+    def allow_public_subnet(self) -> typing.Optional[builtins.bool]:
         """Lambda Functions in a public subnet can NOT access the internet.
 
         Use this property to acknowledge this limitation and still place the function in a public subnet.
@@ -446,7 +451,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("allow_public_subnet")
+        result = self._values.get("allow_public_subnet")
+        return result
 
     @builtins.property
     def current_version_options(self) -> typing.Optional[_VersionOptions_9a55a63d]:
@@ -458,7 +464,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("current_version_options")
+        result = self._values.get("current_version_options")
+        return result
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
@@ -470,10 +477,11 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
 
     @builtins.property
-    def dead_letter_queue_enabled(self) -> typing.Optional[bool]:
+    def dead_letter_queue_enabled(self) -> typing.Optional[builtins.bool]:
         """Enabled DLQ.
 
         If ``deadLetterQueue`` is undefined,
@@ -485,10 +493,11 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue_enabled")
+        result = self._values.get("dead_letter_queue_enabled")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """A description of the function.
 
         default
@@ -497,10 +506,13 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def environment(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def environment(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         """Key-value pairs that Lambda caches and makes available for your Lambda functions.
 
         Use environment variables to apply configuration changes, such
@@ -513,7 +525,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("environment")
+        result = self._values.get("environment")
+        return result
 
     @builtins.property
     def events(self) -> typing.Optional[typing.List[_IEventSource_0e6bcb85]]:
@@ -527,7 +540,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("events")
+        result = self._values.get("events")
+        return result
 
     @builtins.property
     def filesystem(self) -> typing.Optional[_FileSystem_132c0ce7]:
@@ -539,10 +553,11 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("filesystem")
+        result = self._values.get("filesystem")
+        return result
 
     @builtins.property
-    def function_name(self) -> typing.Optional[str]:
+    def function_name(self) -> typing.Optional[builtins.str]:
         """A name for the function.
 
         default
@@ -554,7 +569,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("function_name")
+        result = self._values.get("function_name")
+        return result
 
     @builtins.property
     def initial_policy(self) -> typing.Optional[typing.List[_PolicyStatement_f75dc775]]:
@@ -568,7 +584,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("initial_policy")
+        result = self._values.get("initial_policy")
+        return result
 
     @builtins.property
     def layers(self) -> typing.Optional[typing.List[_ILayerVersion_aa5e0c0c]]:
@@ -584,7 +601,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("layers")
+        result = self._values.get("layers")
+        return result
 
     @builtins.property
     def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
@@ -600,7 +618,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention")
+        result = self._values.get("log_retention")
+        return result
 
     @builtins.property
     def log_retention_retry_options(
@@ -616,7 +635,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention_retry_options")
+        result = self._values.get("log_retention_retry_options")
+        return result
 
     @builtins.property
     def log_retention_role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -628,7 +648,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention_role")
+        result = self._values.get("log_retention_role")
+        return result
 
     @builtins.property
     def memory_size(self) -> typing.Optional[jsii.Number]:
@@ -644,10 +665,11 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("memory_size")
+        result = self._values.get("memory_size")
+        return result
 
     @builtins.property
-    def profiling(self) -> typing.Optional[bool]:
+    def profiling(self) -> typing.Optional[builtins.bool]:
         """Enable profiling.
 
         default
@@ -658,7 +680,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("profiling")
+        result = self._values.get("profiling")
+        return result
 
     @builtins.property
     def profiling_group(self) -> typing.Optional[_IProfilingGroup_ca898ddc]:
@@ -672,7 +695,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("profiling_group")
+        result = self._values.get("profiling_group")
+        return result
 
     @builtins.property
     def reserved_concurrent_executions(self) -> typing.Optional[jsii.Number]:
@@ -686,7 +710,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("reserved_concurrent_executions")
+        result = self._values.get("reserved_concurrent_executions")
+        return result
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -711,7 +736,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("role")
+        result = self._values.get("role")
+        return result
 
     @builtins.property
     def security_group(self) -> typing.Optional[_ISecurityGroup_d72ab8e8]:
@@ -735,7 +761,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: deprecated
         """
-        return self._values.get("security_group")
+        result = self._values.get("security_group")
+        return result
 
     @builtins.property
     def security_groups(self) -> typing.Optional[typing.List[_ISecurityGroup_d72ab8e8]]:
@@ -753,7 +780,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("security_groups")
+        result = self._values.get("security_groups")
+        return result
 
     @builtins.property
     def timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -768,7 +796,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("timeout")
+        result = self._values.get("timeout")
+        return result
 
     @builtins.property
     def tracing(self) -> typing.Optional[_Tracing_34f0a955]:
@@ -780,7 +809,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("tracing")
+        result = self._values.get("tracing")
+        return result
 
     @builtins.property
     def vpc(self) -> typing.Optional[_IVpc_3795853f]:
@@ -794,7 +824,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("vpc")
+        result = self._values.get("vpc")
+        return result
 
     @builtins.property
     def vpc_subnets(self) -> typing.Optional[_SubnetSelection_36a13cd6]:
@@ -809,19 +840,22 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("vpc_subnets")
+        result = self._values.get("vpc_subnets")
+        return result
 
     @builtins.property
-    def entry(self) -> str:
+    def entry(self) -> builtins.str:
         """The path to the root directory of the function.
 
         stability
         :stability: experimental
         """
-        return self._values.get("entry")
+        result = self._values.get("entry")
+        assert result is not None, "Required property 'entry' is missing"
+        return result
 
     @builtins.property
-    def handler(self) -> typing.Optional[str]:
+    def handler(self) -> typing.Optional[builtins.str]:
         """The name of the exported handler in the index file.
 
         default
@@ -830,10 +864,11 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("handler")
+        result = self._values.get("handler")
+        return result
 
     @builtins.property
-    def index(self) -> typing.Optional[str]:
+    def index(self) -> typing.Optional[builtins.str]:
         """The path (relative to entry) to the index file containing the exported handler.
 
         default
@@ -842,7 +877,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("index")
+        result = self._values.get("index")
+        return result
 
     @builtins.property
     def runtime(self) -> typing.Optional[_Runtime_8b970b80]:
@@ -857,12 +893,13 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         stability
         :stability: experimental
         """
-        return self._values.get("runtime")
+        result = self._values.get("runtime")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
