@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,13 +36,13 @@ class CfnCustomDataIdentifier(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
-        regex: str,
-        description: typing.Optional[str] = None,
-        ignore_words: typing.Optional[typing.List[str]] = None,
-        keywords: typing.Optional[typing.List[str]] = None,
+        name: builtins.str,
+        regex: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+        ignore_words: typing.Optional[typing.List[builtins.str]] = None,
+        keywords: typing.Optional[typing.List[builtins.str]] = None,
         maximum_match_distance: typing.Optional[jsii.Number] = None,
     ) -> None:
         """Create a new ``AWS::Macie::CustomDataIdentifier``.
@@ -80,38 +80,39 @@ class CfnCustomDataIdentifier(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrCreatedAt")
-    def attr_created_at(self) -> str:
+    def attr_created_at(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: CreatedAt
         """
         return jsii.get(self, "attrCreatedAt")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrDeleted")
     def attr_deleted(self) -> _IResolvable_9ceae33e:
         """
@@ -120,23 +121,23 @@ class CfnCustomDataIdentifier(
         """
         return jsii.get(self, "attrDeleted")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrId")
-    def attr_id(self) -> str:
+    def attr_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Id
         """
         return jsii.get(self, "attrId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Name``.
 
         see
@@ -144,13 +145,13 @@ class CfnCustomDataIdentifier(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="regex")
-    def regex(self) -> str:
+    def regex(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Regex``.
 
         see
@@ -158,13 +159,13 @@ class CfnCustomDataIdentifier(
         """
         return jsii.get(self, "regex")
 
-    @regex.setter
-    def regex(self, value: str) -> None:
+    @regex.setter # type: ignore
+    def regex(self, value: builtins.str) -> None:
         jsii.set(self, "regex", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::CustomDataIdentifier.Description``.
 
         see
@@ -172,13 +173,13 @@ class CfnCustomDataIdentifier(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ignoreWords")
-    def ignore_words(self) -> typing.Optional[typing.List[str]]:
+    def ignore_words(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.IgnoreWords``.
 
         see
@@ -186,13 +187,13 @@ class CfnCustomDataIdentifier(
         """
         return jsii.get(self, "ignoreWords")
 
-    @ignore_words.setter
-    def ignore_words(self, value: typing.Optional[typing.List[str]]) -> None:
+    @ignore_words.setter # type: ignore
+    def ignore_words(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
         jsii.set(self, "ignoreWords", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="keywords")
-    def keywords(self) -> typing.Optional[typing.List[str]]:
+    def keywords(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.Keywords``.
 
         see
@@ -200,11 +201,11 @@ class CfnCustomDataIdentifier(
         """
         return jsii.get(self, "keywords")
 
-    @keywords.setter
-    def keywords(self, value: typing.Optional[typing.List[str]]) -> None:
+    @keywords.setter # type: ignore
+    def keywords(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
         jsii.set(self, "keywords", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="maximumMatchDistance")
     def maximum_match_distance(self) -> typing.Optional[jsii.Number]:
         """``AWS::Macie::CustomDataIdentifier.MaximumMatchDistance``.
@@ -214,7 +215,7 @@ class CfnCustomDataIdentifier(
         """
         return jsii.get(self, "maximumMatchDistance")
 
-    @maximum_match_distance.setter
+    @maximum_match_distance.setter # type: ignore
     def maximum_match_distance(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "maximumMatchDistance", value)
 
@@ -235,11 +236,11 @@ class CfnCustomDataIdentifierProps:
     def __init__(
         self,
         *,
-        name: str,
-        regex: str,
-        description: typing.Optional[str] = None,
-        ignore_words: typing.Optional[typing.List[str]] = None,
-        keywords: typing.Optional[typing.List[str]] = None,
+        name: builtins.str,
+        regex: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+        ignore_words: typing.Optional[typing.List[builtins.str]] = None,
+        keywords: typing.Optional[typing.List[builtins.str]] = None,
         maximum_match_distance: typing.Optional[jsii.Number] = None,
     ) -> None:
         """Properties for defining a ``AWS::Macie::CustomDataIdentifier``.
@@ -254,7 +255,7 @@ class CfnCustomDataIdentifierProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "regex": regex,
         }
@@ -268,49 +269,56 @@ class CfnCustomDataIdentifierProps:
             self._values["maximum_match_distance"] = maximum_match_distance
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def regex(self) -> str:
+    def regex(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Regex``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-regex
         """
-        return self._values.get("regex")
+        result = self._values.get("regex")
+        assert result is not None, "Required property 'regex' is missing"
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::CustomDataIdentifier.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def ignore_words(self) -> typing.Optional[typing.List[str]]:
+    def ignore_words(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.IgnoreWords``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-ignorewords
         """
-        return self._values.get("ignore_words")
+        result = self._values.get("ignore_words")
+        return result
 
     @builtins.property
-    def keywords(self) -> typing.Optional[typing.List[str]]:
+    def keywords(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.Keywords``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-keywords
         """
-        return self._values.get("keywords")
+        result = self._values.get("keywords")
+        return result
 
     @builtins.property
     def maximum_match_distance(self) -> typing.Optional[jsii.Number]:
@@ -319,12 +327,13 @@ class CfnCustomDataIdentifierProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-maximummatchdistance
         """
-        return self._values.get("maximum_match_distance")
+        result = self._values.get("maximum_match_distance")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -350,12 +359,12 @@ class CfnFindingsFilter(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         finding_criteria: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
-        name: str,
-        action: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
+        name: builtins.str,
+        action: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
         position: typing.Optional[jsii.Number] = None,
     ) -> None:
         """Create a new ``AWS::Macie::FindingsFilter``.
@@ -391,29 +400,30 @@ class CfnFindingsFilter(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrFindingsFilterListItems")
     def attr_findings_filter_list_items(self) -> _IResolvable_9ceae33e:
         """
@@ -422,21 +432,21 @@ class CfnFindingsFilter(
         """
         return jsii.get(self, "attrFindingsFilterListItems")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrId")
-    def attr_id(self) -> str:
+    def attr_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Id
         """
         return jsii.get(self, "attrId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="findingCriteria")
     def finding_criteria(
         self,
@@ -448,15 +458,16 @@ class CfnFindingsFilter(
         """
         return jsii.get(self, "findingCriteria")
 
-    @finding_criteria.setter
+    @finding_criteria.setter # type: ignore
     def finding_criteria(
-        self, value: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "findingCriteria", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::Macie::FindingsFilter.Name``.
 
         see
@@ -464,13 +475,13 @@ class CfnFindingsFilter(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="action")
-    def action(self) -> typing.Optional[str]:
+    def action(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Action``.
 
         see
@@ -478,13 +489,13 @@ class CfnFindingsFilter(
         """
         return jsii.get(self, "action")
 
-    @action.setter
-    def action(self, value: typing.Optional[str]) -> None:
+    @action.setter # type: ignore
+    def action(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "action", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Description``.
 
         see
@@ -492,11 +503,11 @@ class CfnFindingsFilter(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="position")
     def position(self) -> typing.Optional[jsii.Number]:
         """``AWS::Macie::FindingsFilter.Position``.
@@ -506,7 +517,7 @@ class CfnFindingsFilter(
         """
         return jsii.get(self, "position")
 
-    @position.setter
+    @position.setter # type: ignore
     def position(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "position", value)
 
@@ -521,12 +532,12 @@ class CfnFindingsFilter(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-criterion.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -551,7 +562,7 @@ class CfnFindingsFilter(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingcriteria.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if criterion is not None:
                 self._values["criterion"] = criterion
 
@@ -564,12 +575,13 @@ class CfnFindingsFilter(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingcriteria.html#cfn-macie-findingsfilter-findingcriteria-criterion
             """
-            return self._values.get("criterion")
+            result = self._values.get("criterion")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -577,6 +589,62 @@ class CfnFindingsFilter(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_macie.CfnFindingsFilter.FindingsFilterListItemProperty",
+        jsii_struct_bases=[],
+        name_mapping={"id": "id", "name": "name"},
+    )
+    class FindingsFilterListItemProperty:
+        def __init__(
+            self,
+            *,
+            id: typing.Optional[builtins.str] = None,
+            name: typing.Optional[builtins.str] = None,
+        ) -> None:
+            """
+            :param id: ``CfnFindingsFilter.FindingsFilterListItemProperty.Id``.
+            :param name: ``CfnFindingsFilter.FindingsFilterListItemProperty.Name``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingsfilterlistitem.html
+            """
+            self._values: typing.Dict[str, typing.Any] = {}
+            if id is not None:
+                self._values["id"] = id
+            if name is not None:
+                self._values["name"] = name
+
+        @builtins.property
+        def id(self) -> typing.Optional[builtins.str]:
+            """``CfnFindingsFilter.FindingsFilterListItemProperty.Id``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingsfilterlistitem.html#cfn-macie-findingsfilter-findingsfilterlistitem-id
+            """
+            result = self._values.get("id")
+            return result
+
+        @builtins.property
+        def name(self) -> typing.Optional[builtins.str]:
+            """``CfnFindingsFilter.FindingsFilterListItemProperty.Name``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingsfilterlistitem.html#cfn-macie-findingsfilter-findingsfilterlistitem-name
+            """
+            result = self._values.get("name")
+            return result
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "FindingsFilterListItemProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
 
 @jsii.data_type(
     jsii_type="monocdk-experiment.aws_macie.CfnFindingsFilterProps",
@@ -594,9 +662,9 @@ class CfnFindingsFilterProps:
         self,
         *,
         finding_criteria: typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
-        name: str,
-        action: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
+        name: builtins.str,
+        action: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
         position: typing.Optional[jsii.Number] = None,
     ) -> None:
         """Properties for defining a ``AWS::Macie::FindingsFilter``.
@@ -610,7 +678,7 @@ class CfnFindingsFilterProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "finding_criteria": finding_criteria,
             "name": name,
         }
@@ -630,34 +698,40 @@ class CfnFindingsFilterProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-findingcriteria
         """
-        return self._values.get("finding_criteria")
+        result = self._values.get("finding_criteria")
+        assert result is not None, "Required property 'finding_criteria' is missing"
+        return result
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::Macie::FindingsFilter.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def action(self) -> typing.Optional[str]:
+    def action(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Action``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-action
         """
-        return self._values.get("action")
+        result = self._values.get("action")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
     def position(self) -> typing.Optional[jsii.Number]:
@@ -666,12 +740,13 @@ class CfnFindingsFilterProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-position
         """
-        return self._values.get("position")
+        result = self._values.get("position")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -697,10 +772,10 @@ class CfnSession(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        finding_publishing_frequency: typing.Optional[str] = None,
-        status: typing.Optional[str] = None,
+        finding_publishing_frequency: typing.Optional[builtins.str] = None,
+        status: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::Macie::Session``.
 
@@ -728,45 +803,46 @@ class CfnSession(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrAwsAccountId")
-    def attr_aws_account_id(self) -> str:
+    def attr_aws_account_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: AwsAccountId
         """
         return jsii.get(self, "attrAwsAccountId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrServiceRole")
-    def attr_service_role(self) -> str:
+    def attr_service_role(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ServiceRole
         """
         return jsii.get(self, "attrServiceRole")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="findingPublishingFrequency")
-    def finding_publishing_frequency(self) -> typing.Optional[str]:
+    def finding_publishing_frequency(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.FindingPublishingFrequency``.
 
         see
@@ -774,13 +850,16 @@ class CfnSession(
         """
         return jsii.get(self, "findingPublishingFrequency")
 
-    @finding_publishing_frequency.setter
-    def finding_publishing_frequency(self, value: typing.Optional[str]) -> None:
+    @finding_publishing_frequency.setter # type: ignore
+    def finding_publishing_frequency(
+        self,
+        value: typing.Optional[builtins.str],
+    ) -> None:
         jsii.set(self, "findingPublishingFrequency", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="status")
-    def status(self) -> typing.Optional[str]:
+    def status(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.Status``.
 
         see
@@ -788,8 +867,8 @@ class CfnSession(
         """
         return jsii.get(self, "status")
 
-    @status.setter
-    def status(self, value: typing.Optional[str]) -> None:
+    @status.setter # type: ignore
+    def status(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "status", value)
 
 
@@ -805,8 +884,8 @@ class CfnSessionProps:
     def __init__(
         self,
         *,
-        finding_publishing_frequency: typing.Optional[str] = None,
-        status: typing.Optional[str] = None,
+        finding_publishing_frequency: typing.Optional[builtins.str] = None,
+        status: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::Macie::Session``.
 
@@ -816,34 +895,36 @@ class CfnSessionProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if finding_publishing_frequency is not None:
             self._values["finding_publishing_frequency"] = finding_publishing_frequency
         if status is not None:
             self._values["status"] = status
 
     @builtins.property
-    def finding_publishing_frequency(self) -> typing.Optional[str]:
+    def finding_publishing_frequency(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.FindingPublishingFrequency``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-findingpublishingfrequency
         """
-        return self._values.get("finding_publishing_frequency")
+        result = self._values.get("finding_publishing_frequency")
+        return result
 
     @builtins.property
-    def status(self) -> typing.Optional[str]:
+    def status(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.Status``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-status
         """
-        return self._values.get("status")
+        result = self._values.get("status")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
