@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,12 +36,12 @@ class CfnMember(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         member_configuration: typing.Union["MemberConfigurationProperty", _IResolvable_9ceae33e],
-        invitation_id: typing.Optional[str] = None,
+        invitation_id: typing.Optional[builtins.str] = None,
         network_configuration: typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
-        network_id: typing.Optional[str] = None,
+        network_id: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::ManagedBlockchain::Member``.
 
@@ -74,43 +74,44 @@ class CfnMember(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrMemberId")
-    def attr_member_id(self) -> str:
+    def attr_member_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: MemberId
         """
         return jsii.get(self, "attrMemberId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrNetworkId")
-    def attr_network_id(self) -> str:
+    def attr_network_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: NetworkId
         """
         return jsii.get(self, "attrNetworkId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="memberConfiguration")
     def member_configuration(
         self,
@@ -122,15 +123,16 @@ class CfnMember(
         """
         return jsii.get(self, "memberConfiguration")
 
-    @member_configuration.setter
+    @member_configuration.setter # type: ignore
     def member_configuration(
-        self, value: typing.Union["MemberConfigurationProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["MemberConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "memberConfiguration", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="invitationId")
-    def invitation_id(self) -> typing.Optional[str]:
+    def invitation_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.InvitationId``.
 
         see
@@ -138,11 +140,11 @@ class CfnMember(
         """
         return jsii.get(self, "invitationId")
 
-    @invitation_id.setter
-    def invitation_id(self, value: typing.Optional[str]) -> None:
+    @invitation_id.setter # type: ignore
+    def invitation_id(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "invitationId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="networkConfiguration")
     def network_configuration(
         self,
@@ -154,16 +156,16 @@ class CfnMember(
         """
         return jsii.get(self, "networkConfiguration")
 
-    @network_configuration.setter
+    @network_configuration.setter # type: ignore
     def network_configuration(
         self,
         value: typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "networkConfiguration", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="networkId")
-    def network_id(self) -> typing.Optional[str]:
+    def network_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.NetworkId``.
 
         see
@@ -171,8 +173,8 @@ class CfnMember(
         """
         return jsii.get(self, "networkId")
 
-    @network_id.setter
-    def network_id(self, value: typing.Optional[str]) -> None:
+    @network_id.setter # type: ignore
+    def network_id(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "networkId", value)
 
     @jsii.data_type(
@@ -189,7 +191,7 @@ class CfnMember(
             self,
             *,
             proposal_duration_in_hours: typing.Optional[jsii.Number] = None,
-            threshold_comparator: typing.Optional[str] = None,
+            threshold_comparator: typing.Optional[builtins.str] = None,
             threshold_percentage: typing.Optional[jsii.Number] = None,
         ) -> None:
             """
@@ -200,7 +202,7 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if proposal_duration_in_hours is not None:
                 self._values["proposal_duration_in_hours"] = proposal_duration_in_hours
             if threshold_comparator is not None:
@@ -215,16 +217,18 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html#cfn-managedblockchain-member-approvalthresholdpolicy-proposaldurationinhours
             """
-            return self._values.get("proposal_duration_in_hours")
+            result = self._values.get("proposal_duration_in_hours")
+            return result
 
         @builtins.property
-        def threshold_comparator(self) -> typing.Optional[str]:
+        def threshold_comparator(self) -> typing.Optional[builtins.str]:
             """``CfnMember.ApprovalThresholdPolicyProperty.ThresholdComparator``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html#cfn-managedblockchain-member-approvalthresholdpolicy-thresholdcomparator
             """
-            return self._values.get("threshold_comparator")
+            result = self._values.get("threshold_comparator")
+            return result
 
         @builtins.property
         def threshold_percentage(self) -> typing.Optional[jsii.Number]:
@@ -233,12 +237,13 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html#cfn-managedblockchain-member-approvalthresholdpolicy-thresholdpercentage
             """
-            return self._values.get("threshold_percentage")
+            result = self._values.get("threshold_percentage")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -259,8 +264,8 @@ class CfnMember(
         def __init__(
             self,
             *,
-            name: str,
-            description: typing.Optional[str] = None,
+            name: builtins.str,
+            description: typing.Optional[builtins.str] = None,
             member_framework_configuration: typing.Optional[typing.Union["CfnMember.MemberFrameworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
@@ -271,7 +276,7 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "name": name,
             }
             if description is not None:
@@ -280,22 +285,25 @@ class CfnMember(
                 self._values["member_framework_configuration"] = member_framework_configuration
 
         @builtins.property
-        def name(self) -> str:
+        def name(self) -> builtins.str:
             """``CfnMember.MemberConfigurationProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html#cfn-managedblockchain-member-memberconfiguration-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            assert result is not None, "Required property 'name' is missing"
+            return result
 
         @builtins.property
-        def description(self) -> typing.Optional[str]:
+        def description(self) -> typing.Optional[builtins.str]:
             """``CfnMember.MemberConfigurationProperty.Description``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html#cfn-managedblockchain-member-memberconfiguration-description
             """
-            return self._values.get("description")
+            result = self._values.get("description")
+            return result
 
         @builtins.property
         def member_framework_configuration(
@@ -306,12 +314,13 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html#cfn-managedblockchain-member-memberconfiguration-memberframeworkconfiguration
             """
-            return self._values.get("member_framework_configuration")
+            result = self._values.get("member_framework_configuration")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -328,7 +337,12 @@ class CfnMember(
         },
     )
     class MemberFabricConfigurationProperty:
-        def __init__(self, *, admin_password: str, admin_username: str) -> None:
+        def __init__(
+            self,
+            *,
+            admin_password: builtins.str,
+            admin_username: builtins.str,
+        ) -> None:
             """
             :param admin_password: ``CfnMember.MemberFabricConfigurationProperty.AdminPassword``.
             :param admin_username: ``CfnMember.MemberFabricConfigurationProperty.AdminUsername``.
@@ -336,33 +350,37 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberfabricconfiguration.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "admin_password": admin_password,
                 "admin_username": admin_username,
             }
 
         @builtins.property
-        def admin_password(self) -> str:
+        def admin_password(self) -> builtins.str:
             """``CfnMember.MemberFabricConfigurationProperty.AdminPassword``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberfabricconfiguration.html#cfn-managedblockchain-member-memberfabricconfiguration-adminpassword
             """
-            return self._values.get("admin_password")
+            result = self._values.get("admin_password")
+            assert result is not None, "Required property 'admin_password' is missing"
+            return result
 
         @builtins.property
-        def admin_username(self) -> str:
+        def admin_username(self) -> builtins.str:
             """``CfnMember.MemberFabricConfigurationProperty.AdminUsername``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberfabricconfiguration.html#cfn-managedblockchain-member-memberfabricconfiguration-adminusername
             """
-            return self._values.get("admin_username")
+            result = self._values.get("admin_username")
+            assert result is not None, "Required property 'admin_username' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -387,7 +405,7 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberframeworkconfiguration.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if member_fabric_configuration is not None:
                 self._values["member_fabric_configuration"] = member_fabric_configuration
 
@@ -400,12 +418,13 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberframeworkconfiguration.html#cfn-managedblockchain-member-memberframeworkconfiguration-memberfabricconfiguration
             """
-            return self._values.get("member_fabric_configuration")
+            result = self._values.get("member_fabric_configuration")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -429,11 +448,11 @@ class CfnMember(
         def __init__(
             self,
             *,
-            framework: str,
-            framework_version: str,
-            name: str,
+            framework: builtins.str,
+            framework_version: builtins.str,
+            name: builtins.str,
             voting_policy: typing.Union["CfnMember.VotingPolicyProperty", _IResolvable_9ceae33e],
-            description: typing.Optional[str] = None,
+            description: typing.Optional[builtins.str] = None,
             network_framework_configuration: typing.Optional[typing.Union["CfnMember.NetworkFrameworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
@@ -447,7 +466,7 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "framework": framework,
                 "framework_version": framework_version,
                 "name": name,
@@ -459,31 +478,37 @@ class CfnMember(
                 self._values["network_framework_configuration"] = network_framework_configuration
 
         @builtins.property
-        def framework(self) -> str:
+        def framework(self) -> builtins.str:
             """``CfnMember.NetworkConfigurationProperty.Framework``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-framework
             """
-            return self._values.get("framework")
+            result = self._values.get("framework")
+            assert result is not None, "Required property 'framework' is missing"
+            return result
 
         @builtins.property
-        def framework_version(self) -> str:
+        def framework_version(self) -> builtins.str:
             """``CfnMember.NetworkConfigurationProperty.FrameworkVersion``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-frameworkversion
             """
-            return self._values.get("framework_version")
+            result = self._values.get("framework_version")
+            assert result is not None, "Required property 'framework_version' is missing"
+            return result
 
         @builtins.property
-        def name(self) -> str:
+        def name(self) -> builtins.str:
             """``CfnMember.NetworkConfigurationProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            assert result is not None, "Required property 'name' is missing"
+            return result
 
         @builtins.property
         def voting_policy(
@@ -494,16 +519,19 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-votingpolicy
             """
-            return self._values.get("voting_policy")
+            result = self._values.get("voting_policy")
+            assert result is not None, "Required property 'voting_policy' is missing"
+            return result
 
         @builtins.property
-        def description(self) -> typing.Optional[str]:
+        def description(self) -> typing.Optional[builtins.str]:
             """``CfnMember.NetworkConfigurationProperty.Description``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-description
             """
-            return self._values.get("description")
+            result = self._values.get("description")
+            return result
 
         @builtins.property
         def network_framework_configuration(
@@ -514,12 +542,13 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-networkframeworkconfiguration
             """
-            return self._values.get("network_framework_configuration")
+            result = self._values.get("network_framework_configuration")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -533,30 +562,32 @@ class CfnMember(
         name_mapping={"edition": "edition"},
     )
     class NetworkFabricConfigurationProperty:
-        def __init__(self, *, edition: str) -> None:
+        def __init__(self, *, edition: builtins.str) -> None:
             """
             :param edition: ``CfnMember.NetworkFabricConfigurationProperty.Edition``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkfabricconfiguration.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "edition": edition,
             }
 
         @builtins.property
-        def edition(self) -> str:
+        def edition(self) -> builtins.str:
             """``CfnMember.NetworkFabricConfigurationProperty.Edition``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkfabricconfiguration.html#cfn-managedblockchain-member-networkfabricconfiguration-edition
             """
-            return self._values.get("edition")
+            result = self._values.get("edition")
+            assert result is not None, "Required property 'edition' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -581,7 +612,7 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkframeworkconfiguration.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if network_fabric_configuration is not None:
                 self._values["network_fabric_configuration"] = network_fabric_configuration
 
@@ -594,12 +625,13 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkframeworkconfiguration.html#cfn-managedblockchain-member-networkframeworkconfiguration-networkfabricconfiguration
             """
-            return self._values.get("network_fabric_configuration")
+            result = self._values.get("network_fabric_configuration")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -624,7 +656,7 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-votingpolicy.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if approval_threshold_policy is not None:
                 self._values["approval_threshold_policy"] = approval_threshold_policy
 
@@ -637,12 +669,13 @@ class CfnMember(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-votingpolicy.html#cfn-managedblockchain-member-votingpolicy-approvalthresholdpolicy
             """
-            return self._values.get("approval_threshold_policy")
+            result = self._values.get("approval_threshold_policy")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -666,9 +699,9 @@ class CfnMemberProps:
         self,
         *,
         member_configuration: typing.Union["CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e],
-        invitation_id: typing.Optional[str] = None,
+        invitation_id: typing.Optional[builtins.str] = None,
         network_configuration: typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
-        network_id: typing.Optional[str] = None,
+        network_id: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::ManagedBlockchain::Member``.
 
@@ -680,7 +713,7 @@ class CfnMemberProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "member_configuration": member_configuration,
         }
         if invitation_id is not None:
@@ -699,16 +732,19 @@ class CfnMemberProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-memberconfiguration
         """
-        return self._values.get("member_configuration")
+        result = self._values.get("member_configuration")
+        assert result is not None, "Required property 'member_configuration' is missing"
+        return result
 
     @builtins.property
-    def invitation_id(self) -> typing.Optional[str]:
+    def invitation_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.InvitationId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-invitationid
         """
-        return self._values.get("invitation_id")
+        result = self._values.get("invitation_id")
+        return result
 
     @builtins.property
     def network_configuration(
@@ -719,21 +755,23 @@ class CfnMemberProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkconfiguration
         """
-        return self._values.get("network_configuration")
+        result = self._values.get("network_configuration")
+        return result
 
     @builtins.property
-    def network_id(self) -> typing.Optional[str]:
+    def network_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.NetworkId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkid
         """
-        return self._values.get("network_id")
+        result = self._values.get("network_id")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -759,10 +797,10 @@ class CfnNode(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        member_id: str,
-        network_id: str,
+        member_id: builtins.str,
+        network_id: builtins.str,
         node_configuration: typing.Union["NodeConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         """Create a new ``AWS::ManagedBlockchain::Node``.
@@ -794,63 +832,64 @@ class CfnNode(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrMemberId")
-    def attr_member_id(self) -> str:
+    def attr_member_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: MemberId
         """
         return jsii.get(self, "attrMemberId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrNetworkId")
-    def attr_network_id(self) -> str:
+    def attr_network_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: NetworkId
         """
         return jsii.get(self, "attrNetworkId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrNodeId")
-    def attr_node_id(self) -> str:
+    def attr_node_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: NodeId
         """
         return jsii.get(self, "attrNodeId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="memberId")
-    def member_id(self) -> str:
+    def member_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.MemberId``.
 
         see
@@ -858,13 +897,13 @@ class CfnNode(
         """
         return jsii.get(self, "memberId")
 
-    @member_id.setter
-    def member_id(self, value: str) -> None:
+    @member_id.setter # type: ignore
+    def member_id(self, value: builtins.str) -> None:
         jsii.set(self, "memberId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="networkId")
-    def network_id(self) -> str:
+    def network_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.NetworkId``.
 
         see
@@ -872,11 +911,11 @@ class CfnNode(
         """
         return jsii.get(self, "networkId")
 
-    @network_id.setter
-    def network_id(self, value: str) -> None:
+    @network_id.setter # type: ignore
+    def network_id(self, value: builtins.str) -> None:
         jsii.set(self, "networkId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="nodeConfiguration")
     def node_configuration(
         self,
@@ -888,9 +927,10 @@ class CfnNode(
         """
         return jsii.get(self, "nodeConfiguration")
 
-    @node_configuration.setter
+    @node_configuration.setter # type: ignore
     def node_configuration(
-        self, value: typing.Union["NodeConfigurationProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["NodeConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "nodeConfiguration", value)
 
@@ -903,7 +943,12 @@ class CfnNode(
         },
     )
     class NodeConfigurationProperty:
-        def __init__(self, *, availability_zone: str, instance_type: str) -> None:
+        def __init__(
+            self,
+            *,
+            availability_zone: builtins.str,
+            instance_type: builtins.str,
+        ) -> None:
             """
             :param availability_zone: ``CfnNode.NodeConfigurationProperty.AvailabilityZone``.
             :param instance_type: ``CfnNode.NodeConfigurationProperty.InstanceType``.
@@ -911,33 +956,37 @@ class CfnNode(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-node-nodeconfiguration.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "availability_zone": availability_zone,
                 "instance_type": instance_type,
             }
 
         @builtins.property
-        def availability_zone(self) -> str:
+        def availability_zone(self) -> builtins.str:
             """``CfnNode.NodeConfigurationProperty.AvailabilityZone``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-node-nodeconfiguration.html#cfn-managedblockchain-node-nodeconfiguration-availabilityzone
             """
-            return self._values.get("availability_zone")
+            result = self._values.get("availability_zone")
+            assert result is not None, "Required property 'availability_zone' is missing"
+            return result
 
         @builtins.property
-        def instance_type(self) -> str:
+        def instance_type(self) -> builtins.str:
             """``CfnNode.NodeConfigurationProperty.InstanceType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-node-nodeconfiguration.html#cfn-managedblockchain-node-nodeconfiguration-instancetype
             """
-            return self._values.get("instance_type")
+            result = self._values.get("instance_type")
+            assert result is not None, "Required property 'instance_type' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -959,8 +1008,8 @@ class CfnNodeProps:
     def __init__(
         self,
         *,
-        member_id: str,
-        network_id: str,
+        member_id: builtins.str,
+        network_id: builtins.str,
         node_configuration: typing.Union["CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         """Properties for defining a ``AWS::ManagedBlockchain::Node``.
@@ -972,29 +1021,33 @@ class CfnNodeProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "member_id": member_id,
             "network_id": network_id,
             "node_configuration": node_configuration,
         }
 
     @builtins.property
-    def member_id(self) -> str:
+    def member_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.MemberId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-memberid
         """
-        return self._values.get("member_id")
+        result = self._values.get("member_id")
+        assert result is not None, "Required property 'member_id' is missing"
+        return result
 
     @builtins.property
-    def network_id(self) -> str:
+    def network_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.NetworkId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-networkid
         """
-        return self._values.get("network_id")
+        result = self._values.get("network_id")
+        assert result is not None, "Required property 'network_id' is missing"
+        return result
 
     @builtins.property
     def node_configuration(
@@ -1005,12 +1058,14 @@ class CfnNodeProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-nodeconfiguration
         """
-        return self._values.get("node_configuration")
+        result = self._values.get("node_configuration")
+        assert result is not None, "Required property 'node_configuration' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
