@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -38,14 +38,14 @@ class CfnContainer(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        container_name: str,
-        access_logging_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        container_name: builtins.str,
+        access_logging_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]] = None,
-        lifecycle_policy: typing.Optional[str] = None,
+        lifecycle_policy: typing.Optional[builtins.str] = None,
         metric_policy: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]] = None,
-        policy: typing.Optional[str] = None,
+        policy: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::MediaStore::Container``.
@@ -85,34 +85,35 @@ class CfnContainer(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrEndpoint")
-    def attr_endpoint(self) -> str:
+    def attr_endpoint(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Endpoint
         """
         return jsii.get(self, "attrEndpoint")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaStore::Container.Tags``.
@@ -122,9 +123,9 @@ class CfnContainer(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="containerName")
-    def container_name(self) -> str:
+    def container_name(self) -> builtins.str:
         """``AWS::MediaStore::Container.ContainerName``.
 
         see
@@ -132,15 +133,15 @@ class CfnContainer(
         """
         return jsii.get(self, "containerName")
 
-    @container_name.setter
-    def container_name(self, value: str) -> None:
+    @container_name.setter # type: ignore
+    def container_name(self, value: builtins.str) -> None:
         jsii.set(self, "containerName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="accessLoggingEnabled")
     def access_logging_enabled(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.AccessLoggingEnabled``.
 
         see
@@ -148,13 +149,14 @@ class CfnContainer(
         """
         return jsii.get(self, "accessLoggingEnabled")
 
-    @access_logging_enabled.setter
+    @access_logging_enabled.setter # type: ignore
     def access_logging_enabled(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "accessLoggingEnabled", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="corsPolicy")
     def cors_policy(
         self,
@@ -166,16 +168,16 @@ class CfnContainer(
         """
         return jsii.get(self, "corsPolicy")
 
-    @cors_policy.setter
+    @cors_policy.setter # type: ignore
     def cors_policy(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "corsPolicy", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lifecyclePolicy")
-    def lifecycle_policy(self) -> typing.Optional[str]:
+    def lifecycle_policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.LifecyclePolicy``.
 
         see
@@ -183,11 +185,11 @@ class CfnContainer(
         """
         return jsii.get(self, "lifecyclePolicy")
 
-    @lifecycle_policy.setter
-    def lifecycle_policy(self, value: typing.Optional[str]) -> None:
+    @lifecycle_policy.setter # type: ignore
+    def lifecycle_policy(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "lifecyclePolicy", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="metricPolicy")
     def metric_policy(
         self,
@@ -199,16 +201,16 @@ class CfnContainer(
         """
         return jsii.get(self, "metricPolicy")
 
-    @metric_policy.setter
+    @metric_policy.setter # type: ignore
     def metric_policy(
         self,
         value: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "metricPolicy", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="policy")
-    def policy(self) -> typing.Optional[str]:
+    def policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.Policy``.
 
         see
@@ -216,8 +218,8 @@ class CfnContainer(
         """
         return jsii.get(self, "policy")
 
-    @policy.setter
-    def policy(self, value: typing.Optional[str]) -> None:
+    @policy.setter # type: ignore
+    def policy(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "policy", value)
 
     @jsii.data_type(
@@ -235,10 +237,10 @@ class CfnContainer(
         def __init__(
             self,
             *,
-            allowed_headers: typing.Optional[typing.List[str]] = None,
-            allowed_methods: typing.Optional[typing.List[str]] = None,
-            allowed_origins: typing.Optional[typing.List[str]] = None,
-            expose_headers: typing.Optional[typing.List[str]] = None,
+            allowed_headers: typing.Optional[typing.List[builtins.str]] = None,
+            allowed_methods: typing.Optional[typing.List[builtins.str]] = None,
+            allowed_origins: typing.Optional[typing.List[builtins.str]] = None,
+            expose_headers: typing.Optional[typing.List[builtins.str]] = None,
             max_age_seconds: typing.Optional[jsii.Number] = None,
         ) -> None:
             """
@@ -251,7 +253,7 @@ class CfnContainer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if allowed_headers is not None:
                 self._values["allowed_headers"] = allowed_headers
             if allowed_methods is not None:
@@ -264,40 +266,44 @@ class CfnContainer(
                 self._values["max_age_seconds"] = max_age_seconds
 
         @builtins.property
-        def allowed_headers(self) -> typing.Optional[typing.List[str]]:
+        def allowed_headers(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.AllowedHeaders``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedheaders
             """
-            return self._values.get("allowed_headers")
+            result = self._values.get("allowed_headers")
+            return result
 
         @builtins.property
-        def allowed_methods(self) -> typing.Optional[typing.List[str]]:
+        def allowed_methods(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.AllowedMethods``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedmethods
             """
-            return self._values.get("allowed_methods")
+            result = self._values.get("allowed_methods")
+            return result
 
         @builtins.property
-        def allowed_origins(self) -> typing.Optional[typing.List[str]]:
+        def allowed_origins(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.AllowedOrigins``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedorigins
             """
-            return self._values.get("allowed_origins")
+            result = self._values.get("allowed_origins")
+            return result
 
         @builtins.property
-        def expose_headers(self) -> typing.Optional[typing.List[str]]:
+        def expose_headers(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.ExposeHeaders``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-exposeheaders
             """
-            return self._values.get("expose_headers")
+            result = self._values.get("expose_headers")
+            return result
 
         @builtins.property
         def max_age_seconds(self) -> typing.Optional[jsii.Number]:
@@ -306,12 +312,13 @@ class CfnContainer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-maxageseconds
             """
-            return self._values.get("max_age_seconds")
+            result = self._values.get("max_age_seconds")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -331,7 +338,7 @@ class CfnContainer(
         def __init__(
             self,
             *,
-            container_level_metrics: str,
+            container_level_metrics: builtins.str,
             metric_policy_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e]]]] = None,
         ) -> None:
             """
@@ -341,20 +348,22 @@ class CfnContainer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "container_level_metrics": container_level_metrics,
             }
             if metric_policy_rules is not None:
                 self._values["metric_policy_rules"] = metric_policy_rules
 
         @builtins.property
-        def container_level_metrics(self) -> str:
+        def container_level_metrics(self) -> builtins.str:
             """``CfnContainer.MetricPolicyProperty.ContainerLevelMetrics``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html#cfn-mediastore-container-metricpolicy-containerlevelmetrics
             """
-            return self._values.get("container_level_metrics")
+            result = self._values.get("container_level_metrics")
+            assert result is not None, "Required property 'container_level_metrics' is missing"
+            return result
 
         @builtins.property
         def metric_policy_rules(
@@ -365,12 +374,13 @@ class CfnContainer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html#cfn-mediastore-container-metricpolicy-metricpolicyrules
             """
-            return self._values.get("metric_policy_rules")
+            result = self._values.get("metric_policy_rules")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -387,7 +397,12 @@ class CfnContainer(
         },
     )
     class MetricPolicyRuleProperty:
-        def __init__(self, *, object_group: str, object_group_name: str) -> None:
+        def __init__(
+            self,
+            *,
+            object_group: builtins.str,
+            object_group_name: builtins.str,
+        ) -> None:
             """
             :param object_group: ``CfnContainer.MetricPolicyRuleProperty.ObjectGroup``.
             :param object_group_name: ``CfnContainer.MetricPolicyRuleProperty.ObjectGroupName``.
@@ -395,33 +410,37 @@ class CfnContainer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "object_group": object_group,
                 "object_group_name": object_group_name,
             }
 
         @builtins.property
-        def object_group(self) -> str:
+        def object_group(self) -> builtins.str:
             """``CfnContainer.MetricPolicyRuleProperty.ObjectGroup``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html#cfn-mediastore-container-metricpolicyrule-objectgroup
             """
-            return self._values.get("object_group")
+            result = self._values.get("object_group")
+            assert result is not None, "Required property 'object_group' is missing"
+            return result
 
         @builtins.property
-        def object_group_name(self) -> str:
+        def object_group_name(self) -> builtins.str:
             """``CfnContainer.MetricPolicyRuleProperty.ObjectGroupName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html#cfn-mediastore-container-metricpolicyrule-objectgroupname
             """
-            return self._values.get("object_group_name")
+            result = self._values.get("object_group_name")
+            assert result is not None, "Required property 'object_group_name' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -447,12 +466,12 @@ class CfnContainerProps:
     def __init__(
         self,
         *,
-        container_name: str,
-        access_logging_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        container_name: builtins.str,
+        access_logging_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]] = None,
-        lifecycle_policy: typing.Optional[str] = None,
+        lifecycle_policy: typing.Optional[builtins.str] = None,
         metric_policy: typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]] = None,
-        policy: typing.Optional[str] = None,
+        policy: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::MediaStore::Container``.
@@ -468,7 +487,7 @@ class CfnContainerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "container_name": container_name,
         }
         if access_logging_enabled is not None:
@@ -485,24 +504,27 @@ class CfnContainerProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def container_name(self) -> str:
+    def container_name(self) -> builtins.str:
         """``AWS::MediaStore::Container.ContainerName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-containername
         """
-        return self._values.get("container_name")
+        result = self._values.get("container_name")
+        assert result is not None, "Required property 'container_name' is missing"
+        return result
 
     @builtins.property
     def access_logging_enabled(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.AccessLoggingEnabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-accessloggingenabled
         """
-        return self._values.get("access_logging_enabled")
+        result = self._values.get("access_logging_enabled")
+        return result
 
     @builtins.property
     def cors_policy(
@@ -513,16 +535,18 @@ class CfnContainerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-corspolicy
         """
-        return self._values.get("cors_policy")
+        result = self._values.get("cors_policy")
+        return result
 
     @builtins.property
-    def lifecycle_policy(self) -> typing.Optional[str]:
+    def lifecycle_policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.LifecyclePolicy``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-lifecyclepolicy
         """
-        return self._values.get("lifecycle_policy")
+        result = self._values.get("lifecycle_policy")
+        return result
 
     @builtins.property
     def metric_policy(
@@ -533,16 +557,18 @@ class CfnContainerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-metricpolicy
         """
-        return self._values.get("metric_policy")
+        result = self._values.get("metric_policy")
+        return result
 
     @builtins.property
-    def policy(self) -> typing.Optional[str]:
+    def policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.Policy``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-policy
         """
-        return self._values.get("policy")
+        result = self._values.get("policy")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -551,12 +577,13 @@ class CfnContainerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
