@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -38,11 +38,11 @@ class CfnLedger(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        permissions_mode: str,
-        deletion_protection: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        name: typing.Optional[str] = None,
+        permissions_mode: builtins.str,
+        deletion_protection: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::QLDB::Ledger``.
@@ -76,25 +76,26 @@ class CfnLedger(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::QLDB::Ledger.Tags``.
@@ -104,9 +105,9 @@ class CfnLedger(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="permissionsMode")
-    def permissions_mode(self) -> str:
+    def permissions_mode(self) -> builtins.str:
         """``AWS::QLDB::Ledger.PermissionsMode``.
 
         see
@@ -114,15 +115,15 @@ class CfnLedger(
         """
         return jsii.get(self, "permissionsMode")
 
-    @permissions_mode.setter
-    def permissions_mode(self, value: str) -> None:
+    @permissions_mode.setter # type: ignore
+    def permissions_mode(self, value: builtins.str) -> None:
         jsii.set(self, "permissionsMode", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deletionProtection")
     def deletion_protection(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::QLDB::Ledger.DeletionProtection``.
 
         see
@@ -130,15 +131,16 @@ class CfnLedger(
         """
         return jsii.get(self, "deletionProtection")
 
-    @deletion_protection.setter
+    @deletion_protection.setter # type: ignore
     def deletion_protection(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "deletionProtection", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Ledger.Name``.
 
         see
@@ -146,8 +148,8 @@ class CfnLedger(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: typing.Optional[str]) -> None:
+    @name.setter # type: ignore
+    def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
 
@@ -165,9 +167,9 @@ class CfnLedgerProps:
     def __init__(
         self,
         *,
-        permissions_mode: str,
-        deletion_protection: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        name: typing.Optional[str] = None,
+        permissions_mode: builtins.str,
+        deletion_protection: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::QLDB::Ledger``.
@@ -180,7 +182,7 @@ class CfnLedgerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "permissions_mode": permissions_mode,
         }
         if deletion_protection is not None:
@@ -191,33 +193,37 @@ class CfnLedgerProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def permissions_mode(self) -> str:
+    def permissions_mode(self) -> builtins.str:
         """``AWS::QLDB::Ledger.PermissionsMode``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-permissionsmode
         """
-        return self._values.get("permissions_mode")
+        result = self._values.get("permissions_mode")
+        assert result is not None, "Required property 'permissions_mode' is missing"
+        return result
 
     @builtins.property
     def deletion_protection(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::QLDB::Ledger.DeletionProtection``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-deletionprotection
         """
-        return self._values.get("deletion_protection")
+        result = self._values.get("deletion_protection")
+        return result
 
     @builtins.property
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Ledger.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -226,12 +232,13 @@ class CfnLedgerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -257,14 +264,14 @@ class CfnStream(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        inclusive_start_time: str,
+        inclusive_start_time: builtins.str,
         kinesis_configuration: typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e],
-        ledger_name: str,
-        role_arn: str,
-        stream_name: str,
-        exclusive_end_time: typing.Optional[str] = None,
+        ledger_name: builtins.str,
+        role_arn: builtins.str,
+        stream_name: builtins.str,
+        exclusive_end_time: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::QLDB::Stream``.
@@ -304,43 +311,44 @@ class CfnStream(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrId")
-    def attr_id(self) -> str:
+    def attr_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Id
         """
         return jsii.get(self, "attrId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::QLDB::Stream.Tags``.
@@ -350,9 +358,9 @@ class CfnStream(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="inclusiveStartTime")
-    def inclusive_start_time(self) -> str:
+    def inclusive_start_time(self) -> builtins.str:
         """``AWS::QLDB::Stream.InclusiveStartTime``.
 
         see
@@ -360,11 +368,11 @@ class CfnStream(
         """
         return jsii.get(self, "inclusiveStartTime")
 
-    @inclusive_start_time.setter
-    def inclusive_start_time(self, value: str) -> None:
+    @inclusive_start_time.setter # type: ignore
+    def inclusive_start_time(self, value: builtins.str) -> None:
         jsii.set(self, "inclusiveStartTime", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="kinesisConfiguration")
     def kinesis_configuration(
         self,
@@ -376,16 +384,16 @@ class CfnStream(
         """
         return jsii.get(self, "kinesisConfiguration")
 
-    @kinesis_configuration.setter
+    @kinesis_configuration.setter # type: ignore
     def kinesis_configuration(
         self,
         value: typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "kinesisConfiguration", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ledgerName")
-    def ledger_name(self) -> str:
+    def ledger_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.LedgerName``.
 
         see
@@ -393,13 +401,13 @@ class CfnStream(
         """
         return jsii.get(self, "ledgerName")
 
-    @ledger_name.setter
-    def ledger_name(self, value: str) -> None:
+    @ledger_name.setter # type: ignore
+    def ledger_name(self, value: builtins.str) -> None:
         jsii.set(self, "ledgerName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="roleArn")
-    def role_arn(self) -> str:
+    def role_arn(self) -> builtins.str:
         """``AWS::QLDB::Stream.RoleArn``.
 
         see
@@ -407,13 +415,13 @@ class CfnStream(
         """
         return jsii.get(self, "roleArn")
 
-    @role_arn.setter
-    def role_arn(self, value: str) -> None:
+    @role_arn.setter # type: ignore
+    def role_arn(self, value: builtins.str) -> None:
         jsii.set(self, "roleArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamName")
-    def stream_name(self) -> str:
+    def stream_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.StreamName``.
 
         see
@@ -421,13 +429,13 @@ class CfnStream(
         """
         return jsii.get(self, "streamName")
 
-    @stream_name.setter
-    def stream_name(self, value: str) -> None:
+    @stream_name.setter # type: ignore
+    def stream_name(self, value: builtins.str) -> None:
         jsii.set(self, "streamName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="exclusiveEndTime")
-    def exclusive_end_time(self) -> typing.Optional[str]:
+    def exclusive_end_time(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Stream.ExclusiveEndTime``.
 
         see
@@ -435,8 +443,8 @@ class CfnStream(
         """
         return jsii.get(self, "exclusiveEndTime")
 
-    @exclusive_end_time.setter
-    def exclusive_end_time(self, value: typing.Optional[str]) -> None:
+    @exclusive_end_time.setter # type: ignore
+    def exclusive_end_time(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "exclusiveEndTime", value)
 
     @jsii.data_type(
@@ -451,8 +459,8 @@ class CfnStream(
         def __init__(
             self,
             *,
-            aggregation_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            stream_arn: typing.Optional[str] = None,
+            aggregation_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            stream_arn: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param aggregation_enabled: ``CfnStream.KinesisConfigurationProperty.AggregationEnabled``.
@@ -461,7 +469,7 @@ class CfnStream(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qldb-stream-kinesisconfiguration.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if aggregation_enabled is not None:
                 self._values["aggregation_enabled"] = aggregation_enabled
             if stream_arn is not None:
@@ -470,27 +478,29 @@ class CfnStream(
         @builtins.property
         def aggregation_enabled(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnStream.KinesisConfigurationProperty.AggregationEnabled``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qldb-stream-kinesisconfiguration.html#cfn-qldb-stream-kinesisconfiguration-aggregationenabled
             """
-            return self._values.get("aggregation_enabled")
+            result = self._values.get("aggregation_enabled")
+            return result
 
         @builtins.property
-        def stream_arn(self) -> typing.Optional[str]:
+        def stream_arn(self) -> typing.Optional[builtins.str]:
             """``CfnStream.KinesisConfigurationProperty.StreamArn``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qldb-stream-kinesisconfiguration.html#cfn-qldb-stream-kinesisconfiguration-streamarn
             """
-            return self._values.get("stream_arn")
+            result = self._values.get("stream_arn")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -516,12 +526,12 @@ class CfnStreamProps:
     def __init__(
         self,
         *,
-        inclusive_start_time: str,
+        inclusive_start_time: builtins.str,
         kinesis_configuration: typing.Union["CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e],
-        ledger_name: str,
-        role_arn: str,
-        stream_name: str,
-        exclusive_end_time: typing.Optional[str] = None,
+        ledger_name: builtins.str,
+        role_arn: builtins.str,
+        stream_name: builtins.str,
+        exclusive_end_time: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::QLDB::Stream``.
@@ -537,7 +547,7 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "inclusive_start_time": inclusive_start_time,
             "kinesis_configuration": kinesis_configuration,
             "ledger_name": ledger_name,
@@ -550,13 +560,15 @@ class CfnStreamProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def inclusive_start_time(self) -> str:
+    def inclusive_start_time(self) -> builtins.str:
         """``AWS::QLDB::Stream.InclusiveStartTime``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-inclusivestarttime
         """
-        return self._values.get("inclusive_start_time")
+        result = self._values.get("inclusive_start_time")
+        assert result is not None, "Required property 'inclusive_start_time' is missing"
+        return result
 
     @builtins.property
     def kinesis_configuration(
@@ -567,43 +579,52 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-kinesisconfiguration
         """
-        return self._values.get("kinesis_configuration")
+        result = self._values.get("kinesis_configuration")
+        assert result is not None, "Required property 'kinesis_configuration' is missing"
+        return result
 
     @builtins.property
-    def ledger_name(self) -> str:
+    def ledger_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.LedgerName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-ledgername
         """
-        return self._values.get("ledger_name")
+        result = self._values.get("ledger_name")
+        assert result is not None, "Required property 'ledger_name' is missing"
+        return result
 
     @builtins.property
-    def role_arn(self) -> str:
+    def role_arn(self) -> builtins.str:
         """``AWS::QLDB::Stream.RoleArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-rolearn
         """
-        return self._values.get("role_arn")
+        result = self._values.get("role_arn")
+        assert result is not None, "Required property 'role_arn' is missing"
+        return result
 
     @builtins.property
-    def stream_name(self) -> str:
+    def stream_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.StreamName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-streamname
         """
-        return self._values.get("stream_name")
+        result = self._values.get("stream_name")
+        assert result is not None, "Required property 'stream_name' is missing"
+        return result
 
     @builtins.property
-    def exclusive_end_time(self) -> typing.Optional[str]:
+    def exclusive_end_time(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Stream.ExclusiveEndTime``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-exclusiveendtime
         """
-        return self._values.get("exclusive_end_time")
+        result = self._values.get("exclusive_end_time")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -612,12 +633,13 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
