@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -38,12 +38,12 @@ class CfnResourceShare(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
-        allow_external_principals: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        principals: typing.Optional[typing.List[str]] = None,
-        resource_arns: typing.Optional[typing.List[str]] = None,
+        name: builtins.str,
+        allow_external_principals: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        principals: typing.Optional[typing.List[builtins.str]] = None,
+        resource_arns: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::RAM::ResourceShare``.
@@ -79,34 +79,35 @@ class CfnResourceShare(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::RAM::ResourceShare.Tags``.
@@ -116,9 +117,9 @@ class CfnResourceShare(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::RAM::ResourceShare.Name``.
 
         see
@@ -126,15 +127,15 @@ class CfnResourceShare(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="allowExternalPrincipals")
     def allow_external_principals(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::RAM::ResourceShare.AllowExternalPrincipals``.
 
         see
@@ -142,15 +143,16 @@ class CfnResourceShare(
         """
         return jsii.get(self, "allowExternalPrincipals")
 
-    @allow_external_principals.setter
+    @allow_external_principals.setter # type: ignore
     def allow_external_principals(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "allowExternalPrincipals", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="principals")
-    def principals(self) -> typing.Optional[typing.List[str]]:
+    def principals(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::RAM::ResourceShare.Principals``.
 
         see
@@ -158,13 +160,13 @@ class CfnResourceShare(
         """
         return jsii.get(self, "principals")
 
-    @principals.setter
-    def principals(self, value: typing.Optional[typing.List[str]]) -> None:
+    @principals.setter # type: ignore
+    def principals(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
         jsii.set(self, "principals", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceArns")
-    def resource_arns(self) -> typing.Optional[typing.List[str]]:
+    def resource_arns(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::RAM::ResourceShare.ResourceArns``.
 
         see
@@ -172,8 +174,8 @@ class CfnResourceShare(
         """
         return jsii.get(self, "resourceArns")
 
-    @resource_arns.setter
-    def resource_arns(self, value: typing.Optional[typing.List[str]]) -> None:
+    @resource_arns.setter # type: ignore
+    def resource_arns(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
         jsii.set(self, "resourceArns", value)
 
 
@@ -192,10 +194,10 @@ class CfnResourceShareProps:
     def __init__(
         self,
         *,
-        name: str,
-        allow_external_principals: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        principals: typing.Optional[typing.List[str]] = None,
-        resource_arns: typing.Optional[typing.List[str]] = None,
+        name: builtins.str,
+        allow_external_principals: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        principals: typing.Optional[typing.List[builtins.str]] = None,
+        resource_arns: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::RAM::ResourceShare``.
@@ -209,7 +211,7 @@ class CfnResourceShareProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
         if allow_external_principals is not None:
@@ -222,42 +224,47 @@ class CfnResourceShareProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::RAM::ResourceShare.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
     def allow_external_principals(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::RAM::ResourceShare.AllowExternalPrincipals``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-allowexternalprincipals
         """
-        return self._values.get("allow_external_principals")
+        result = self._values.get("allow_external_principals")
+        return result
 
     @builtins.property
-    def principals(self) -> typing.Optional[typing.List[str]]:
+    def principals(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::RAM::ResourceShare.Principals``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-principals
         """
-        return self._values.get("principals")
+        result = self._values.get("principals")
+        return result
 
     @builtins.property
-    def resource_arns(self) -> typing.Optional[typing.List[str]]:
+    def resource_arns(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::RAM::ResourceShare.ResourceArns``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-resourcearns
         """
-        return self._values.get("resource_arns")
+        result = self._values.get("resource_arns")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -266,12 +273,13 @@ class CfnResourceShareProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
