@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     AssetHashType as _AssetHashType_16f7047a,
     AssetOptions as _AssetOptions_b07b0eef,
@@ -39,7 +40,7 @@ class Asset(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         path: builtins.str,
