@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     AssetHashType as _AssetHashType_16f7047a,
     BundlingOptions as _BundlingOptions_0cab5223,
@@ -36,7 +37,7 @@ class BucketDeployment(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         destination_bucket: _IBucket_25bad983,
