@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -43,7 +43,9 @@ class LambdaDestination(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _scope: _Construct_f50a3f53, bucket: _IBucket_25bad983
+        self,
+        _scope: _Construct_f50a3f53,
+        bucket: _IBucket_25bad983,
     ) -> _BucketNotificationDestinationConfig_f2b78ed5:
         """Registers this resource to receive notifications for the specified bucket.
 
@@ -82,7 +84,9 @@ class SnsDestination(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _scope: _Construct_f50a3f53, bucket: _IBucket_25bad983
+        self,
+        _scope: _Construct_f50a3f53,
+        bucket: _IBucket_25bad983,
     ) -> _BucketNotificationDestinationConfig_f2b78ed5:
         """Registers this resource to receive notifications for the specified bucket.
 
@@ -121,7 +125,9 @@ class SqsDestination(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _scope: _Construct_f50a3f53, bucket: _IBucket_25bad983
+        self,
+        _scope: _Construct_f50a3f53,
+        bucket: _IBucket_25bad983,
     ) -> _BucketNotificationDestinationConfig_f2b78ed5:
         """Allows using SQS queues as destinations for bucket notifications.
 
