@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -35,9 +35,9 @@ class CfnDomain(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        description: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::SDB::Domain``.
 
@@ -62,27 +62,28 @@ class CfnDomain(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::SDB::Domain.Description``.
 
         see
@@ -90,8 +91,8 @@ class CfnDomain(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
 
@@ -101,7 +102,7 @@ class CfnDomain(
     name_mapping={"description": "description"},
 )
 class CfnDomainProps:
-    def __init__(self, *, description: typing.Optional[str] = None) -> None:
+    def __init__(self, *, description: typing.Optional[builtins.str] = None) -> None:
         """Properties for defining a ``AWS::SDB::Domain``.
 
         :param description: ``AWS::SDB::Domain.Description``.
@@ -109,23 +110,24 @@ class CfnDomainProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-simpledb.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if description is not None:
             self._values["description"] = description
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::SDB::Domain.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-simpledb.html#cfn-sdb-domain-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
