@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -23,7 +23,8 @@ from ..aws_sns import ITopic as _ITopic_ef0ebe0e
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
 class AddHeader(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.AddHeader"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_ses_actions.AddHeader",
 ):
     """Adds a header to the received email.
 
@@ -31,7 +32,7 @@ class AddHeader(
     :stability: experimental
     """
 
-    def __init__(self, *, name: str, value: str) -> None:
+    def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         """
         :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
         :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
@@ -61,7 +62,7 @@ class AddHeader(
     name_mapping={"name": "name", "value": "value"},
 )
 class AddHeaderProps:
-    def __init__(self, *, name: str, value: str) -> None:
+    def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         """Construction properties for a add header action.
 
         :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
@@ -70,13 +71,13 @@ class AddHeaderProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "value": value,
         }
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """The name of the header to add.
 
         Must be between 1 and 50 characters,
@@ -86,10 +87,12 @@ class AddHeaderProps:
         stability
         :stability: experimental
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def value(self) -> str:
+    def value(self) -> builtins.str:
         """The value of the header to add.
 
         Must be less than 2048 characters,
@@ -98,12 +101,14 @@ class AddHeaderProps:
         stability
         :stability: experimental
         """
-        return self._values.get("value")
+        result = self._values.get("value")
+        assert result is not None, "Required property 'value' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -114,7 +119,8 @@ class AddHeaderProps:
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
 class Bounce(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Bounce"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_ses_actions.Bounce",
 ):
     """Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
 
@@ -125,7 +131,7 @@ class Bounce(
     def __init__(
         self,
         *,
-        sender: str,
+        sender: builtins.str,
         template: "BounceTemplate",
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
@@ -162,7 +168,7 @@ class BounceProps:
     def __init__(
         self,
         *,
-        sender: str,
+        sender: builtins.str,
         template: "BounceTemplate",
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
@@ -175,7 +181,7 @@ class BounceProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "sender": sender,
             "template": template,
         }
@@ -183,7 +189,7 @@ class BounceProps:
             self._values["topic"] = topic
 
     @builtins.property
-    def sender(self) -> str:
+    def sender(self) -> builtins.str:
         """The email address of the sender of the bounced email.
 
         This is the address
@@ -192,7 +198,9 @@ class BounceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("sender")
+        result = self._values.get("sender")
+        assert result is not None, "Required property 'sender' is missing"
+        return result
 
     @builtins.property
     def template(self) -> "BounceTemplate":
@@ -201,7 +209,9 @@ class BounceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("template")
+        result = self._values.get("template")
+        assert result is not None, "Required property 'template' is missing"
+        return result
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
@@ -213,12 +223,13 @@ class BounceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -240,9 +251,9 @@ class BounceTemplate(
     def __init__(
         self,
         *,
-        message: str,
-        smtp_reply_code: str,
-        status_code: typing.Optional[str] = None,
+        message: builtins.str,
+        smtp_reply_code: builtins.str,
+        status_code: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param message: Human-readable text to include in the bounce message.
@@ -258,7 +269,7 @@ class BounceTemplate(
 
         jsii.create(BounceTemplate, self, [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MAILBOX_DOES_NOT_EXIST")
     def MAILBOX_DOES_NOT_EXIST(cls) -> "BounceTemplate":
         """
@@ -267,7 +278,7 @@ class BounceTemplate(
         """
         return jsii.sget(cls, "MAILBOX_DOES_NOT_EXIST")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MAILBOX_FULL")
     def MAILBOX_FULL(cls) -> "BounceTemplate":
         """
@@ -276,7 +287,7 @@ class BounceTemplate(
         """
         return jsii.sget(cls, "MAILBOX_FULL")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MESSAGE_CONTENT_REJECTED")
     def MESSAGE_CONTENT_REJECTED(cls) -> "BounceTemplate":
         """
@@ -285,7 +296,7 @@ class BounceTemplate(
         """
         return jsii.sget(cls, "MESSAGE_CONTENT_REJECTED")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MESSAGE_TOO_LARGE")
     def MESSAGE_TOO_LARGE(cls) -> "BounceTemplate":
         """
@@ -294,7 +305,7 @@ class BounceTemplate(
         """
         return jsii.sget(cls, "MESSAGE_TOO_LARGE")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="TEMPORARY_FAILURE")
     def TEMPORARY_FAILURE(cls) -> "BounceTemplate":
         """
@@ -303,7 +314,7 @@ class BounceTemplate(
         """
         return jsii.sget(cls, "TEMPORARY_FAILURE")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="props")
     def props(self) -> "BounceTemplateProps":
         """
@@ -326,9 +337,9 @@ class BounceTemplateProps:
     def __init__(
         self,
         *,
-        message: str,
-        smtp_reply_code: str,
-        status_code: typing.Optional[str] = None,
+        message: builtins.str,
+        smtp_reply_code: builtins.str,
+        status_code: typing.Optional[builtins.str] = None,
     ) -> None:
         """Construction properties for a BounceTemplate.
 
@@ -339,7 +350,7 @@ class BounceTemplateProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "message": message,
             "smtp_reply_code": smtp_reply_code,
         }
@@ -347,16 +358,18 @@ class BounceTemplateProps:
             self._values["status_code"] = status_code
 
     @builtins.property
-    def message(self) -> str:
+    def message(self) -> builtins.str:
         """Human-readable text to include in the bounce message.
 
         stability
         :stability: experimental
         """
-        return self._values.get("message")
+        result = self._values.get("message")
+        assert result is not None, "Required property 'message' is missing"
+        return result
 
     @builtins.property
-    def smtp_reply_code(self) -> str:
+    def smtp_reply_code(self) -> builtins.str:
         """The SMTP reply code, as defined by RFC 5321.
 
         see
@@ -364,10 +377,12 @@ class BounceTemplateProps:
         stability
         :stability: experimental
         """
-        return self._values.get("smtp_reply_code")
+        result = self._values.get("smtp_reply_code")
+        assert result is not None, "Required property 'smtp_reply_code' is missing"
+        return result
 
     @builtins.property
-    def status_code(self) -> typing.Optional[str]:
+    def status_code(self) -> typing.Optional[builtins.str]:
         """The SMTP enhanced status code, as defined by RFC 3463.
 
         see
@@ -375,12 +390,13 @@ class BounceTemplateProps:
         stability
         :stability: experimental
         """
-        return self._values.get("status_code")
+        result = self._values.get("status_code")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -413,7 +429,8 @@ class EmailEncoding(enum.Enum):
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
 class Lambda(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Lambda"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_ses_actions.Lambda",
 ):
     """Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
 
@@ -506,7 +523,7 @@ class LambdaProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "function": function,
         }
         if invocation_type is not None:
@@ -521,7 +538,9 @@ class LambdaProps:
         stability
         :stability: experimental
         """
-        return self._values.get("function")
+        result = self._values.get("function")
+        assert result is not None, "Required property 'function' is missing"
+        return result
 
     @builtins.property
     def invocation_type(self) -> typing.Optional["LambdaInvocationType"]:
@@ -533,7 +552,8 @@ class LambdaProps:
         stability
         :stability: experimental
         """
-        return self._values.get("invocation_type")
+        result = self._values.get("invocation_type")
+        return result
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
@@ -545,12 +565,13 @@ class LambdaProps:
         stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -572,7 +593,7 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.
         *,
         bucket: _IBucket_25bad983,
         kms_key: typing.Optional[_IKey_3336c79d] = None,
-        object_key_prefix: typing.Optional[str] = None,
+        object_key_prefix: typing.Optional[builtins.str] = None,
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
         """
@@ -621,7 +642,7 @@ class S3Props:
         *,
         bucket: _IBucket_25bad983,
         kms_key: typing.Optional[_IKey_3336c79d] = None,
-        object_key_prefix: typing.Optional[str] = None,
+        object_key_prefix: typing.Optional[builtins.str] = None,
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
         """Construction properties for a S3 action.
@@ -634,7 +655,7 @@ class S3Props:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "bucket": bucket,
         }
         if kms_key is not None:
@@ -651,7 +672,9 @@ class S3Props:
         stability
         :stability: experimental
         """
-        return self._values.get("bucket")
+        result = self._values.get("bucket")
+        assert result is not None, "Required property 'bucket' is missing"
+        return result
 
     @builtins.property
     def kms_key(self) -> typing.Optional[_IKey_3336c79d]:
@@ -663,10 +686,11 @@ class S3Props:
         stability
         :stability: experimental
         """
-        return self._values.get("kms_key")
+        result = self._values.get("kms_key")
+        return result
 
     @builtins.property
-    def object_key_prefix(self) -> typing.Optional[str]:
+    def object_key_prefix(self) -> typing.Optional[builtins.str]:
         """The key prefix of the S3 bucket.
 
         default
@@ -675,7 +699,8 @@ class S3Props:
         stability
         :stability: experimental
         """
-        return self._values.get("object_key_prefix")
+        result = self._values.get("object_key_prefix")
+        return result
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
@@ -687,12 +712,13 @@ class S3Props:
         stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -758,7 +784,7 @@ class SnsProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "topic": topic,
         }
         if encoding is not None:
@@ -771,7 +797,9 @@ class SnsProps:
         stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        assert result is not None, "Required property 'topic' is missing"
+        return result
 
     @builtins.property
     def encoding(self) -> typing.Optional["EmailEncoding"]:
@@ -783,12 +811,13 @@ class SnsProps:
         stability
         :stability: experimental
         """
-        return self._values.get("encoding")
+        result = self._values.get("encoding")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -799,7 +828,8 @@ class SnsProps:
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
 class Stop(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Stop"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_ses_actions.Stop",
 ):
     """Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
 
@@ -844,7 +874,7 @@ class StopProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if topic is not None:
             self._values["topic"] = topic
 
@@ -855,12 +885,13 @@ class StopProps:
         stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
