@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     AssetHashType as _AssetHashType_16f7047a,
     BundlingOptions as _BundlingOptions_0cab5223,
@@ -114,7 +115,7 @@ class Canary(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         test: "Test",
@@ -136,7 +137,7 @@ class Canary(
         :param canary_name: The name of the canary. Be sure to give it a descriptive name that distinguishes it from other canaries in your account. Do not include secrets or proprietary information in your canary name. The canary name makes up part of the canary ARN, which is included in outbound calls over the internet. Default: - A unique name will be generated from the construct ID
         :param failure_retention_period: How many days should failed runs be retained. Default: Duration.days(31)
         :param role: Canary execution role. This is the role that will be assumed by the canary upon execution. It controls the permissions that the canary will have. The role must be assumable by the AWS Lambda service principal. If not supplied, a role will be created with all the required permissions. If you provide a Role, you must add the required permissions. Default: - A unique role will be generated for this canary. You can add permissions to roles by calling 'addToRolePolicy'.
-        :param runtime: Specify the runtime version to use for the canary. Currently, the only valid value is ``Runtime.SYNTHETICS_1.0``. Default: Runtime.SYNTHETICS_1_0
+        :param runtime: Specify the runtime version to use for the canary. Default: Runtime.SYNTHETICS_NODEJS_2_0
         :param schedule: Specify the schedule for how often the canary runs. For example, if you set ``schedule`` to ``rate(10 minutes)``, then the canary will run every 10 minutes. You can set the schedule with ``Schedule.rate(Duration)`` (recommended) or you can specify an expression using ``Schedule.expression()``. Default: 'rate(5 minutes)'
         :param start_after_creation: Whether or not the canary should start after creation. Default: true
         :param success_retention_period: How many days should successful runs be retained. Default: Duration.days(31)
@@ -386,7 +387,7 @@ class CanaryProps:
         :param canary_name: The name of the canary. Be sure to give it a descriptive name that distinguishes it from other canaries in your account. Do not include secrets or proprietary information in your canary name. The canary name makes up part of the canary ARN, which is included in outbound calls over the internet. Default: - A unique name will be generated from the construct ID
         :param failure_retention_period: How many days should failed runs be retained. Default: Duration.days(31)
         :param role: Canary execution role. This is the role that will be assumed by the canary upon execution. It controls the permissions that the canary will have. The role must be assumable by the AWS Lambda service principal. If not supplied, a role will be created with all the required permissions. If you provide a Role, you must add the required permissions. Default: - A unique role will be generated for this canary. You can add permissions to roles by calling 'addToRolePolicy'.
-        :param runtime: Specify the runtime version to use for the canary. Currently, the only valid value is ``Runtime.SYNTHETICS_1.0``. Default: Runtime.SYNTHETICS_1_0
+        :param runtime: Specify the runtime version to use for the canary. Default: Runtime.SYNTHETICS_NODEJS_2_0
         :param schedule: Specify the schedule for how often the canary runs. For example, if you set ``schedule`` to ``rate(10 minutes)``, then the canary will run every 10 minutes. You can set the schedule with ``Schedule.rate(Duration)`` (recommended) or you can specify an expression using ``Schedule.expression()``. Default: 'rate(5 minutes)'
         :param start_after_creation: Whether or not the canary should start after creation. Default: true
         :param success_retention_period: How many days should successful runs be retained. Default: Duration.days(31)
@@ -508,11 +509,11 @@ class CanaryProps:
     def runtime(self) -> typing.Optional["Runtime"]:
         """Specify the runtime version to use for the canary.
 
-        Currently, the only valid value is ``Runtime.SYNTHETICS_1.0``.
-
         default
-        :default: Runtime.SYNTHETICS_1_0
+        :default: Runtime.SYNTHETICS_NODEJS_2_0
 
+        see
+        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Library.html
         stability
         :stability: experimental
         """
@@ -1736,11 +1737,25 @@ class Runtime(
         - Puppeteer-core version 1.14.0
         - The Chromium version that matches Puppeteer-core 1.14.0
 
+        see
+        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Library.html#CloudWatch_Synthetics_runtimeversion-1.0
         stability
         :stability: experimental
         """
         return jsii.sget(cls, "SYNTHETICS_1_0")
 
+    @jsii.python.classproperty # type: ignore
+    @jsii.member(jsii_name="SYNTHETICS_NODEJS_2_0")
+    def SYNTHETICS_NODEJS_2_0(cls) -> "Runtime":
+        """``syn-nodejs-2.0`` includes the following: - Lambda runtime Node.js 10.x - Puppeteer-core version 3.3.0 - Chromium version 81.0.4044.0.
+
+        see
+        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Library.html#CloudWatch_Synthetics_runtimeversion-2.0
+        stability
+        :stability: experimental
+        """
+        return jsii.sget(cls, "SYNTHETICS_NODEJS_2_0")
+
     @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
