@@ -640,6 +640,7 @@ class AvailabilityZonesContextQuery:
         "requires_bootstrap_stack_version": "requiresBootstrapStackVersion",
         "stack_name": "stackName",
         "stack_template_asset_object_url": "stackTemplateAssetObjectUrl",
+        "tags": "tags",
         "termination_protection": "terminationProtection",
     },
 )
@@ -654,6 +655,7 @@ class AwsCloudFormationStackProperties:
         requires_bootstrap_stack_version: typing.Optional[jsii.Number] = None,
         stack_name: typing.Optional[builtins.str] = None,
         stack_template_asset_object_url: typing.Optional[builtins.str] = None,
+        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         termination_protection: typing.Optional[builtins.bool] = None,
     ) -> None:
         """Artifact properties for CloudFormation stacks.
@@ -665,6 +667,7 @@ class AwsCloudFormationStackProperties:
         :param requires_bootstrap_stack_version: Version of bootstrap stack required to deploy this stack. Default: - No bootstrap stack required
         :param stack_name: The name to use for the CloudFormation stack. Default: - name derived from artifact ID
         :param stack_template_asset_object_url: If the stack template has already been included in the asset manifest, its asset URL. Default: - Not uploaded yet, upload just before deploying
+        :param tags: Values for CloudFormation stack tags that should be passed when the stack is deployed. Default: - No tags
         :param termination_protection: Whether to enable termination protection for this stack. Default: false
 
         stability
@@ -685,6 +688,8 @@ class AwsCloudFormationStackProperties:
             self._values["stack_name"] = stack_name
         if stack_template_asset_object_url is not None:
             self._values["stack_template_asset_object_url"] = stack_template_asset_object_url
+        if tags is not None:
+            self._values["tags"] = tags
         if termination_protection is not None:
             self._values["termination_protection"] = termination_protection
 
@@ -777,6 +782,19 @@ class AwsCloudFormationStackProperties:
         result = self._values.get("stack_template_asset_object_url")
         return result
 
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        """Values for CloudFormation stack tags that should be passed when the stack is deployed.
+
+        default
+        :default: - No tags
+
+        stability
+        :stability: experimental
+        """
+        result = self._values.get("tags")
+        return result
+
     @builtins.property
     def termination_protection(self) -> typing.Optional[builtins.bool]:
         """Whether to enable termination protection for this stack.
@@ -2485,8 +2503,8 @@ class Tag:
     def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
         """Metadata Entry spec for stack tag.
 
-        :param key: Tag key.
-        :param value: Tag value.
+        :param key: Tag key. (In the actual file on disk this will be cased as "Key", and the structure is patched to match this structure upon loading: https://github.com/aws/aws-cdk/blob/4aadaa779b48f35838cccd4e25107b2338f05547/packages/%40aws-cdk/cloud-assembly-schema/lib/manifest.ts#L137)
+        :param value: Tag value. (In the actual file on disk this will be cased as "Value", and the structure is patched to match this structure upon loading: https://github.com/aws/aws-cdk/blob/4aadaa779b48f35838cccd4e25107b2338f05547/packages/%40aws-cdk/cloud-assembly-schema/lib/manifest.ts#L137)
 
         stability
         :stability: experimental
@@ -2500,6 +2518,10 @@ class Tag:
     def key(self) -> builtins.str:
         """Tag key.
 
+        (In the actual file on disk this will be cased as "Key", and the structure is
+        patched to match this structure upon loading:
+        https://github.com/aws/aws-cdk/blob/4aadaa779b48f35838cccd4e25107b2338f05547/packages/%40aws-cdk/cloud-assembly-schema/lib/manifest.ts#L137)
+
         stability
         :stability: experimental
         """
@@ -2511,6 +2533,10 @@ class Tag:
     def value(self) -> builtins.str:
         """Tag value.
 
+        (In the actual file on disk this will be cased as "Value", and the structure is
+        patched to match this structure upon loading:
+        https://github.com/aws/aws-cdk/blob/4aadaa779b48f35838cccd4e25107b2338f05547/packages/%40aws-cdk/cloud-assembly-schema/lib/manifest.ts#L137)
+
         stability
         :stability: experimental
         """
