@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -41,18 +41,18 @@ class CfnInclude(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        template_file: str,
-        nested_stacks: typing.Optional[typing.Mapping[str, "CfnIncludeProps"]] = None,
-        parameters: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        preserve_logical_ids: typing.Optional[bool] = None,
+        template_file: builtins.str,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]] = None,
+        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
         :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from {@link CfnInclude.getNestedStack}. If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
         :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
         :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
 
@@ -61,7 +61,7 @@ class CfnInclude(
         """
         props = CfnIncludeProps(
             template_file=template_file,
-            nested_stacks=nested_stacks,
+            load_nested_stacks=load_nested_stacks,
             parameters=parameters,
             preserve_logical_ids=preserve_logical_ids,
         )
@@ -69,7 +69,7 @@ class CfnInclude(
         jsii.create(CfnInclude, self, [scope, id, props])
 
     @jsii.member(jsii_name="getCondition")
-    def get_condition(self, condition_name: str) -> _CfnCondition_548166d0:
+    def get_condition(self, condition_name: builtins.str) -> _CfnCondition_548166d0:
         """Returns the CfnCondition object from the 'Conditions' section of the CloudFormation template with the given name.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -85,7 +85,7 @@ class CfnInclude(
         return jsii.invoke(self, "getCondition", [condition_name])
 
     @jsii.member(jsii_name="getHook")
-    def get_hook(self, hook_logical_id: str) -> _CfnHook_ca75538d:
+    def get_hook(self, hook_logical_id: builtins.str) -> _CfnHook_ca75538d:
         """Returns the CfnHook object from the 'Hooks' section of the included CloudFormation template with the given logical ID.
 
         Any modifications performed on the returned object will be reflected in the resulting CDK template.
@@ -101,7 +101,7 @@ class CfnInclude(
         return jsii.invoke(self, "getHook", [hook_logical_id])
 
     @jsii.member(jsii_name="getMapping")
-    def get_mapping(self, mapping_name: str) -> _CfnMapping_b46343a2:
+    def get_mapping(self, mapping_name: builtins.str) -> _CfnMapping_b46343a2:
         """Returns the CfnMapping object from the 'Mappings' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -117,11 +117,12 @@ class CfnInclude(
         return jsii.invoke(self, "getMapping", [mapping_name])
 
     @jsii.member(jsii_name="getNestedStack")
-    def get_nested_stack(self, logical_id: str) -> "IncludedNestedStack":
-        """Returns the NestedStack with name logicalId.
+    def get_nested_stack(self, logical_id: builtins.str) -> "IncludedNestedStack":
+        """Returns a loaded NestedStack with name logicalId.
 
-        For a nested stack to be returned by this method, it must be specified in the {@link CfnIncludeProps.nestedStacks}
-        property.
+        For a nested stack to be returned by this method,
+        it must be specified either in the {@link CfnIncludeProps.loadNestedStacks} property,
+        or through the {@link loadNestedStack} method.
 
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
 
@@ -131,7 +132,7 @@ class CfnInclude(
         return jsii.invoke(self, "getNestedStack", [logical_id])
 
     @jsii.member(jsii_name="getOutput")
-    def get_output(self, logical_id: str) -> _CfnOutput_1185605a:
+    def get_output(self, logical_id: builtins.str) -> _CfnOutput_1185605a:
         """Returns the CfnOutput object from the 'Outputs' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -147,7 +148,7 @@ class CfnInclude(
         return jsii.invoke(self, "getOutput", [logical_id])
 
     @jsii.member(jsii_name="getParameter")
-    def get_parameter(self, parameter_name: str) -> _CfnParameter_90f1d0df:
+    def get_parameter(self, parameter_name: builtins.str) -> _CfnParameter_90f1d0df:
         """Returns the CfnParameter object from the 'Parameters' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -163,7 +164,7 @@ class CfnInclude(
         return jsii.invoke(self, "getParameter", [parameter_name])
 
     @jsii.member(jsii_name="getResource")
-    def get_resource(self, logical_id: str) -> _CfnResource_7760e8e4:
+    def get_resource(self, logical_id: builtins.str) -> _CfnResource_7760e8e4:
         """Returns the low-level CfnResource from the template with the given logical ID.
 
         Any modifications performed on that resource will be reflected in the resulting CDK template.
@@ -186,7 +187,7 @@ class CfnInclude(
         return jsii.invoke(self, "getResource", [logical_id])
 
     @jsii.member(jsii_name="getRule")
-    def get_rule(self, rule_name: str) -> _CfnRule_a373f272:
+    def get_rule(self, rule_name: builtins.str) -> _CfnRule_a373f272:
         """Returns the CfnRule object from the 'Rules' section of the CloudFormation template with the given name.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -201,13 +202,51 @@ class CfnInclude(
         """
         return jsii.invoke(self, "getRule", [rule_name])
 
+    @jsii.member(jsii_name="loadNestedStack")
+    def load_nested_stack(
+        self,
+        logical_id: builtins.str,
+        *,
+        template_file: builtins.str,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]] = None,
+        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        preserve_logical_ids: typing.Optional[builtins.bool] = None,
+    ) -> "IncludedNestedStack":
+        """Includes a template for a child stack inside of this parent template.
+
+        A child with this logical ID must exist in the template,
+        and be of type AWS::CloudFormation::Stack.
+        This is equivalent to specifying the value in the {@link CfnIncludeProps.loadNestedStacks}
+        property on object construction.
+
+        :param logical_id: the ID of the stack to retrieve, as it appears in the template.
+        :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
+        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
+        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
+
+        return
+        :return: the same {@link IncludedNestedStack} object that {@link getNestedStack} returns for this logical ID
+
+        stability
+        :stability: experimental
+        """
+        nested_stack_props = CfnIncludeProps(
+            template_file=template_file,
+            load_nested_stacks=load_nested_stacks,
+            parameters=parameters,
+            preserve_logical_ids=preserve_logical_ids,
+        )
+
+        return jsii.invoke(self, "loadNestedStack", [logical_id, nested_stack_props])
+
 
 @jsii.data_type(
     jsii_type="monocdk-experiment.cloudformation_include.CfnIncludeProps",
     jsii_struct_bases=[],
     name_mapping={
         "template_file": "templateFile",
-        "nested_stacks": "nestedStacks",
+        "load_nested_stacks": "loadNestedStacks",
         "parameters": "parameters",
         "preserve_logical_ids": "preserveLogicalIds",
     },
@@ -216,33 +255,33 @@ class CfnIncludeProps:
     def __init__(
         self,
         *,
-        template_file: str,
-        nested_stacks: typing.Optional[typing.Mapping[str, "CfnIncludeProps"]] = None,
-        parameters: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        preserve_logical_ids: typing.Optional[bool] = None,
+        template_file: builtins.str,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]] = None,
+        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
         """Construction properties of {@link CfnInclude}.
 
         :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from {@link CfnInclude.getNestedStack}. If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
         :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
         :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
 
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "template_file": template_file,
         }
-        if nested_stacks is not None:
-            self._values["nested_stacks"] = nested_stacks
+        if load_nested_stacks is not None:
+            self._values["load_nested_stacks"] = load_nested_stacks
         if parameters is not None:
             self._values["parameters"] = parameters
         if preserve_logical_ids is not None:
             self._values["preserve_logical_ids"] = preserve_logical_ids
 
     @builtins.property
-    def template_file(self) -> str:
+    def template_file(self) -> builtins.str:
         """Path to the template file.
 
         Both JSON and YAML template formats are supported.
@@ -250,14 +289,19 @@ class CfnIncludeProps:
         stability
         :stability: experimental
         """
-        return self._values.get("template_file")
+        result = self._values.get("template_file")
+        assert result is not None, "Required property 'template_file' is missing"
+        return result
 
     @builtins.property
-    def nested_stacks(self) -> typing.Optional[typing.Mapping[str, "CfnIncludeProps"]]:
+    def load_nested_stacks(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]]:
         """Specifies the template files that define nested stacks that should be included.
 
         If your template specifies a stack that isn't included here, it won't be created as a NestedStack
-        resource, and it won't be accessible from {@link CfnInclude.getNestedStack}.
+        resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method
+        (but will still be accessible from the {@link CfnInclude.getResource} method).
 
         If you include a stack here with an ID that isn't in the template,
         or is in the template but is not a nested stack,
@@ -269,10 +313,11 @@ class CfnIncludeProps:
         stability
         :stability: experimental
         """
-        return self._values.get("nested_stacks")
+        result = self._values.get("load_nested_stacks")
+        return result
 
     @builtins.property
-    def parameters(self) -> typing.Optional[typing.Mapping[str, typing.Any]]:
+    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
         """Specifies parameters to be replaced by the values in this mapping.
 
         Any parameters in the template that aren't specified here will be left unmodified.
@@ -285,10 +330,11 @@ class CfnIncludeProps:
         stability
         :stability: experimental
         """
-        return self._values.get("parameters")
+        result = self._values.get("parameters")
+        return result
 
     @builtins.property
-    def preserve_logical_ids(self) -> typing.Optional[bool]:
+    def preserve_logical_ids(self) -> typing.Optional[builtins.bool]:
         """Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file.
 
         If you're vending a Construct using an existing CloudFormation template,
@@ -304,12 +350,13 @@ class CfnIncludeProps:
         stability
         :stability: experimental
         """
-        return self._values.get("preserve_logical_ids")
+        result = self._values.get("preserve_logical_ids")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -325,7 +372,10 @@ class CfnIncludeProps:
 )
 class IncludedNestedStack:
     def __init__(
-        self, *, included_template: "CfnInclude", stack: _NestedStack_e205561c
+        self,
+        *,
+        included_template: "CfnInclude",
+        stack: _NestedStack_e205561c,
     ) -> None:
         """The type returned from {@link CfnInclude.getNestedStack}. Contains both the NestedStack object and CfnInclude representations of the child stack.
 
@@ -335,7 +385,7 @@ class IncludedNestedStack:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "included_template": included_template,
             "stack": stack,
         }
@@ -347,7 +397,9 @@ class IncludedNestedStack:
         stability
         :stability: experimental
         """
-        return self._values.get("included_template")
+        result = self._values.get("included_template")
+        assert result is not None, "Required property 'included_template' is missing"
+        return result
 
     @builtins.property
     def stack(self) -> _NestedStack_e205561c:
@@ -356,12 +408,14 @@ class IncludedNestedStack:
         stability
         :stability: experimental
         """
-        return self._values.get("stack")
+        result = self._values.get("stack")
+        assert result is not None, "Required property 'stack' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
