@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import (
     Construct as _Construct_f50a3f53,
     Duration as _Duration_5170c158,
@@ -46,7 +47,7 @@ class AwsCustomResource(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         policy: "AwsCustomResourcePolicy",
@@ -743,7 +744,7 @@ class Provider(
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         on_event_handler: _IFunction_1c1de0bc,
