@@ -60,8 +60,14 @@ class AssemblyBuildOptions:
         default
         :default: - if this option is not specified, runtime info will not be included
 
+        deprecated
+        :deprecated:
+
+        All template modifications that should result from this should
+        have already been inserted into the template.
+
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         result = self._values.get("runtime_info")
         return result
@@ -766,6 +772,16 @@ class CloudFormationStackArtifact(
         """
         return jsii.get(self, "stackName")
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> typing.Mapping[builtins.str, builtins.str]:
+        """CloudFormation tags to pass to the stack.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "tags")
+
     @builtins.property # type: ignore
     @jsii.member(jsii_name="template")
     def template(self) -> typing.Any:
