@@ -180,6 +180,16 @@ class FactName(
         """
         return jsii.sinvoke(cls, "servicePrincipal", [service])
 
+    @jsii.python.classproperty # type: ignore
+    @jsii.member(jsii_name="APPMESH_ECR_ACCOUNT")
+    def APPMESH_ECR_ACCOUNT(cls) -> builtins.str:
+        """The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sget(cls, "APPMESH_ECR_ACCOUNT")
+
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CDK_METADATA_RESOURCE_AVAILABLE")
     def CDK_METADATA_RESOURCE_AVAILABLE(cls) -> builtins.str:
@@ -439,6 +449,16 @@ class RegionInfo(
         """
         return jsii.get(self, "name")
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="appMeshRepositoryAccount")
+    def app_mesh_repository_account(self) -> typing.Optional[builtins.str]:
+        """The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "appMeshRepositoryAccount")
+
     @builtins.property # type: ignore
     @jsii.member(jsii_name="dlcRepositoryAccount")
     def dlc_repository_account(self) -> typing.Optional[builtins.str]:
